@@ -166,10 +166,10 @@ QString SKGBookmarkPlugin::icon() const
 QStringList SKGBookmarkPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... some bookmarks can be opened automatically when the application is launched.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... bookmarks can be reorganized by drag & drop.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... a double click on a folder of bookmarks will open all the bookmarks it contains.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can <a href=\"skg://import_standard_bookmarks\">import standard bookmarks</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… some bookmarks can be opened automatically when the application is launched.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… bookmarks can be reorganized by drag & drop.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… a double click on a folder of bookmarks will open all the bookmarks it contains.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can <a href=\"skg://import_standard_bookmarks\">import standard bookmarks</a>.</p>"));
     return output;
 }
 
