@@ -138,7 +138,7 @@ void SKGBookmarkPluginDockWidget::initMenu()
         m_actRename->setShortcut(Qt::Key_F2);
         connect(m_actRename, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onRenameBookmark);
 
-        m_actChangeIcon = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-image-face-add")), i18nc("Verb, change the icon of an item", "Change icon..."));
+        m_actChangeIcon = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-image-face-add")), i18nc("Verb, change the icon of an item", "Change icon…"));
         connect(m_actChangeIcon, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onChangeIconBookmark);
 
         m_mainMenu->addSeparator();
@@ -436,7 +436,7 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
                 defaultIcon = tab-> tabIcon(index).name();
             }
         }
-        name += defaultName;
+        name += defaultName.replace("&", "");
 
         // Create bookmark
         SKGBEGINTRANSACTION(*iParentNode.getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err)
