@@ -98,9 +98,9 @@ int SKGDashboardPlugin::getOrder() const
 QStringList SKGDashboardPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... the <a href=\"skg://dashboard_plugin\">dashboard</a> is there to give you a summary of your situation.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... the <a href=\"skg://dashboard_plugin\">dashboard</a> can be reorganized by drag and drop.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... some widgets of the <a href=\"skg://dashboard_plugin\">dashboard</a> have parameters.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… the <a href=\"skg://dashboard_plugin\">dashboard</a> is there to give you a summary of your situation.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… the <a href=\"skg://dashboard_plugin\">dashboard</a> can be reorganized by drag and drop.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… some widgets of the <a href=\"skg://dashboard_plugin\">dashboard</a> have parameters.</p>"));
     return output;
 }
 
