@@ -81,7 +81,7 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument)
     registerGlobalAction(QStringLiteral("file_save"), m_saveAction);
     registerGlobalAction(QStringLiteral("file_save_as"), KStandardAction::saveAs(this, SLOT(onSaveAs()), actionCollection()));
 
-    auto actChangePassword = new QAction(SKGServices::fromTheme(QStringLiteral("document-encrypt")),  i18nc("Action allowing the user to change his document password", "Change password..."), this);
+    auto actChangePassword = new QAction(SKGServices::fromTheme(QStringLiteral("document-encrypt")),  i18nc("Action allowing the user to change his document password", "Change password…"), this);
     connect(actChangePassword, &QAction::triggered, this, &SKGFilePlugin::onChangePassword);
     actionCollection()->setDefaultShortcut(actChangePassword, Qt::CTRL + Qt::Key_K);
     registerGlobalAction(QStringLiteral("file_change_password"), actChangePassword);
@@ -120,7 +120,7 @@ QStringList SKGFilePlugin::processArguments(const QStringList& iArgument)
                     if (SKGMainPanel::getMainPanel() != nullptr) {
                         QSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
                         if (splashScreen != nullptr) {
-                            splashScreen->showMessage(i18nc("Splash screen message", "Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
+                            splashScreen->showMessage(i18nc("Splash screen message", "Opening file %1…", filename), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
                         }
                     }
                     Q_EMIT loadFile(QUrl::fromLocalFile(filename));
@@ -141,7 +141,7 @@ QStringList SKGFilePlugin::processArguments(const QStringList& iArgument)
                     if (SKGMainPanel::getMainPanel() != nullptr) {
                         QSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
                         if (splashScreen != nullptr) {
-                            splashScreen->showMessage(i18nc("Splash screen message",  "Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
+                            splashScreen->showMessage(i18nc("Splash screen message",  "Opening file %1…", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
                         }
                     }
                     Q_EMIT loadFile(QUrl::fromLocalFile(lastOpenedFile));
@@ -239,14 +239,14 @@ QString SKGFilePlugin::icon() const
 
 QString SKGFilePlugin::toolTip() const
 {
-    return i18nc("File Management, as in Save File, Save As...", "File management");
+    return i18nc("File Management, as in Save File, Save As…", "File management");
 }
 
 QStringList SKGFilePlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tip", "<p>... the last opened file can be <a href=\"skg://tab_configure?page=File plugin\">open automatically</a> when the application is launched.</p>"));
-    output.push_back(i18nc("Description of a tip", "<p>... you can secure your document with a <a href=\"skg://file_change_password\">password</a>.</p>"));
+    output.push_back(i18nc("Description of a tip", "<p>… the last opened file can be <a href=\"skg://tab_configure?page=File plugin\">open automatically</a> when the application is launched.</p>"));
+    output.push_back(i18nc("Description of a tip", "<p>… you can secure your document with a <a href=\"skg://file_change_password\">password</a>.</p>"));
     return output;
 }
 
