@@ -90,7 +90,7 @@ QStringList SKGMonthlyPlugin::processArguments(const QStringList& iArgument)
     // Initialise the main page
     if (m_mainPage == nullptr) {
 #ifdef SKG_WEBENGINE
-        m_mainPage = new SKGWebView(SKGMainPanel::getMainPanel(), 0, false);
+        m_mainPage = new SKGWebView(SKGMainPanel::getMainPanel(), nullptr, false);
 #endif
 #ifdef SKG_WEBKIT
         m_mainPage = new QWebView();
@@ -176,9 +176,9 @@ int SKGMonthlyPlugin::getOrder() const
 QStringList SKGMonthlyPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... you can generate a <a href=\"skg://monthly_plugin\">monthly report</a>.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can download more monthly report <a href=\"skg://monthly_plugin\">templates</a>.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can create and share your own <a href=\"skg://monthly_plugin\">monthly report</a> template.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can generate a <a href=\"skg://monthly_plugin\">monthly report</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can download more monthly report <a href=\"skg://monthly_plugin\">templates</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can create and share your own <a href=\"skg://monthly_plugin\">monthly report</a> template.</p>"));
     return output;
 }
 
