@@ -86,7 +86,7 @@ int SKGPrintPlugin::getOrder() const
 QStringList SKGPrintPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... you can <a href=\"skg://file_print\">print</a> all opened pages.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can <a href=\"skg://file_print\">print</a> all opened pages.</p>"));
     return output;
 }
 
