@@ -97,6 +97,7 @@ void SKGSelectAllPlugin::onSelectionChanged()
             double sum = 0.0;
             double max = -std::numeric_limits<double>::max();
             double min = std::numeric_limits<double>::max();
+            qlonglong nbdec = -1;
             int count = 0;
             for (int i = 0; i < nb; ++i) {
                 const SKGObjectBase& obj(selection.at(i));
@@ -111,16 +112,20 @@ void SKGSelectAllPlugin::onSelectionChanged()
                     min = qMin(min, vald);
                     count++;
                 }
+                auto dec = obj.getAttribute(QStringLiteral("i_NBDEC"));
+                if (!dec.isEmpty()) {
+                    nbdec = qMax(nbdec, SKGServices::stringToInt(dec));
+                }
             }
             if (count > 1) {
                 m_selectionMessage->setText(i18n("Selection: %1 lines for %2 (min: %3, average: %4, max: %5)",
                                                  nb,
-                                                 m_currentDocument->formatPrimaryMoney(sum),
-                                                 m_currentDocument->formatPrimaryMoney(min),
-                                                 m_currentDocument->formatPrimaryMoney(sum / count),
-                                                 m_currentDocument->formatPrimaryMoney(max)));
+                                                 m_currentDocument->formatPrimaryMoney(sum, nbdec),
+                                                 m_currentDocument->formatPrimaryMoney(min, nbdec),
+                                                 m_currentDocument->formatPrimaryMoney(sum / count, nbdec),
+                                                 m_currentDocument->formatPrimaryMoney(max, nbdec)));
             } else if (count > 0) {
-                m_selectionMessage->setText(i18n("Selection: %1 line for %2", nb, m_currentDocument->formatPrimaryMoney(sum)));
+                m_selectionMessage->setText(i18n("Selection: %1 line for %2", nb, m_currentDocument->formatPrimaryMoney(sum, nbdec)));
             } else {
                 m_selectionMessage->setText(i18np("Selection: %1 line", "Selection: %1 lines", nb));
             }
