@@ -135,7 +135,7 @@ void SKGUndoRedoPlugin::refresh()
         // Refresh undo redo
         QString name;
         m_currentDocument->getTransactionToProcess(SKGDocument::UNDO, &name);
-        QString message = i18nc("Verb",  "Undo operation '%1'.", name);
+        QString message = i18nc("Verb",  "Undo transaction '%1'.", name);
         if (name.isEmpty()) {
             message = QLatin1String("");
         }
@@ -144,7 +144,7 @@ void SKGUndoRedoPlugin::refresh()
         }
 
         m_currentDocument->getTransactionToProcess(SKGDocument::REDO, &name);
-        message = i18nc("Verb",  "Redo operation '%1'.", name);
+        message = i18nc("Verb",  "Redo transaction '%1'.", name);
         if (name.isEmpty()) {
             message = QLatin1String("");
         }
@@ -220,8 +220,8 @@ QString SKGUndoRedoPlugin::toolTip() const
 QStringList SKGUndoRedoPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... you can undo and redo your modifications.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can modify the maximum size of the undo/redo stack in the <a href=\"skg://tab_configure?page=Undo redo plugin\">settings</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can undo and redo your modifications.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can modify the maximum size of the undo/redo stack in the <a href=\"skg://tab_configure?page=Undo redo plugin\">settings</a>.</p>"));
     return output;
 }
 
