@@ -225,8 +225,8 @@ SKGError SKGImportPluginBackend::importFile()
         }
     }
 
-    // Download operations
-    IFOKDO(err, m_importer->getDocument()->stepForward(1, i18nc("Progress message", "Download operations")))
+    // Download transactions
+    IFOKDO(err, m_importer->getDocument()->stepForward(1, i18nc("Progress message", "Download transactions")))
     IFOK(err) {
         if (backendAccounts.isEmpty()) {
             err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Your backend '%1' seems to be not well configure because no account has been found.", bankendName));
