@@ -184,11 +184,11 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
         // Check if mandatory attributes have been found
         if (m_importParameters.value(QStringLiteral("mode_csv_rule")) == QStringLiteral("Y")) {
             if (!m_csvMapping.contains(QStringLiteral("payee")) || !m_csvMapping.contains(QStringLiteral("category"))) {
-                err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns payee and category not found. Set import parameters in settings (Configure Skrooge... / Import/Export / CSV / Edit regular expressions...)."));
+                err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns payee and category not found. Set import parameters in settings (Configure Skrooge… / Import/Export / CSV / Edit regular expressions…)."));
             }
         } else {
             if (!m_csvMapping.contains(QStringLiteral("date")) || !m_csvMapping.contains(QStringLiteral("amount"))) {
-                err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings (Configure Skrooge... / Import/Export / CSV / Edit regular expressions...)."));
+                err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings (Configure Skrooge… / Import/Export / CSV / Edit regular expressions…)."));
             }
         }
     }
@@ -422,7 +422,7 @@ SKGError SKGImportPluginCsv::importFile()
                 // Treat all lines
                 IFOK(err) {
                     int nb2 = lines.size();
-                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb2);
+                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb2);
 
                     // Save last mapping used in a settings
                     QString mappingDesc;
@@ -513,31 +513,31 @@ SKGError SKGImportPluginCsv::importFile()
                                     }
                                 } else if (col == QStringLiteral("mode")) {
                                     if (val == QStringLiteral("1")) {
-                                        val = i18nc("An operation mode", "Transfer");
+                                        val = i18nc("An transaction mode", "Transfer");
                                     } else if (val == QStringLiteral("2")) {
-                                        val = i18nc("An operation mode", "Direct debit");
+                                        val = i18nc("An transaction mode", "Direct debit");
                                     } else if (val == QStringLiteral("3")) {
-                                        val = i18nc("An operation mode", "Check");
+                                        val = i18nc("An transaction mode", "Check");
                                     } else if (val == QStringLiteral("4")) {
-                                        val = i18nc("An operation mode", "Deposit");
+                                        val = i18nc("An transaction mode", "Deposit");
                                     } else if (val == QStringLiteral("5")) {
-                                        val = i18nc("An operation mode", "Payback");
+                                        val = i18nc("An transaction mode", "Payback");
                                     } else if (val == QStringLiteral("6")) {
-                                        val = i18nc("An operation mode", "Withdrawal");
+                                        val = i18nc("An transaction mode", "Withdrawal");
                                     } else if (val == QStringLiteral("7")) {
-                                        val = i18nc("An operation mode", "Card");
+                                        val = i18nc("An transaction mode", "Card");
                                     } else if (val == QStringLiteral("8")) {
-                                        val = i18nc("An operation mode", "Loan payment");
+                                        val = i18nc("An transaction mode", "Loan payment");
                                     } else if (val == QStringLiteral("9")) {
-                                        val = i18nc("An operation mode", "Subscription");
+                                        val = i18nc("An transaction mode", "Subscription");
                                     } else if (val == QStringLiteral("0")) {
                                         val = QString();
                                     } else if (val == QStringLiteral("10")) {
-                                        val = i18nc("An operation mode", "Cash deposit");
+                                        val = i18nc("An transaction mode", "Cash deposit");
                                     } else if (val == QStringLiteral("11")) {
-                                        val = i18nc("An operation mode", "Card summary");
+                                        val = i18nc("An transaction mode", "Card summary");
                                     } else if (val == QStringLiteral("12")) {
-                                        val = i18nc("An operation mode", "Deferred card");
+                                        val = i18nc("An transaction mode", "Deferred card");
                                     }
                                     err = currentOperation.setMode(val);
                                 } else if (col == QStringLiteral("payee")) {
@@ -553,7 +553,7 @@ SKGError SKGImportPluginCsv::importFile()
                                     err = currentOperation.setComment(comment);
                                     IFOKDO(err, currentSubOperation.setComment(comment))
                                 } else if (col == QStringLiteral("status")) {
-                                    err = currentOperation.setStatus(val == QStringLiteral("C") || val == QStringLiteral("Y") ?  SKGOperationObject::CHECKED : val == QStringLiteral("P") ?  SKGOperationObject::POINTED : SKGOperationObject::NONE);
+                                    err = currentOperation.setStatus(val == QStringLiteral("C") || val == QStringLiteral("Y") ?  SKGOperationObject::CHECKED : val == QStringLiteral("P") ?  SKGOperationObject::MARKED : SKGOperationObject::NONE);
                                 } else if (col == QStringLiteral("bookmarked")) {
                                     err = currentOperation.bookmark(val == QStringLiteral("Y"));
                                 } else if (col == QStringLiteral("idgroup")) {
@@ -743,7 +743,7 @@ SKGError SKGImportPluginCsv::importFile()
                                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", defAccount.getName()), SKGDocument::Warning))
 
                             } else {
-                                m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", defAccount.getName()));
+                                m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some transactions are already existing", defAccount.getName()));
                             }
                         }
                     }
@@ -796,7 +796,7 @@ SKGError SKGImportPluginCsv::exportFile()
     if (wc.isEmpty()) {
         wc = QStringLiteral("1=1");
     }  else {
-        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and operations have been exported")))
+        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and transactions have been exported")))
     }
 
     // Open file
