@@ -251,12 +251,12 @@ SKGError SKGImportPluginGnc::importFile()
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
-                    // Step 3- Get operations
+                    // Step 3- Get transactions
                     QMap<QString, SKGOperationObject> mapIdScheduledOperation;
                     {
                         QDomNodeList operationsList = book.elementsByTagName(QStringLiteral("gnc:transaction"));
                         int nbOperations = operationsList.count();
-                        IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nbOperations))
+                        IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nbOperations))
                         QVector<SubOpInfo> suboperationsList;
                         for (int i = 0; !err && i < nbOperations; ++i) {
                             QDomElement operation = operationsList.at(i).toElement();
@@ -341,7 +341,7 @@ SKGError SKGImportPluginGnc::importFile()
                                             QDomElement value = slot.firstChildElement(QStringLiteral("slot:value"));
                                             if (!key.isNull() && !value.isNull()) {
                                                 if (key.text() == QStringLiteral("sched-xaction")) {
-                                                    // This is a scheduled operation
+                                                    // This is a scheduled transaction
                                                     QDomNodeList scheduledSlotList = value.elementsByTagName(QStringLiteral("slot"));
                                                     int nbscheduledSlotList = scheduledSlotList.count();
                                                     for (int k2 = 0; !err && k2 < nbscheduledSlotList; ++k2) {
@@ -397,10 +397,10 @@ SKGError SKGImportPluginGnc::importFile()
                                 QDomElement suboperationMemo = suboperation.firstChildElement(QStringLiteral("split:memo"));
                                 QDomElement suboperationAction = suboperation.firstChildElement(QStringLiteral("split:action"));
 
-                                // Set operation attribute
+                                // Set transaction attribute
                                 if (!suboperationReconciled.isNull() && operationObj.getStatus() == SKGOperationObject::NONE) {
                                     QString val = suboperationReconciled.text();
-                                    IFOKDO(err, operationObj.setStatus(val == QStringLiteral("c") ? SKGOperationObject::POINTED : val == QStringLiteral("y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
+                                    IFOKDO(err, operationObj.setStatus(val == QStringLiteral("c") ? SKGOperationObject::MARKED : val == QStringLiteral("y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
                                 }
                                 if (!err && !suboperationMemo.isNull() && operationObj.getComment().isEmpty()) {
                                     err = operationObj.setComment(suboperationMemo.text());
@@ -459,7 +459,7 @@ SKGError SKGImportPluginGnc::importFile()
                                         IFOKDO(err, operationObj2.setPayee(payeeObject))
                                         IFOK(err) {
                                             QString val = suboperationReconciled.text();
-                                            err = operationObj2.setStatus(val == QStringLiteral("c") ? SKGOperationObject::POINTED : val == QStringLiteral("y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
+                                            err = operationObj2.setStatus(val == QStringLiteral("c") ? SKGOperationObject::MARKED : val == QStringLiteral("y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
                                         }
                                         IFOKDO(err, operationObj2.setImported(true))
                                         IFOKDO(err, operationObj2.setImportID(operationObj.getImportID()))
@@ -471,7 +471,7 @@ SKGError SKGImportPluginGnc::importFile()
                                         IFOKDO(err, operationObj2.setGroupOperation(operationObj))
                                         IFOKDO(err, operationObj2.save())
 
-                                        // Create sub operation on operationObj2
+                                        // Create sub transaction on operationObj2
                                         SKGSubOperationObject suboperationObj2;
                                         IFOKDO(err, operationObj2.addSubOperation(suboperationObj2))
                                         IFOK(err) {
@@ -494,7 +494,7 @@ SKGError SKGImportPluginGnc::importFile()
                                         // Compute quantity
                                         quantity = suboperationInfo.value;
 
-                                        // Create sub operation on operationObj
+                                        // Create sub transaction on operationObj
                                         quantity -= SKGServices::stringToDouble(operationObj.getAttribute(QStringLiteral("f_QUANTITY")));
                                         if (fabs(quantity) > 10e-9) {
                                             IFOKDO(err, operationObj.addSubOperation(suboperationObj))
@@ -526,7 +526,7 @@ SKGError SKGImportPluginGnc::importFile()
                         // Create scheduled
                         QDomNodeList scheduleList = book.elementsByTagName(QStringLiteral("gnc:schedxaction"));
                         int nbSchedule = scheduleList.count();
-                        IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nbSchedule))
+                        IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled transactions"), nbSchedule))
                         for (int i = 0; !err && i < nbSchedule; ++i) {
                             QDomElement schedule = scheduleList.at(i).toElement();
                             QDomElement scheduleAutoCreate = schedule.firstChildElement(QStringLiteral("sx:autoCreate"));
