@@ -294,12 +294,12 @@ SKGError SKGImportPluginGsb::importFile()
             IFOK(err) {
                 QDomNodeList transactionList = docElem.elementsByTagName(QStringLiteral("Transaction"));
                 int nb = transactionList.count();
-                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     // Get account object
                     QDomElement transaction = transactionList.at(i).toElement();
 
-                    // Creation of the operation
+                    // Creation of the transaction
                     SKGOperationObject opObj;
                     QString parentOpId = getAttribute(transaction,  QStringLiteral("Mo"));
                     if (parentOpId == QStringLiteral("0")) {
@@ -368,12 +368,12 @@ SKGError SKGImportPluginGsb::importFile()
             IFOK(err) {
                 QDomNodeList scheduledList = docElem.elementsByTagName(QStringLiteral("Scheduled"));
                 int nb = scheduledList.count();
-                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nb);
+                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled transactions"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     // Get account object
                     QDomElement transaction = scheduledList.at(i).toElement();
 
-                    // Creation of the operation
+                    // Creation of the transaction
                     SKGAccountObject account = mapIdAccount[getAttribute(transaction,  QStringLiteral("Ac"))];
                     SKGOperationObject opObj;
                     IFOKDO(err, account.addOperation(opObj, true))
@@ -414,7 +414,7 @@ SKGError SKGImportPluginGsb::importFile()
                             IFOKDO(err, subObj2.save())
                         }
 
-                        // Group operations
+                        // Group transactions
                         IFOKDO(err, opObj.setGroupOperation(opObj2))
                         IFOKDO(err, opObj.save())
                     }
