@@ -24,7 +24,7 @@
 #include "skgtraces.h"
 
 /**
- * Operations treated.
+ * Transactions treated.
  */
 QSet<QString> SKGImportPluginKmy::m_opTreated;
 
@@ -211,10 +211,10 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
     SKGTRACEINRC(10, "SKGImportPluginKmy::importFile-TRANSACTION", err)
     QDomNodeList transactionList = docElem.elementsByTagName(QStringLiteral("TRANSACTION"));
     int nb = transactionList.count();
-    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
     QVector<QDomNode> suboperationsList;
     for (int i = 0; !err && i < nb; ++i) {
-        // Get operation object
+        // Get transaction object
         QDomElement operation = transactionList.at(i).toElement();
 
         SKGOperationObject operationObj;
@@ -327,7 +327,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
         for (int j = 0; !err && j < nbSuboperations; ++j) {
             QDomElement suboperation = suboperationsList.at(j).toElement();
 
-            // Set operation attributes
+            // Set transaction attributes
             IFOKDO(err, operationObj.setPayee(mapIdPayee[suboperation.attribute(QStringLiteral("payee"))]))
             if (!err && operationObj.getComment().isEmpty()) {
                 err = operationObj.setComment(suboperation.attribute(QStringLiteral("memo")));
@@ -337,7 +337,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
             // Set state
             if (operationObj.getStatus() == SKGOperationObject::NONE) {
                 QString val = suboperation.attribute(QStringLiteral("reconcileflag"));
-                IFOKDO(err, operationObj.setStatus(val == QStringLiteral("1") ? SKGOperationObject::POINTED : val == QStringLiteral("2") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
+                IFOKDO(err, operationObj.setStatus(val == QStringLiteral("1") ? SKGOperationObject::MARKED : val == QStringLiteral("2") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
             }
             IFOKDO(err, operationObj.save())
 
@@ -395,7 +395,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                             IFOKDO(err, operationObj2.setPayee(payeeObject))
                             IFOK(err) {
                                 QString val = suboperation.attribute(QStringLiteral("reconcileflag"));
-                                err = operationObj2.setStatus(val == QStringLiteral("1") ? SKGOperationObject::POINTED : val == QStringLiteral("2") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
+                                err = operationObj2.setStatus(val == QStringLiteral("1") ? SKGOperationObject::MARKED : val == QStringLiteral("2") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
                             }
                             IFOKDO(err, operationObj2.setImported(true))
                             IFOKDO(err, operationObj2.setImportID(operationObj.getImportID()))
@@ -411,7 +411,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                             IFOKDO(err, operationObj2.setGroupOperation(operationObj))
                             IFOKDO(err, operationObj2.save())
 
-                            // Create sub operation on operationObj2
+                            // Create sub transaction on operationObj2
                             SKGSubOperationObject suboperationObj2;
                             IFOKDO(err, operationObj2.addSubOperation(suboperationObj2))
                             IFOK(err) {
@@ -432,7 +432,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                             // Compute quantity
                             quantity = toKmyValue(suboperation.attribute(QStringLiteral("shares")));
 
-                            // Create sub operation on operationObj
+                            // Create sub transaction on operationObj
                             quantity -= SKGServices::stringToDouble(operationObj.getAttribute(QStringLiteral("f_QUANTITY")));
                             if (quantity != 0 || nbSuboperations == 1) {
                                 IFOKDO(err, operationObj.addSubOperation(suboperationObj))
@@ -728,7 +728,7 @@ SKGError SKGImportPluginKmy::importFile()
             IFOKDO(err, importPayees(mapIdPayee, docElem))
             IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
-            // Step 6-Create operations
+            // Step 6-Create transactions
             IFOKDO(err, importTransactions(docElem, kmymoneyTemporaryAccount, mapIdPayee))
             IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
@@ -1036,7 +1036,7 @@ SKGError SKGImportPluginKmy::exportSchedules(QDomDocument& doc, QDomElement& roo
     int nb = objects.count();
     schedules.setAttribute(QStringLiteral("count"), SKGServices::intToString(nb));
     IFOK(err) {
-        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export scheduled operations"), nb);
+        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export scheduled transactions"), nb);
         for (int i = 0; !err && i < nb; ++i) {
             SKGRecurrentOperationObject obj(objects.at(i));
             SKGOperationObject op;
@@ -1118,7 +1118,7 @@ SKGError SKGImportPluginKmy::exportTransactions(QDomDocument& doc, QDomElement&
     int nb = objects.count();
     transactions.setAttribute(QStringLiteral("count"), SKGServices::intToString(nb));
     IFOK(err) {
-        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export operations"), nb);
+        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export transactions"), nb);
         for (int i = 0; !err && i < nb; ++i) {
             SKGOperationObject op(objects.at(i));
             err = exportOperation(op, doc, transactions);
@@ -1596,7 +1596,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
         transaction.setAttribute(QStringLiteral("memo"), iOperation.getComment());
         transaction.setAttribute(QStringLiteral("commodity"), SKGUnitObject::getInternationalCode(unit.getName()));
 
-        QString reconcileflag = (iOperation.getStatus() == SKGOperationObject::POINTED ? QStringLiteral("1") : (iOperation.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("2") : QStringLiteral("0")));
+        QString reconcileflag = (iOperation.getStatus() == SKGOperationObject::MARKED ? QStringLiteral("1") : (iOperation.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("2") : QStringLiteral("0")));
 
         SKGAccountObject act;
         IFOKDO(err, iOperation.getParentAccount(act))
@@ -1634,7 +1634,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
         SKGOperationObject obj2;
         if (!err && iOperation.isTransfer(obj2)) {
             // It is a Transfer
-            QString reconcileflag2 = (obj2.getStatus() == SKGOperationObject::POINTED ? QStringLiteral("1") : (obj2.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("2") : QStringLiteral("0")));
+            QString reconcileflag2 = (obj2.getStatus() == SKGOperationObject::MARKED ? QStringLiteral("1") : (obj2.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("2") : QStringLiteral("0")));
 
             SKGAccountObject act2;
             IFOKDO(err, obj2.getParentAccount(act2))
