@@ -74,7 +74,7 @@ SKGError SKGImportPluginLedger::exportFile()
         if (wc.isEmpty()) {
             wc = QStringLiteral("1=1");
         }  else {
-            IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and operations have been exported")))
+            IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and transactions have been exported")))
         }
 
         QLocale en(QLocale::C);
@@ -110,13 +110,13 @@ SKGError SKGImportPluginLedger::exportFile()
         IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
         IFOK(err) {
-            SKGObjectBase::SKGListSKGObjectBase operations;
-            err = m_importer->getDocument()->getObjects(QStringLiteral("v_operation"), wc % QStringLiteral(" AND t_template='N' ORDER BY d_date"), operations);
-            int nb = operations.count();
+            SKGObjectBase::SKGListSKGObjectBase transactions;
+            err = m_importer->getDocument()->getObjects(QStringLiteral("v_operation"), wc % QStringLiteral(" AND t_template='N' ORDER BY d_date"), transactions);
+            int nb = transactions.count();
             IFOK(err) {
-                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export operations"), nb);
+                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export transactions"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGOperationObject op(operations.at(i));
+                    SKGOperationObject op(transactions.at(i));
                     auto status = op.getStatus();
                     auto number = op.getNumber();
 
@@ -148,7 +148,7 @@ SKGError SKGImportPluginLedger::exportFile()
                     }
 
                     stream << SKGServices::dateToSqlString(op.getDate()).replace('-', '/')
-                           << (status == SKGOperationObject::CHECKED ? " *" : status == SKGOperationObject::POINTED ? " !" : "")
+                           << (status == SKGOperationObject::CHECKED ? " *" : status == SKGOperationObject::MARKED ? " !" : "")
                            << (!number.isEmpty() ? QStringLiteral(" (") % number % ")" : QString())
                            << QStringLiteral(" ") << payeeString
                            << SKGENDL;
@@ -162,11 +162,11 @@ SKGError SKGImportPluginLedger::exportFile()
                            << "  " << qs
                            << SKGENDL;
 
-                    SKGObjectBase::SKGListSKGObjectBase suboperations;
-                    IFOKDO(err, op.getSubOperations(suboperations))
-                    int nbsuboperations = suboperations.count();
+                    SKGObjectBase::SKGListSKGObjectBase subtransactions;
+                    IFOKDO(err, op.getSubOperations(subtransactions))
+                    int nbsuboperations = subtransactions.count();
                     for (int j = 0; !err && j < nbsuboperations; ++j) {
-                        SKGSubOperationObject sop(suboperations.at(j));
+                        SKGSubOperationObject sop(subtransactions.at(j));
                         SKGCategoryObject cat;
                         sop.getCategory(cat);
                         auto catString = cat.getFullName().replace(OBJECTSEPARATOR, QLatin1String(":"));
@@ -312,7 +312,7 @@ SKGError SKGImportPluginLedger::importFile()
                 IFOK(err) {
                     auto transactionL = docElem.elementsByTagName(QStringLiteral("transaction"));
                     int nb = transactionL.count();
-                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         // Get account object
                         auto transaction = transactionL.at(i).toElement();
@@ -322,7 +322,7 @@ SKGError SKGImportPluginLedger::importFile()
                         auto note = transaction.firstChildElement(QStringLiteral("note")).toElement().text().trimmed();
                         auto status = getAttribute(transaction, QStringLiteral("state"));
 
-                        // Create operation and suboperation
+                        // Create transaction and suboperation
                         SKGOperationObject opObj;
                         SKGSubOperationObject subObj;
                         auto postingL = transaction.elementsByTagName(QStringLiteral("posting"));
@@ -366,10 +366,10 @@ SKGError SKGImportPluginLedger::importFile()
                             auto isaccount = isAccount(type);
                             if (i2 > 0) {
                                 if (isaccount) {
-                                    // Save the suboperation
+                                    // Save the subtransaction
                                     IFOKDO(err, subObj.save())
                                 } else {
-                                    // Forget the suboperation
+                                    // Forget the subtransaction
                                     IFOKDO(err, opObj.load())
                                 }
                             }
@@ -394,7 +394,7 @@ SKGError SKGImportPluginLedger::importFile()
                                     accountObj = mapIdAccount[account_id];
                                 }
 
-                                // Creation of the operation
+                                // Creation of the transaction
                                 IFOKDO(err, accountObj.addOperation(opObj, true))
                                 IFOKDO(err, opObj.setDate(QDate::fromString(date, QStringLiteral("yyyy/MM/dd"))))
 
@@ -414,7 +414,7 @@ SKGError SKGImportPluginLedger::importFile()
                                 IFOKDO(err, opObj.setImported(true))
                                 IFOKDO(err, opObj.setImportID(QStringLiteral("LEDGER-")))
                                 IFOKDO(err, opObj.setStatus(status == QStringLiteral("cleared") ? SKGOperationObject::CHECKED :
-                                                            status == QStringLiteral("pending") ? SKGOperationObject::POINTED : SKGOperationObject::NONE))
+                                                            status == QStringLiteral("pending") ? SKGOperationObject::MARKED : SKGOperationObject::NONE))
                                 IFOKDO(err, opObj.save())
 
                                 if (opPreviousObj.getID()) {
@@ -425,7 +425,7 @@ SKGError SKGImportPluginLedger::importFile()
                                 }
                             }
 
-                            // Creation of the suboperation
+                            // Creation of the subtransaction
                             IFOKDO(err, opObj.addSubOperation(subObj))
                             if (!isaccount) {
                                 SKGCategoryObject catObj;
