@@ -221,7 +221,7 @@ SKGError SKGImportPluginMmb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
-            // Step 6 - operations
+            // Step 6 - transactions
             QMap<QString, SKGOperationObject> mapOperation;
             IFOK(err) {
                 SKGStringListList listOperations;
@@ -230,7 +230,7 @@ SKGError SKGImportPluginMmb::importFile()
                         "SELECT BDID,    ACCOUNTID, TOACCOUNTID, PAYEEID, TRANSCODE, TRANSAMOUNT, STATUS, TRANSACTIONNUMBER, NOTES, CATEGID, SUBCATEGID, TRANSDATE, FOLLOWUPID, TOTRANSAMOUNT, REPEATS, NEXTOCCURRENCEDATE, NUMOCCURRENCES FROM BILLSDEPOSITS_V1)"), listOperations);
                 IFOK(err) {
                     int nb = listOperations.count() - 1;
-                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         const QStringList& attributes = listOperations.at(i + 1);
                         if (attributes.at(6) != QStringLiteral("V")) {  // Void
