@@ -89,7 +89,7 @@ SKGError SKGImportPluginMT940::importFile()
                 QString bankName = QStringLiteral("MT940");
 
                 int nb = lines.count();
-                IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
+                IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb))
                 for (int i = 0; i < nb && !err; ++i) {
                     // Read line
                     const QString& line = lines.at(i);
@@ -151,7 +151,7 @@ SKGError SKGImportPluginMT940::importFile()
                                 err = SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), val.mid(7, 3), unit);
                                 // Example C040802EUR16,40
                                 if (account.getNbOperation() > 1) {
-                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", account.getName()), SKGDocument::Warning))
+                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some transactions are already existing", account.getName()), SKGDocument::Warning))
                                 } else {
                                     // Set initial balance
                                     IFOKDO(err, account.setInitialBalance((val[0] == 'C' ? 1.0 : -1.0) * SKGServices::stringToDouble(val.right(val.count() - 10)), unit))
