@@ -195,7 +195,7 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void*
         if (!SKGImportPluginOfx::m_ofxError) {
             impotExporter->addAccountToCheck(act, data.ledger_balance);
             if (act.getNbOperation() > 1) {
-                SKGImportPluginOfx::m_ofxError = doc->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", act.getName()));
+                SKGImportPluginOfx::m_ofxError = doc->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some transactions are already existing", act.getName()));
             } else {
                 auto d = QDate::currentDate();
                 if (static_cast<bool>(data.ledger_balance_date_valid)) {
@@ -390,7 +390,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
     SKGAccountObject account;
     SKGImportPluginOfx::m_ofxError = getAccount(data.account_ptr, doc, account);
     if (!SKGImportPluginOfx::m_ofxError) {
-        // Get operation date
+        // Get transaction date
         QDateTime date_time;
         date_time.setSecsSinceEpoch(static_cast<bool>(data.date_initiated_valid) ? data.date_initiated : data.date_posted);
         QDate date = date_time.date();
@@ -478,19 +478,19 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
             } else if (data.transactiontype == OFX_POS) {
                 mode = i18nc("Noun, type of OFX transaction", "Point of sale");
             } else if (data.transactiontype == OFX_XFER) {
-                mode = i18nc("An operation mode", "Transfer");
+                mode = i18nc("An transaction mode", "Transfer");
             } else if (data.transactiontype == OFX_CHECK) {
-                mode = i18nc("An operation mode", "Check");
+                mode = i18nc("An transaction mode", "Check");
             } else if (data.transactiontype == OFX_PAYMENT) {
                 mode = i18nc("Noun, type of OFX transaction", "Electronic payment");
             } else if (data.transactiontype == OFX_CASH) {
-                mode = i18nc("An operation mode", "Withdrawal");
+                mode = i18nc("An transaction mode", "Withdrawal");
             } else if (data.transactiontype == OFX_DIRECTDEP) {
                 mode = i18nc("Noun, type of OFX transaction", "Deposit");
             } else if (data.transactiontype == OFX_REPEATPMT) {
                 mode = i18nc("Noun, type of OFX transaction", "Repeating payment");
             } else if (data.transactiontype == OFX_DIRECTDEBIT) {
-                mode = i18nc("An operation mode", "Direct debit");
+                mode = i18nc("An transaction mode", "Direct debit");
             }
 
             SKGImportPluginOfx::m_ofxError = ope.setMode(mode);
