@@ -164,7 +164,7 @@ SKGError SKGImportPluginQif::importFile()
                 bool openingbalancecreated = false;
 
                 int nb = lines.size();
-                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     QString line = lines.at(i);
                     QString val;
@@ -305,7 +305,7 @@ SKGError SKGImportPluginQif::importFile()
                             }
                         }
                     } else if (inSection == 'B') {
-                        // Operation creation
+                        // Transaction creation
                         /*
                         >>>> Items for Non-Investment Accounts <<<<
                         DONE    D      Date
@@ -352,7 +352,7 @@ SKGError SKGImportPluginQif::importFile()
                             banks appear to be using a completely undifferentiated numeric QString
                             formateed YYYYMMDD in downloaded QIF files.
                             */
-                            // Operation creation
+                            // Transaction creation
                             SKGUnitObject unit;
                             IFOK(err) {
                                 if (account != nullptr) {
@@ -428,7 +428,7 @@ SKGError SKGImportPluginQif::importFile()
 
                             SKGSubOperationObject subcommission;
                             if (!payement.exist()) {
-                                // We have to create a new operation
+                                // We have to create a new transaction
                                 if (account != nullptr) {
                                     err = account->addOperation(payement, true);
                                 } else {
@@ -561,7 +561,7 @@ SKGError SKGImportPluginQif::importFile()
                             if (!val.isEmpty()) {
                                 double previousQuantity = currentSubOperation.getQuantity();
                                 if (previousQuantity != 0.0) {
-                                    // We have to create a new operation
+                                    // We have to create a new transaction
                                     if (account != nullptr) {
                                         err = account->addOperation(payement, true);
                                     } else {
@@ -676,7 +676,7 @@ SKGError SKGImportPluginQif::importFile()
                                                     // Oups, the real account is existing and it is another one
                                                     err = newAccount.load();
 
-                                                    // We move the operation in the right account
+                                                    // We move the transaction in the right account
                                                     IFOKDO(err, currentOperation.setParentAccount(newAccount))
                                                     IFOKDO(err, currentOperation.save())
 
@@ -735,7 +735,7 @@ SKGError SKGImportPluginQif::importFile()
                         } else if (op == 'C') {
                             // C     Cleared status
                             // Set status
-                            err = currentOperation.setStatus((val == QStringLiteral("C") || val == QStringLiteral("*") ? SKGOperationObject::POINTED : (val == QStringLiteral("R") || val == QStringLiteral("X") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE)));
+                            err = currentOperation.setStatus((val == QStringLiteral("C") || val == QStringLiteral("*") ? SKGOperationObject::MARKED : (val == QStringLiteral("R") || val == QStringLiteral("X") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE)));
                         } else if (op == '^') {
                             // ^     End of entry
                             // save
@@ -769,7 +769,7 @@ SKGError SKGImportPluginQif::importFile()
                                     bool merged = false;
                                     double tq = transferQuantity.at(j);
                                     const QString& ta = transferAccount.at(j);
-                                    // Is the transfert operation already existing?
+                                    // Is the transfert transaction already existing?
                                     double qua = tq == 0.0 && addNextAmountToTransferQuantity ? SKGServices::stringToDouble(opOrigin.getAttribute(QStringLiteral("f_QUANTITY"))) : tq;
                                     QString wc = "t_ACCOUNT='" % SKGServices::stringToSqlString(ta) %
                                                  "' AND t_TOACCOUNT='" % SKGServices::stringToSqlString(accountOrigin.getName()) %
@@ -782,7 +782,7 @@ SKGError SKGImportPluginQif::importFile()
                                         // We have to merge them and we do not need to create the transfer
                                         SKGOperationObject firstOne(obs.at(0));
 
-                                        // Remove all operation attached to this transfer
+                                        // Remove all transaction attached to this transfer
                                         SKGObjectBase::SKGListSKGObjectBase list;
                                         IFOKDO(err, firstOne.getGroupedOperations(list))
                                         for (const auto& o : qAsConst(list)) {
@@ -799,7 +799,7 @@ SKGError SKGImportPluginQif::importFile()
 
                                         merged = true;
                                     } else {
-                                        // Is the operation already created as a transfer of an other one?
+                                        // Is the transaction already created as a transfer of an other one?
                                         QString wc = "t_import_id='QIF TRANSFER-" % SKGServices::stringToSqlString(ta) % "' AND t_ACCOUNT='" % SKGServices::stringToSqlString(accountOrigin.getName()) %
                                                      "' AND (ABS(f_CURRENTAMOUNT-(" % SKGServices::doubleToString(opOrigin.getCurrentAmount()) % "))<0.0001 OR f_QUANTITY=" % SKGServices::doubleToString(qua) % ")"
                                                      " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "'))<1"
@@ -877,10 +877,10 @@ SKGError SKGImportPluginQif::importFile()
                                 SKGSubOperationObject suboprepair;
                                 IFOKDO(err, currentOperation.addSubOperation(suboprepair))
                                 IFOKDO(err, suboprepair.setQuantity(checkOperationAmount - checkSuboperationsAmount))
-                                IFOKDO(err, suboprepair.setComment(i18nc("An information message",  "Auto repaired operation")))
+                                IFOKDO(err, suboprepair.setComment(i18nc("An information message",  "Auto repaired transaction")))
                                 IFOKDO(err, suboprepair.save())
 
-                                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "The total amount of the operation (%1) was different to the sum of the sub-operations (%2). The operation has been repaired.", checkOperationAmountString, checkSuboperationsAmountString), SKGDocument::Warning))
+                                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "The total amount of the transaction (%1) was different to the sum of the sub-transactions (%2). The transaction has been repaired.", checkOperationAmountString, checkSuboperationsAmountString), SKGDocument::Warning))
                             }
 
                             // Initialize variables
@@ -951,7 +951,7 @@ SKGError SKGImportPluginQif::exportFile()
     }
 
     if ((listAccountsToExport.count() != 0) || (listOperationsToExport.count() != 0)) {
-        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and operations have been exported")))
+        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and transactions have been exported")))
     }
 
     // Open file
@@ -994,15 +994,15 @@ SKGError SKGImportPluginQif::exportFile()
 
             SKGServices::SKGUnitInfo primaryUnit = m_importer->getDocument()->getPrimaryUnit();
 
-            // Get operations
+            // Get transactions
             QString currentAccountName;
-            SKGObjectBase::SKGListSKGObjectBase operations;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display_all"), QStringLiteral("t_template='N' ORDER BY t_ACCOUNT, d_date, id"), operations))
-            int nb = operations.count();
+            SKGObjectBase::SKGListSKGObjectBase transactions;
+            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display_all"), QStringLiteral("t_template='N' ORDER BY t_ACCOUNT, d_date, id"), transactions))
+            int nb = transactions.count();
             IFOK(err) {
-                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export operations"), nb);
+                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export transactions"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGOperationObject operation(operations.at(i));
+                    SKGOperationObject operation(transactions.at(i));
                     SKGAccountObject a;
                     operation.getParentAccount(a);
                     if ((listOperationsToExport.isEmpty() || listOperationsToExport.contains(operation.getUniqueID())) &&
@@ -1128,16 +1128,16 @@ SKGError SKGImportPluginQif::exportFile()
                         }
 
                         SKGOperationObject::OperationStatus status = operation.getStatus();
-                        stream << 'C' << (status == SKGOperationObject::POINTED ? "C" : (status == SKGOperationObject::CHECKED ? "R" : "")) << SKGENDL;
+                        stream << 'C' << (status == SKGOperationObject::MARKED ? "C" : (status == SKGOperationObject::CHECKED ? "R" : "")) << SKGENDL;
 
-                        // Get sub operations
-                        SKGObjectBase::SKGListSKGObjectBase suboperations;
-                        err = operation.getSubOperations(suboperations);
+                        // Get sub transactions
+                        SKGObjectBase::SKGListSKGObjectBase subtransactions;
+                        err = operation.getSubOperations(subtransactions);
                         IFOK(err) {
-                            int nbSubOps = suboperations.size();
+                            int nbSubOps = subtransactions.size();
                             QString category;
                             if (nbSubOps == 1) {
-                                SKGSubOperationObject suboperation(suboperations.at(0));
+                                SKGSubOperationObject suboperation(subtransactions.at(0));
                                 // Dump quantity
                                 if (unitExported) {
                                     stream << 'Q' << SKGServices::doubleToString(qAbs(suboperation.getQuantity())) << SKGENDL;
@@ -1168,7 +1168,7 @@ SKGError SKGImportPluginQif::exportFile()
                             if (nbSubOps > 1) {
                                 // Split operation
                                 for (int k = 0; k < nbSubOps; ++k) {
-                                    SKGSubOperationObject suboperation(suboperations.at(k));
+                                    SKGSubOperationObject suboperation(subtransactions.at(k));
                                     SKGCategoryObject cat;
                                     suboperation.getCategory(cat);
 
