@@ -17,9 +17,9 @@
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
 #include "skgobjectbase.h"
-#include "skgpayeeobject.h"
 #include "skgservices.h"
 #include "skgtraces.h"
+#include "skgtrackerobject.h"
 
 /**
  * This plugin factory.
@@ -223,11 +223,11 @@ SKGError SKGImportPluginXhb::importFile()
 
             // Step 4-Create transaction
             IFOK(err) {
-                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), 2);
+                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), 2);
                 for (int j = 1; !err && j <= 2; ++j) {
                     QDomNodeList transactionList = docElem.elementsByTagName(j == 1 ? QStringLiteral("ope") : QStringLiteral("fav"));
                     int nb = transactionList.count();
-                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         // Get account object
                         QDomElement transaction = transactionList.at(i).toElement();
@@ -257,7 +257,7 @@ SKGError SKGImportPluginXhb::importFile()
                             SKGPayeeObject payee = mapIdPayee[ getAttribute(transaction,  QStringLiteral("payee"))];
                             SKGCategoryObject category = mapIdCategory[getAttribute(transaction,  QStringLiteral("category"))];
 
-                            // Creation of the operation
+                            // Creation of the transaction
                             SKGOperationObject opObj;
                             IFOKDO(err, account.addOperation(opObj, true))
                             IFOKDO(err, opObj.setDate(date))
@@ -279,6 +279,14 @@ SKGError SKGImportPluginXhb::importFile()
                             IFOKDO(err, subObj.setQuantity(amount))
                             IFOKDO(err, subObj.save())
 
+                            QString tags = getAttribute(transaction,  QStringLiteral("tags"));
+                            if(!tags.isEmpty()) {
+                                SKGTrackerObject tracker;
+                                IFOKDO(err, SKGTrackerObject::createTracker(m_importer->getDocument(), tags, tracker))
+                                IFOKDO(err, subObj.setTracker(tracker))
+                                IFOKDO(err, subObj.save())
+                            }
+
                             // Transfer
                             /*if(dst_account != idAccount && dst_account != "0") {
                                 SKGAccountObject account = mapIdAccount[dst_account];
@@ -307,9 +315,9 @@ SKGError SKGImportPluginXhb::importFile()
                                 if(!err) err = op2Obj.save();
                             }*/
 
-                            // Scheduled operations
+                            // Scheduled transactions
                             if (j == 2) {
-                                // Creation of scheduled operation
+                                // Creation of scheduled transaction
                                 SKGRecurrentOperationObject recu;
                                 IFOKDO(err, opObj.addRecurrentOperation(recu))
                                 int limit = SKGServices::stringToInt(getAttribute(transaction,  QStringLiteral("limit")));
