@@ -79,7 +79,7 @@ SKGError SKGImportPluginXml::importFile()
                 query.setFocus(xml);
                 query.setQuery(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/ISO20022.xslt"))));
                 query.evaluateTo(&out);
-                //SKGTRACE << "OUT=" << out << Qt::endl;
+                SKGTRACEL(1) << "OUT=" << out << Qt::endl;
 
                 // Set the file without uncompression
                 QString errorMsg;
