@@ -39,7 +39,7 @@ void SKGAddOperation::reloadConfiguration()
     }
 
     QList<Plasma::RunnerSyntax> listofSyntaxes;
-    Plasma::RunnerSyntax syntax(QStringLiteral("%1:q:").arg(m_triggerWord), i18n("Add a new operation in skrooge"));
+    Plasma::RunnerSyntax syntax(QStringLiteral("%1:q:").arg(m_triggerWord), i18n("Add a new transaction in skrooge"));
     syntax.addExampleQuery(i18nc("Example of krunner command", "%1 10 computer", m_triggerWord));
     listofSyntaxes.append(syntax);
     setSyntaxes(listofSyntaxes);
@@ -54,7 +54,7 @@ void SKGAddOperation::match(Plasma::RunnerContext& iContext)
     query = query.remove(0, m_triggerWord.length());
 
     Plasma::QueryMatch m(this);
-    m.setText(i18n("Add operation %1", query));
+    m.setText(i18n("Add transaction %1", query));
     m.setData(query);
     m.setIcon(QIcon::fromTheme(QStringLiteral("skrooge")));
     m.setId(query);
@@ -87,7 +87,7 @@ void SKGAddOperation::run(const Plasma::RunnerContext& iContext, const Plasma::Q
         // Close file
         file.commit();
 
-        KMessageBox::information(nullptr, i18nc("Information message", "Operation created"));
+        KMessageBox::information(nullptr, i18nc("Information message", "Transaction created"));
     } else {
         KMessageBox::error(nullptr, i18nc("Error message: Could not create a file", "Creation of file %1 failed", fileName));
     }
