@@ -39,7 +39,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     });
     addAction(m_menuFavorite);
 
-    m_menuPastOperations = new QAction(i18nc("Noun, a type of account", "Only past operations"), this);
+    m_menuPastOperations = new QAction(i18nc("Noun, a type of account", "Only past transactions"), this);
     m_menuPastOperations->setCheckable(true);
     m_menuPastOperations->setChecked(false);
     connect(m_menuPastOperations, &QAction::triggered, this, [ = ]() {
@@ -246,7 +246,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
             IFOK(err) {
                 QString html;
                 if (!exist) {
-                    html = "<html><body>" % i18nc("Message, do not translate URL", "First, you have to create at least one account<br>from <a href=\"%1\">\"Bank and Account\"</a> page or <a href=\"%2\">import</a> operations.", "skg://Skrooge_bank_plugin", "skg://import_operation") % "</body></html>";
+                    html = "<html><body>" % i18nc("Message, do not translate URL", "First, you have to create at least one account<br>from <a href=\"%1\">\"Bank and Account\"</a> page or <a href=\"%2\">import</a> transactions.", "skg://Skrooge_bank_plugin", "skg://import_operation") % "</body></html>";
                 } else {
                     // Build where clause
                     QString wc;
