@@ -60,7 +60,7 @@ bool SKGBankPlugin::setupActions(SKGDocument* iDocument)
     setXMLFile(QStringLiteral("skrooge_bank.rc"));
 
     // Menu
-    auto actReconciliate = new QAction(SKGServices::fromTheme(QStringLiteral("window-duplicate")), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile..."), this);
+    auto actReconciliate = new QAction(SKGServices::fromTheme(QStringLiteral("window-duplicate")), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile…"), this);
     connect(actReconciliate, &QAction::triggered, this, &SKGBankPlugin::onReconciliate);
     actionCollection()->setDefaultShortcut(actReconciliate, Qt::ALT + Qt::Key_R);
     registerGlobalAction(QStringLiteral("edit_reconcile"), actReconciliate, QStringList() << QStringLiteral("account"), 1, -1, 320);
@@ -122,7 +122,7 @@ SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
 
         QStringList overlayopen;
         overlayopen.push_back(QStringLiteral("quickopen"));
-        auto open = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report..."), w);
+        auto open = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), w);
         connect(open, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
             SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
         });
@@ -186,9 +186,9 @@ QString SKGBankPlugin::toolTip() const
 QStringList SKGBankPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tip", "<p>... you can associate a logo with your <a href=\"skg://skrooge_bank_plugin\">banks</a>.</p>"));
-    output.push_back(i18nc("Description of a tip", "<p>... <a href=\"skg://skrooge_bank_plugin\">accounts</a> can be merged by drag & drop.</p>"));
-    output.push_back(i18nc("Description of a tip", "<p>... you can set a minimum and a maximum limit on your <a href=\"skg://skrooge_bank_plugin\">accounts</a>. This will trigger an alarm.</p>"));
+    output.push_back(i18nc("Description of a tip", "<p>… you can associate a logo with your <a href=\"skg://skrooge_bank_plugin\">banks</a>.</p>"));
+    output.push_back(i18nc("Description of a tip", "<p>… <a href=\"skg://skrooge_bank_plugin\">accounts</a> can be merged by drag & drop.</p>"));
+    output.push_back(i18nc("Description of a tip", "<p>… you can set a minimum and a maximum limit on your <a href=\"skg://skrooge_bank_plugin\">accounts</a>. This will trigger an alarm.</p>"));
     return output;
 }
 
@@ -206,7 +206,7 @@ bool SKGBankPlugin::isInPagesChooser() const
 void SKGBankPlugin::onReconciliate()
 {
     if ((m_currentBankDocument != nullptr) && (SKGMainPanel::getMainPanel() != nullptr)) {
-        // Open in operation plugin
+        // Open in transaction plugin
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         for (int i = 0; i < nb; ++i) {
@@ -270,7 +270,7 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
             }
             {
                 SKGAdvice::SKGAdviceAction a;
-                a.Title = i18nc("Action to create a fake operation to set the amount of the account to 0", "Create fake operation");
+                a.Title = i18nc("Action to create a fake transaction to set the amount of the account to 0", "Create fake transaction");
                 a.IconName = QStringLiteral("edit-delete");
                 a.IsRecommended = true;
                 autoCorrections.push_back(a);
@@ -332,13 +332,13 @@ SKGError SKGBankPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
             }
         } else if (iSolution == 1) {
             {
-                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create fake operation"), err)
+                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create fake transaction"), err)
 
                 SKGOperationObject op;
                 IFOKDO(err, accountObj.setClosed(false))
                 IFOKDO(err, accountObj.addOperation(op))
                 IFOKDO(err, op.setDate(QDate::currentDate()))
-                IFOKDO(err, op.setComment(i18nc("Noun, default comment for a fake operation", "Fake operation")))
+                IFOKDO(err, op.setComment(i18nc("Noun, default comment for a fake transaction", "fake transaction")))
                 SKGUnitObject unit;
                 IFOKDO(err, accountObj.getUnit(unit))
                 IFOKDO(err, op.setUnit(unit))
@@ -350,11 +350,11 @@ SKGError SKGBankPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                 IFOKDO(err, sop.save())
 
                 // Send message
-                IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user that something was added", "The operation '%1' has been added", op.getDisplayName()), SKGDocument::Hidden))
+                IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user that something was added", "The transaction '%1' has been added", op.getDisplayName()), SKGDocument::Hidden))
             }
 
             // status bar
-            IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Fake operation created.")))
+            IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Fake transaction created.")))
             else {
                 err.addError(ERR_FAIL, i18nc("Error message",  "Creation failed"));
             }
