@@ -186,7 +186,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
                 }
             }
         }
-        ui.kAccountCreatorIcon->addItem(SKGServices::fromTheme(QStringLiteral("document-open-folder")), i18nc("Other type of bank account", "Other..."));
+        ui.kAccountCreatorIcon->addItem(SKGServices::fromTheme(QStringLiteral("document-open-folder")), i18nc("Other type of bank account", "Other…"));
 
         file.close();
     }
@@ -368,7 +368,7 @@ void SKGBankPluginWidget::onRefreshGraph()
                     nbSelect = objs.count();
                     if (nbSelect != 0) {
                         wc = QStringLiteral("t_ACCOUNT IN (");
-                        title = i18nc("Noun, a list of items", "Operations of account ");
+                        title = i18nc("Noun, a list of items", "Transactions of account ");
                         for (int i = 0; i < nbSelect; ++i) {
                             if (i != 0) {
                                 wc += ',';
@@ -489,7 +489,8 @@ void SKGBankPluginWidget::onAddAccountClicked()
         QString accountName = ui.kAccountCreatorAccount->text();
         QString name = bankName % '-' % accountName;
         SKGAccountObject::AccountType accountType = static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
-        if (accountType == SKGAccountObject::WALLET) {
+        const bool wallet = (accountType == SKGAccountObject::WALLET);
+        if (wallet) {
             bankName = QLatin1String("");
         }
         {
@@ -497,10 +498,10 @@ void SKGBankPluginWidget::onAddAccountClicked()
 
             // Create bank object in case of missing
             SKGBankObject bankObj(getDocument());
-            IFOKDO(err, bankObj.setName(ui.kAccountCreatorBank->text()))
+            IFOKDO(err, bankObj.setName(bankName))
             IFOK(err) {
                 // Build icon name
-                QString icon = ui.kAccountCreatorIcon->currentText();
+                QString icon = wallet ? "" : ui.kAccountCreatorIcon->currentText();
                 if (!QFile(icon).exists() && !icon.isEmpty()) {
                     QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
                     if (!code.isEmpty()) {
@@ -594,7 +595,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                     err = accountObj1.merge(accountObj, true);
                 }
 
-                // Change selection for the rest of the operation
+                // Change selection for the rest of the transaction
                 selection.clear();
                 selection.push_back(accountObj1);
                 nb = 1;
@@ -603,7 +604,8 @@ void SKGBankPluginWidget::onModifyAccountClicked()
 
         QString bankName = ui.kAccountCreatorBank->text();
         SKGAccountObject::AccountType accountType = static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
-        if (accountType == SKGAccountObject::WALLET) {
+        const bool wallet = (accountType == SKGAccountObject::WALLET);
+        if (wallet) {
             bankName = QLatin1String("");
         }
 
@@ -695,7 +697,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             if (ui.kAccountCreatorIcon->text() != NOUPDATE) {
                 IFOK(err) {
                     // Build icon name
-                    QString icon = ui.kAccountCreatorIcon->currentText();
+                    QString icon = wallet ? "" : ui.kAccountCreatorIcon->currentText();
                     if (!QFile(icon).exists() && !icon.isEmpty()) {
                         QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
                         if (!code.isEmpty()) {
@@ -819,7 +821,7 @@ void SKGBankPluginWidget::refreshInfoZone()
     SKGTRACEINFUNC(10)
     auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc != nullptr) {
-        ui.kInfo->setText(i18nc("Message", "Computing..."));
+        ui.kInfo->setText(i18nc("Message", "Computing…"));
         doc->concurrentExecuteSelectSqliteOrder(QStringLiteral("SELECT TOTAL(f_TODAYAMOUNT), TOTAL(f_CURRENTAMOUNT), TOTAL(f_CHECKED), TOTAL(f_COMING_SOON) from v_account_display"), [ = ](const SKGStringListList & iResult) {
             if (iResult.count() == 2 && SKGMainPanel::getMainPanel()->pageIndex(this) != -1) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
