@@ -94,7 +94,7 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument)
     registerGlobalAction(QStringLiteral("clean_delete_unused_categories"), deleteUnusedCategoriesAction);
 
     // ------------
-    auto actTmp = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Open similar categories..."), this);
+    auto actTmp = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Open similar categories…"), this);
     actTmp->setData(QString("skg://skrooge_categories_plugin/?title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Similar categories")) %
                             "&whereClause=" % SKGServices::encodeForUrl(QStringLiteral("id IN (SELECT category.id FROM category, ("
                                     "SELECT * FROM category C WHERE EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>C.id AND upper(p2.t_fullname)=upper(C.t_fullname) AND p2.t_fullname<>C.t_fullname)) "
@@ -111,7 +111,7 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument)
     SELECT v_category_display.t_name, v_category_display.id, cat.level+1
     FROM v_category_display JOIN cat ON v_category_display.rd_category_id=cat.id
     ORDER BY 2
-    ) SELECT substr('..........',1,level*3) || t_fullname FROM cat;
+    ) SELECT substr('……….',1,level*3) || t_fullname FROM cat;
     */
     return true;
 }
@@ -287,8 +287,8 @@ QString SKGCategoriesPlugin::toolTip() const
 QStringList SKGCategoriesPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... <a href=\"skg://skrooge_categories_plugin\">categories</a> can be reorganized by drag & drop.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... if you delete a <a href=\"skg://skrooge_categories_plugin\">category</a>, all operations affected by this category will be associated to its parent category.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… <a href=\"skg://skrooge_categories_plugin\">categories</a> can be reorganized by drag & drop.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… if you delete a <a href=\"skg://skrooge_categories_plugin\">category</a>, all transactions affected by this category will be associated to its parent category.</p>"));
     return output;
 }
 
@@ -315,7 +315,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setUUID(QStringLiteral("skgcategoriesplugin_unused"));
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused categories"));
-            ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing categories that have no operations."));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing categories that have no transactions."));
             SKGAdvice::SKGAdviceActionList autoCorrections;
             {
                 SKGAdvice::SKGAdviceAction a;
@@ -328,7 +328,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    // Check operations not validated
+    // Check transactions not validated
     if (!iIgnoredAdvice.contains(QStringLiteral("skgmonthlyplugin_maincategoriesvariation"))) {
         QString month = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
         QDate datepreviousmonth = QDate::currentDate().addDays(-QDate::currentDate().day());
@@ -348,7 +348,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
-                a.Title = i18nc("Advice on making the best (action)", "Open sub operations with category containing '%1'", listCategories.at(i));
+                a.Title = i18nc("Advice on making the best (action)", "Open sub transactions with category containing '%1'", listCategories.at(i));
                 a.IconName = QStringLiteral("quickopen");
                 a.IsRecommended = false;
                 autoCorrections.push_back(a);
@@ -389,9 +389,9 @@ SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIden
         QString category = iAdviceIdentifier.right(iAdviceIdentifier.length() - 41);
         QString month = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
 
-        // Call operation plugin
+        // Call transaction plugin
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=" % icon() % "&operationTable=v_suboperation_consolidated&title=" %
-                                               SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations with category containing '%1'",  category)) % "&operationWhereClause=" % SKGServices::encodeForUrl("d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % '\''));
+                                               SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub transactions with category containing '%1'",  category)) % "&operationWhereClause=" % SKGServices::encodeForUrl("d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % '\''));
         return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
