@@ -77,7 +77,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
     QStringList overlay;
     overlay.push_back(QStringLiteral("skrooge"));
 
-    auto actImport = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlay), i18nc("Verb, action to import items from another format", "Import..."), this);
+    auto actImport = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlay), i18nc("Verb, action to import items from another format", "Import…"), this);
     actionCollection()->setDefaultShortcut(actImport, Qt::CTRL + Qt::META + Qt::Key_I);
     connect(actImport, &QAction::triggered, this, [ = ]() {
         this->importFiles();
@@ -98,7 +98,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
     // Import CSV Unit
     QStringList overlaycsv;
     overlaycsv.push_back(QStringLiteral("text-csv"));
-    auto actImportCsvUnit = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaycsv), i18nc("Verb, action to import", "Import currency values..."), this);
+    auto actImportCsvUnit = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaycsv), i18nc("Verb, action to import", "Import currency values…"), this);
     connect(actImportCsvUnit, &QAction::triggered, this, [ = ]() {
         this->importFiles(QList<QUrl>(), 2);
     });
@@ -106,7 +106,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
     registerGlobalAction(QStringLiteral("import_csv_unit"), actImportCsvUnit);
 
     // Import CSV Rule
-    auto actImportCsvRule = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaycsv), i18nc("Verb, action to import", "Import rules..."), this);
+    auto actImportCsvRule = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaycsv), i18nc("Verb, action to import", "Import rules…"), this);
     connect(actImportCsvRule, &QAction::triggered, this, [ = ]() {
         this->importFiles(QList<QUrl>(), 3);
     });
@@ -118,7 +118,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
     registerGlobalAction(QStringLiteral("export"), exports);
 
     // Export
-    auto actExportFile = new QAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Verb, action to export items to another format", "Export..."), this);
+    auto actExportFile = new QAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Verb, action to export items to another format", "Export…"), this);
     connect(actExportFile, &QAction::triggered, this, &SKGImportExportPlugin::exportFile);
     exports->addAction(actExportFile);
     actionCollection()->setDefaultShortcut(actExportFile, Qt::CTRL + Qt::META + Qt::Key_E);
@@ -152,20 +152,20 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
     // Processing banks
     QStringList overlayValidate;
     overlayValidate.push_back(QStringLiteral("dialog-ok"));
-    auto actSwithValidationImportedOperations = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlayValidate), i18nc("Verb, action to validate imported operations", "Switch validation of imported operations"), this);
+    auto actSwithValidationImportedOperations = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlayValidate), i18nc("Verb, action to validate imported transactions", "Switch validation of imported transactions"), this);
     connect(actSwithValidationImportedOperations, &QAction::triggered, this, &SKGImportExportPlugin::swithvalidationImportedOperations);
     actionCollection()->setDefaultShortcut(actSwithValidationImportedOperations, Qt::CTRL + Qt::SHIFT + Qt::Key_V);
     registerGlobalAction(QStringLiteral("switch_validation_imported_operation"), actSwithValidationImportedOperations, QStringList() << QStringLiteral("operation"), 1, -1, 318);
 
 
-    auto act = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlayValidate), i18nc("Verb, action to merge", "Validate operations that do not require further action"), this);
+    auto act = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlayValidate), i18nc("Verb, action to merge", "Validate transactions that do not require further action"), this);
     connect(act, &QAction::triggered, this, &SKGImportExportPlugin::validateAllOperations);
     registerGlobalAction(QStringLiteral("process_validate"), act, QStringList(), -2, -1);
 
     QStringList overlayopen;
     overlayopen.push_back(QStringLiteral("quickopen"));
-    auto actOpenNotValidated = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlayopen), i18nc("Verb, action to open", "Open imported operations not yet validated..."), this);
-    actOpenNotValidated->setData(QString("skg://skrooge_operation_plugin/?title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations imported and not yet validated")) %
+    auto actOpenNotValidated = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlayopen), i18nc("Verb, action to open", "Open imported transactions not yet validated…"), this);
+    actOpenNotValidated->setData(QString("skg://skrooge_operation_plugin/?title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Transactions imported and not yet validated")) %
                                          "&title_icon=" % SKGServices::encodeForUrl(icon()) %
                                          "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("t_imported='P'"))));
     connect(actOpenNotValidated, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
@@ -174,7 +174,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
     actionCollection()->setDefaultShortcut(actOpenNotValidated, Qt::META + Qt::Key_V);
     registerGlobalAction(QStringLiteral("view_open_not_validated"), actOpenNotValidated);
 
-    auto actMergeImportedOperation = new QAction(SKGServices::fromTheme(QStringLiteral("merge")), i18nc("Verb, action to merge", "Merge imported operations"), this);
+    auto actMergeImportedOperation = new QAction(SKGServices::fromTheme(QStringLiteral("merge")), i18nc("Verb, action to merge", "Merge imported transactions"), this);
     connect(actMergeImportedOperation, &QAction::triggered, this, &SKGImportExportPlugin::mergeImportedOperation);
     actionCollection()->setDefaultShortcut(actMergeImportedOperation, Qt::CTRL + Qt::ALT + Qt::Key_M);
     registerGlobalAction(QStringLiteral("merge_imported_operation"), actMergeImportedOperation, QStringList() << QStringLiteral("operation"), 1, -1, 319);
@@ -190,11 +190,11 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
         this->importFile(iFileName, true);
     }, Qt::QueuedConnection);
 
-    // Krunner operations
+    // Krunner transactions
     QString dirName = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) ;
     QStringList fileList = QDir(dirName).entryList(QStringList() << QStringLiteral("add_operation_*.txt"), QDir::Files);
     if (!fileList.isEmpty()) {
-        m_currentBankDocument->sendMessage(i18nc("Information message", "You have some krunner's operations to import"));
+        m_currentBankDocument->sendMessage(i18nc("Information message", "You have some krunner's transactions to import"));
     }
 
     return true;
@@ -344,16 +344,16 @@ QString SKGImportExportPlugin::toolTip() const
 QStringList SKGImportExportPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... skrooge is able to detect <a href=\"skg://tab_configure?page=Skrooge import and export plugin\">automatically</a> transfers after an import.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can automatically import operation with <a href=\"skg://tab_configure?page=Skrooge import and export plugin\">backend</a>.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can <a href=\"skg://import_operation\">import</a> many files in one shot.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... unit amounts can be imported through a CSV file.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can customize your CSV import with regular expressions defined in <a href=\"skg://tab_configure?page=Skrooge import and export plugin\">setting</a> panel.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can export the full content of your document into a XML file.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can export some accounts or operations just be selecting them before to launch the <a href=\"skg://export\">export_operation</a>.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can apply <a href=\"skg://skrooge_search_plugin\">automatic rules</a> after an import to set the right categories.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can convert file by using the batch tool '%1'.</p>", "skroogeconvert"));
-    output.push_back(i18nc("Description of a tips", "<p>... skrooge uses the name of the imported file to find the target account.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… skrooge is able to detect <a href=\"skg://tab_configure?page=Skrooge import and export plugin\">automatically</a> transfers after an import.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can automatically import transaction with <a href=\"skg://tab_configure?page=Skrooge import and export plugin\">backend</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can <a href=\"skg://import_operation\">import</a> many files in one shot.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… unit amounts can be imported through a CSV file.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can customize your CSV import with regular expressions defined in <a href=\"skg://tab_configure?page=Skrooge import and export plugin\">setting</a> panel.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can export the full content of your document into a XML file.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can export some accounts or transactions just be selecting them before to launch the <a href=\"skg://export\">export_operation</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can apply <a href=\"skg://skrooge_search_plugin\">automatic rules</a> after an import to set the right categories.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can convert file by using the batch tool '%1'.</p>", "skroogeconvert"));
+    output.push_back(i18nc("Description of a tips", "<p>… skrooge uses the name of the imported file to find the target account.</p>"));
     return output;
 }
 
@@ -490,7 +490,7 @@ SKGError SKGImportExportPlugin::importbackends()
     // Display error
     SKGMainPanel::displayErrorMessage(err);
 
-    // Open last modified operations if setting activated
+    // Open last modified transactions if setting activated
     IFOK(err) openLastModifiedIfSetting();
 
     return err;
@@ -515,7 +515,7 @@ void SKGImportExportPlugin::importFiles(const QList<QUrl>& iFiles, int mode, boo
 
         if (iFiles.isEmpty()) {
             // Panel to ask files
-            KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(lastCodecUsed, QUrl(QStringLiteral("kfiledialog:///IMPEXP")),
+            KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(lastCodecUsed, QUrl::fromLocalFile(QUrl(QStringLiteral("kfiledialog:///IMPEXP")).toLocalFile()),
                                                  mode == 2 || mode == 3 ? QString("*.csv|" % i18nc("A file format", "CSV Files")) :
                                                  SKGImportExportManager().getImportMimeTypeFilter(),
                                                  SKGMainPanel::getMainPanel());
@@ -680,7 +680,7 @@ void SKGImportExportPlugin::importFiles(const QList<QUrl>& iFiles, int mode, boo
                 connect(install, &QAction::triggered, msg, &KMessageWidget::deleteLater, Qt::QueuedConnection);
             }
 
-            // Open last modified operations if setting activated
+            // Open last modified transactions if setting activated
             if (!iBlockOpenLastModified) {
                 IFOK(err) openLastModifiedIfSetting();
             }
@@ -795,7 +795,7 @@ void SKGImportExportPlugin::findTransfers()
         // Display error
         SKGMainPanel::displayErrorMessage(err);
 
-        // Open last modified operations if setting activated
+        // Open last modified transactions if setting activated
         if (!err && (NbOperationsMerged != 0)) {
             openLastModifiedIfSetting();
         }
@@ -822,7 +822,7 @@ void SKGImportExportPlugin::cleanBanks()
     // Display error
     SKGMainPanel::displayErrorMessage(err);
 
-    // Open last modified operations if setting activated
+    // Open last modified transactions if setting activated
     IFOK(err) openLastModifiedIfSetting();
 }
 
@@ -835,7 +835,7 @@ void SKGImportExportPlugin::swithvalidationImportedOperations()
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         {
-            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Switch validation of imported operations"), err, nb)
+            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Switch validation of imported transactions"), err, nb)
             for (int i = 0; !err && i < nb; ++i) {
                 SKGOperationObject op(selection.at(i));
                 if (op.getAttribute(QStringLiteral("t_imported")) == QStringLiteral("P")) {
@@ -851,7 +851,7 @@ void SKGImportExportPlugin::swithvalidationImportedOperations()
     }
 
     // status bar
-    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported operations validated.")))
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported transactions validated.")))
     else {
         err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
     }
@@ -868,7 +868,7 @@ void SKGImportExportPlugin::mergeImportedOperation()
     if ((SKGMainPanel::getMainPanel() != nullptr) && (m_currentBankDocument != nullptr)) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
-        err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Invalid selection, you must select one imported operation and one manual operation with same amounts"));
+        err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Invalid selection, you must select one imported transaction and one manual transaction with same amounts"));
         if (nb == 2) {
             SKGOperationObject opImported(selection.at(0));
             SKGOperationObject opManual(selection.at(1));
@@ -893,7 +893,7 @@ void SKGImportExportPlugin::mergeImportedOperation()
                     SKGMainPanel::getMainPanel()->displayMessage(i18nc("Question",  "Amounts are not equals. Do you want to force the merge ?"), SKGDocument::Error, QStringLiteral("skg://merge_imported_operation_force"));
                     err = SKGError();
                 } else {
-                    SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Merge imported operations"), err)
+                    SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Merge imported transactions"), err)
                     err = opManual.mergeAttribute(opImported);
                     IFKO(err) err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
                 }
@@ -902,7 +902,7 @@ void SKGImportExportPlugin::mergeImportedOperation()
     }
 
     // status bar
-    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported operations merged.")))
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported transactions merged.")))
 
     // Display error
     SKGMainPanel::displayErrorMessage(err);
@@ -913,7 +913,7 @@ void SKGImportExportPlugin::openLastModifiedIfSetting()
     // Read Setting
     bool open_after_import_or_processing = skgimportexport_settings::open_after_import_or_processing();
     if (open_after_import_or_processing) {
-        // Open last operations
+        // Open last transactions
         QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("view_open_last_modified"));
         if (act != nullptr) {
             act->trigger();
@@ -925,12 +925,12 @@ void SKGImportExportPlugin::validateAllOperations()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err) {
-        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate all operations"), err)
+        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate all transactions"), err)
         err = m_currentBankDocument->executeSqliteOrder(QStringLiteral("UPDATE operation SET t_imported='Y' WHERE t_imported='P'"));
     }
 
     // status bar
-    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Operations validated.")))
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Transactions validated.")))
     else {
         err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
     }
@@ -944,7 +944,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEINFUNC(10)
     SKGAdviceList output;
 
-    // Check operations not validated
+    // Check transactions not validated
     if (!iIgnoredAdvice.contains(QStringLiteral("skgimportexportplugin_notvalidated"))) {
         bool exist = false;
         m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("t_imported='P'"), exist);
@@ -952,8 +952,8 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
             SKGAdvice ad;
             ad.setUUID(QStringLiteral("skgimportexportplugin_notvalidated"));
             ad.setPriority(4);
-            ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations imported and not yet validated"));
-            ad.setLongMessage(i18nc("Advice on making the best (long)", "After importing operations, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported operation as validated, so that you know the operation has been fully processed."));
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Many transactions imported and not yet validated"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "After importing transactions, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported transaction as validated, so that you know the transaction has been fully processed."));
             SKGAdvice::SKGAdviceActionList autoCorrections;
             {
                 SKGAdvice::SKGAdviceAction a;
@@ -972,7 +972,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    // Krunner operations
+    // Krunner transactions
     QString dirName = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
     QStringList fileList = QDir(dirName).entryList(QStringList() << QStringLiteral("add_operation_*.txt"), QDir::Files);
     int nb = fileList.count();
@@ -994,19 +994,19 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
                 SKGAdvice ad;
                 ad.setUUID("skgimportexportplugin_krunner_" % fileName);
                 ad.setPriority(8);
-                ad.setShortMessage(i18nc("Advice on making the best (short)", "Krunner's operation ongoing [%1 %2 %3]", date, amount, payee));
-                ad.setLongMessage(i18nc("Advice on making the best (long)", "Operations created through krunner have to be fully created in skrooge."));
+                ad.setShortMessage(i18nc("Advice on making the best (short)", "Krunner's transaction ongoing [%1 %2 %3]", date, amount, payee));
+                ad.setLongMessage(i18nc("Advice on making the best (long)", "Transactions created through krunner have to be fully created in skrooge."));
                 autoCorrections.resize(0);
                 for (int j = 0; j < nbAccounts; ++j) {
                     SKGAdvice::SKGAdviceAction a;
-                    a.Title = i18nc("Advice on making the best (action)", "Import operation in %1", listAccounts.at(j));
+                    a.Title = i18nc("Advice on making the best (action)", "Import transaction in %1", listAccounts.at(j));
                     a.IconName = icon();
                     a.IsRecommended = false;
                     autoCorrections.push_back(a);
                 }
                 {
                     SKGAdvice::SKGAdviceAction a;
-                    a.Title = i18nc("Advice on making the best (action)", "Remove operation");
+                    a.Title = i18nc("Advice on making the best (action)", "Remove transaction");
                     a.IconName = QStringLiteral("edit-delete");
                     a.IsRecommended = false;
                     autoCorrections.push_back(a);
@@ -1045,7 +1045,7 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 double amount = SKGServices::stringToDouble(stream.readLine().trimmed());
                 QString payee = stream.readLine().trimmed();
 
-                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Import krunner's operation"), err)
+                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Import krunner's transaction"), err)
 
                 // Get account
                 SKGAccountObject act(m_currentBankDocument);
@@ -1057,7 +1057,7 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 IFOKDO(err, unit.setName(m_currentBankDocument->getPrimaryUnit().Name))
                 IFOKDO(err, unit.load())
 
-                // Add operation
+                // Add transaction
                 SKGOperationObject op;
                 IFOKDO(err, act.addOperation(op))
                 IFOKDO(err, op.setDate(date))
@@ -1098,7 +1098,7 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 }
 
                 // Send message
-                IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user", "The operation '%1' has been added", op.getDisplayName()), SKGDocument::Hidden))
+                IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user", "The transaction '%1' has been added", op.getDisplayName()), SKGDocument::Hidden))
 
                 // Close file
                 file.close();
@@ -1106,13 +1106,13 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
 
             // status bar
             IFOK(err) {
-                err = SKGError(0, i18nc("Message for successful user action", "Operations imported."));
+                err = SKGError(0, i18nc("Message for successful user action", "Transactions imported."));
                 QFile::remove(fileName);
             } else {
                 err.addError(ERR_FAIL, i18nc("Error message", "Import failed"));
             }
         } else {
-            err = SKGError(0, i18nc("Message for successful user action", "Operations removed."));
+            err = SKGError(0, i18nc("Message for successful user action", "Transactions removed."));
             QFile::remove(fileName);
         }
 
