@@ -142,7 +142,7 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void importFile(const QString& iFile = QString(), bool iBlockOpenLastModified = false);
-    void importFiles(const QList<QUrl>& iFiles = QList<QUrl>(), int mode = 1, bool iBlockOpenLastModified = false);  // 1=operations, 2=unit, 3=rules
+    void importFiles(const QList<QUrl>& iFiles = QList<QUrl>(), int mode = 1, bool iBlockOpenLastModified = false);  // 1=transactions, 2=unit, 3=rules
     SKGError importbackends();
     void exportFile();
     void findTransfers();
