@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
- * This file is Skrooge plugin for operation management.
+ * This file is Skrooge plugin for transaction management.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -40,7 +40,7 @@ SKGOperationBoardWidgetQml::SKGOperationBoardWidgetQml(QWidget* iParent, SKGDocu
 
     QStringList overlayopen;
     overlayopen.push_back(QStringLiteral("quickopen"));
-    m_menuOpen = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report..."), this);
+    m_menuOpen = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
     connect(m_menuOpen, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
         SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
     });
@@ -51,14 +51,14 @@ SKGOperationBoardWidgetQml::SKGOperationBoardWidgetQml(QWidget* iParent, SKGDocu
         sep->setSeparator(true);
         addAction(sep);
     }
-    m_menuGroup = new QAction(i18nc("Noun, a type of operations", "Grouped"), this);
+    m_menuGroup = new QAction(i18nc("Noun, a type of transactions", "Grouped"), this);
     m_menuGroup->setCheckable(true);
     m_menuGroup->setChecked(false);
     connect(m_menuGroup, &QAction::triggered, this, &SKGOperationBoardWidgetQml::settingsModified);
     addAction(m_menuGroup);
     m_Quick->rootContext()->setContextProperty(QStringLiteral("groupedWidget"), m_menuGroup);
 
-    m_menuTransfer = new QAction(i18nc("Noun, a type of operations", "Transfers"), this);
+    m_menuTransfer = new QAction(i18nc("Noun, a type of transactions", "Transfers"), this);
     m_menuTransfer->setCheckable(true);
     m_menuTransfer->setChecked(false);
     connect(m_menuTransfer, &QAction::triggered, this, &SKGOperationBoardWidgetQml::settingsModified);
@@ -67,14 +67,14 @@ SKGOperationBoardWidgetQml::SKGOperationBoardWidgetQml(QWidget* iParent, SKGDocu
 
     connect(m_menuGroup, &QAction::toggled, m_menuTransfer, &QAction::setEnabled);
 
-    m_menuTracked = new QAction(i18nc("Noun, a type of operations", "Tracked"), this);
+    m_menuTracked = new QAction(i18nc("Noun, a type of transactions", "Tracked"), this);
     m_menuTracked->setCheckable(true);
     m_menuTracked->setChecked(true);
     connect(m_menuTracked, &QAction::triggered, this, &SKGOperationBoardWidgetQml::settingsModified);
     addAction(m_menuTracked);
     m_Quick->rootContext()->setContextProperty(QStringLiteral("trackerWidget"), m_menuTracked);
 
-    m_menuSuboperation = new QAction(i18nc("Noun, a type of operations", "On suboperations"), this);
+    m_menuSuboperation = new QAction(i18nc("Noun, a type of transactions", "On subtransactions"), this);
     m_menuSuboperation->setCheckable(true);
     m_menuSuboperation->setChecked(false);
     connect(m_menuSuboperation, &QAction::triggered, this, &SKGOperationBoardWidgetQml::settingsModified);
