@@ -23,7 +23,7 @@ class SKGTreeView;
 class QAction;
 
 /**
- * This file is Skrooge plugin for operation management
+ * This file is Skrooge plugin for transaction management
  */
 class SKGOperationPluginWidget : public SKGTabPage
 {
@@ -123,7 +123,7 @@ private Q_SLOTS:
     void onRefreshInformationZone();
     void onRefreshInformationZoneDelayed();
     void onRotateAccountTools();
-    void onValidatePointedOperations();
+    void onValidateMarkedOperations();
     void onBtnModeClicked(int mode);
     void onAutoPoint();
     void onAddFakeOperation();
