@@ -28,7 +28,7 @@ SKGReportBoardWidget::SKGReportBoardWidget(QWidget* iParent, SKGDocumentBank* iD
 
     QStringList overlayopen;
     overlayopen.push_back(QStringLiteral("quickopen"));
-    auto open = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report..."), this);
+    auto open = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
     connect(open, &QAction::triggered, this, &SKGReportBoardWidget::onOpen);
     addAction(open);
 
