@@ -61,15 +61,15 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
     ui.kLineAdd->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-right")));
     ui.kLineRemove->setIcon(SKGServices::fromTheme(QStringLiteral("edit-delete")));
 
-    ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-line")), i18nc("Display graph values as the sum of operations amount", "Sum of operations"), 0);
-    ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-line-stacked")), i18nc("Display graph values as the cumulated sum of operations amount", "Cumulated sum of operations"), 1);
+    ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-line")), i18nc("Display graph values as the sum of transactions amount", "Sum of transactions"), 0);
+    ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-line-stacked")), i18nc("Display graph values as the cumulated sum of transactions amount", "Cumulated sum of transactions"), 1);
     ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-bar-percentage")), i18nc("Display graph values in base 100", "Base 100"), 7);
     ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-bar-percentage")), i18nc("Display graph values in base 100", "Cumulated sum in base 100"), 8);
     ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-area")), i18nc("Display graph values in percentage", "Percent of columns"), 2);
     ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-area")), i18nc("Display graph values in percentage", "Absolute percent of columns"), 5);
     ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-line")), i18nc("Display graph values in percentage", "Percent of lines"), 4);
     ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("office-chart-line")), i18nc("Display graph values in percentage", "Absolute percent of lines"), 6);
-    ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("irc-operator")), i18nc("Display graph values as a number of operations (or transaction)", "Count number of operations"), 3);
+    ui.kMode->addItem(SKGServices::fromTheme(QStringLiteral("irc-operator")), i18nc("Display graph values as a number of transactions (or transaction)", "Count number of transactions"), 3);
 
     ui.kForecastCmb->addItem(i18nc("Noun", "None"), 0);
     ui.kForecastCmb->addItem(SKGServices::fromTheme(QStringLiteral("download-later")), i18nc("Noun", "Moving average"), 2);
@@ -91,13 +91,13 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
     QMenu* tableMenu = ui.kTableWithGraph->getTableContextualMenu();
     if (tableMenu != nullptr) {
         tableMenu->addSeparator();
-        m_openAction = tableMenu->addAction(SKGServices::fromTheme(QStringLiteral("quickopen")), i18nc("Verb", "Open..."));
+        m_openAction = tableMenu->addAction(SKGServices::fromTheme(QStringLiteral("quickopen")), i18nc("Verb", "Open…"));
         if (m_openAction != nullptr) {
             m_openAction->setEnabled(false);
         }
         QStringList overlayopen;
         overlayopen.push_back(QStringLiteral("quickopen"));
-        m_openReportAction = tableMenu->addAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report..."));
+        m_openReportAction = tableMenu->addAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"));
         if (m_openReportAction != nullptr) {
             m_openReportAction->setEnabled(false);
         }
@@ -150,7 +150,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
                    QStringLiteral("t_REALREFUND") <<
                    QStringLiteral("t_TRANSFER");
 
-    // Adding properties of operations and sub operations
+    // Adding properties of transactions and sub transactions
     QStringList properties;
     iDocument->getDistinctValues(QStringLiteral("parameters"), QStringLiteral("'p_'||t_name"), QStringLiteral("(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation')  AND t_name NOT LIKE 'SKG_%'"), properties);
     int nb = properties.count();
@@ -521,7 +521,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
     }
 
     // Condition on line attribute
-    oTitle += i18nc("Noun, a list of items", "Sub operations");
+    oTitle += i18nc("Noun, a list of items", "Sub transactions");
     auto* btn = qobject_cast<SKGColorButton*>(ui.kTableWithGraph->table()->cellWidget(row, 0));
 
     QString attLine;
@@ -978,26 +978,26 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 // Mode history ?
                 bool modeHistory = (mode == 1 || mode == 8);
 
-                // Get condition (must be done before forecast on scheduled operations)
+                // Get condition (must be done before forecast on scheduled transactions)
                 int nbVirtualColumn = 0;
                 QString conditionPrevious;
                 QString conditionForecast;
                 QString condition = getConsolidatedWhereClause(&conditionPrevious, &conditionForecast);
                 int forecastMode = ui.kForecastCmb->itemData(ui.kForecastCmb->currentIndex()).toInt();
 
-                // Compute forecast on scheduled operations
+                // Compute forecast on scheduled transactions
                 bool transactionToRollback = false;
                 if (forecastMode == 1 || forecastMode == 4) {
-                    // Create operations
+                    // Create transactions
                     QDate lastDate = QDate::currentDate().addDays(ui.kForecastValue->value() * skgreport_settings::maxForecasts() * 365.0 / ui.kForecastValue->maximum());
                     if (forecastMode == 1) {
-                        // Create scheduled operations
-                        doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create scheduled operations"));
+                        // Create scheduled transactions
+                        doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create scheduled transactions"));
                         transactionToRollback = true;
                         int nbInserted = 0;
                         SKGRecurrentOperationObject::process(doc, nbInserted, true, lastDate);
                     } else {
-                        // Create budgeted operations
+                        // Create budgeted transactions
                         SKGObjectBase::SKGListSKGObjectBase budgets;
                         IFOKDO(err, doc->getObjects(QStringLiteral("v_budget"),
                                                     "t_PERIOD>STRFTIME('%Y-%m', date('now', 'localtime')) AND "
@@ -1026,7 +1026,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                                 IFOKDO(err, unit.load())
 
 
-                                doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create budgeted operations"));
+                                doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create budgeted transactions"));
                                 transactionToRollback = true;
                                 for (int i = 0; !err && i < nbBudgets; ++i) {
                                     SKGBudgetObject budget(budgets.at(i));
@@ -1142,7 +1142,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
                 }
 
-                // Rollback create operations
+                // Rollback create transactions
                 if (transactionToRollback) {
                     doc->endTransaction(false);
                 }
