@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
- * A skrooge plugin to manage scheduled operations
+ * A skrooge plugin to manage scheduled transactions
  *
  * @author Stephane MANKOWSKI
  */
@@ -19,6 +19,7 @@
 
 #include "skgdocumentbank.h"
 #include "skgmainpanel.h"
+#include "skgmenuitem.h"
 #include "skgrecurrentoperationobject.h"
 #include "skgscheduled_settings.h"
 #include "skgscheduledboardwidget.h"
@@ -61,12 +62,12 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument)
     listOperation << QStringLiteral("operation");
 
     // Create yours actions here
-    auto actScheduleOperation = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb, create a scheduled operation", "Schedule"), this);
+    auto actScheduleOperation = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb, create a scheduled transaction", "Schedule"), this);
     connect(actScheduleOperation, &QAction::triggered, this, &SKGScheduledPlugin::onScheduleOperation);
     actionCollection()->setDefaultShortcut(actScheduleOperation, Qt::CTRL + Qt::Key_I);
     registerGlobalAction(QStringLiteral("schedule_operation"), actScheduleOperation, QStringList() << QStringLiteral("operation"), 1, -1, 410);
 
-    auto actSkipScheduledOperation = new QAction(SKGServices::fromTheme(QStringLiteral("nextuntranslated")), i18nc("Verb, skip scheduled operations", "Skip"), this);
+    auto actSkipScheduledOperation = new QAction(SKGServices::fromTheme(QStringLiteral("nextuntranslated")), i18nc("Verb, skip scheduled transactions", "Skip"), this);
     connect(actSkipScheduledOperation, &QAction::triggered, this, &SKGScheduledPlugin::onSkipScheduledOperations);
     registerGlobalAction(QStringLiteral("skip_scheduled_operations"), actSkipScheduledOperation, QStringList() << QStringLiteral("recurrentoperation"), 1, -1, 410);
 
@@ -90,10 +91,49 @@ void SKGScheduledPlugin::onShowAssignScheduleMenu()
         // Search templates
         SKGStringListList listTmp;
         m_currentBankDocument->executeSelectSqliteOrder(
-            QStringLiteral("SELECT t_displayname, id FROM v_recurrentoperation_displayname ORDER BY t_displayname"),
+            QStringLiteral("SELECT t_displayname, id, i_nb_times FROM v_recurrentoperation_displayname ORDER BY i_nb_times DESC, t_displayname"),
             listTmp);
 
+        // Get assigned schedules of selected transactions
+        QSet<int> recurrentIds;
+        if ((SKGMainPanel::getMainPanel() != nullptr) && (m_currentBankDocument != nullptr)) {
+            SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+            int nb = selection.count();
+            for (int i = 0; i < nb; ++i) {
+                SKGOperationObject operationObj(selection.at(i));
+                if (operationObj.isTemplate()) {
+                    QAction* act = m->addAction(i18nc("A message that is shown in assign schedule menu for a tempate operation", "Cannot assign a schedule to a template"));
+                    if (act != nullptr) {
+                        act->setEnabled(false);
+                    }
+                    return;
+                }
+                recurrentIds.insert(operationObj.getRecurrentOperation());
+            }
+        }
+
+        const auto fontDisabledScheduleColor = KSharedConfig::openConfig()->group("skrooge_scheduled").readEntry("fontFutureColor", QColor(Qt::gray));
+        const auto addAction = [this, recurrentIds, fontDisabledScheduleColor](QMenu * menu, const QString & text, const QString & recurrentId, bool isActive = true) {
+            auto act = new QWidgetAction(menu);
+            auto menuItem = new SKGMenuitem;
+            menuItem->setText(text);
+            menuItem->setIcon(SKGServices::fromTheme(QStringLiteral("edit-guides")));
+            if (!isActive) {
+                menuItem->setColor(fontDisabledScheduleColor);
+            }
+            menuItem->setIsBold(recurrentIds.contains(SKGServices::stringToInt(recurrentId)));
+            act->setDefaultWidget(menuItem);
+            act->setData(recurrentId);
+            connect(act, &QAction::triggered, this, &SKGScheduledPlugin::onAssignScheduleMenu);
+            menu->addAction(act);
+        };
+
+        // Add the "unassign" item
+        addAction(m, i18nc("Noun, item to unassign a schedule", "None"), "0");
+
         // Build menus
+        bool hasActive = false;
+        bool hasInactive = false;
         int count = 0;
         bool fav = true;
         int nb = listTmp.count();
@@ -105,12 +145,17 @@ void SKGScheduledPlugin::onShowAssignScheduleMenu()
             }
             count++;
 
-            // Add actions
-            QAction* act = m->addAction(SKGServices::fromTheme(QStringLiteral("edit-guides")), listTmp.at(i).at(0));
-            if (act != nullptr) {
-                act->setData(listTmp.at(i).at(1));
-                connect(act, &QAction::triggered, this, &SKGScheduledPlugin::onAssignScheduleMenu);
+            const bool isScheduleActive = SKGServices::stringToInt(listTmp.at(i).at(2)) > 0;
+            if (isScheduleActive && !hasActive) {
+                m->addSection(i18nc("Adjective, a header for active schedule items that should follow", "active"));
+                hasActive = true;
             }
+            if (!isScheduleActive && !hasInactive) {
+                m->addSection(i18nc("Adjective, a header for non-active schedule items that should follow", "inactive"));
+                hasInactive = true;
+            }
+
+            addAction(m, listTmp.at(i).at(0), listTmp.at(i).at(1), isScheduleActive);
         }
     }
 }
@@ -122,7 +167,7 @@ void SKGScheduledPlugin::onAssignScheduleMenu()
     auto* act = qobject_cast<QAction*>(sender());
     if (act != nullptr) {
         // Get template
-        auto id = act->data().toString();
+        const auto id = SKGServices::stringToInt(act->data().toString());
 
         // Get Selection
         if ((SKGMainPanel::getMainPanel() != nullptr) && (m_currentBankDocument != nullptr)) {
@@ -132,8 +177,7 @@ void SKGScheduledPlugin::onAssignScheduleMenu()
                 SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Assign schedule"), err, nb)
                 for (int i = 0; !err && i < nb; ++i) {
                     SKGOperationObject operationObj(selection.at(i));
-                    IFOKDO(err, operationObj.setAttribute("r_recurrentoperation_id", id))
-                    IFOKDO(err, operationObj.save(true, false))
+                    IFOKDO(err, operationObj.setRecurrentOperation(id))
 
                     IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                 }
@@ -165,7 +209,7 @@ void SKGScheduledPlugin::refresh()
             bool check_on_open = skgscheduled_settings::check_on_open();
 
             if (check_on_open) {
-                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Insert recurrent operations"), err)
+                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Insert recurrent transactions"), err)
                 int nbi = 0;
                 err = SKGRecurrentOperationObject::process(m_currentBankDocument, nbi);
             }
@@ -183,7 +227,7 @@ int SKGScheduledPlugin::getNbDashboardWidgets()
 QString SKGScheduledPlugin::getDashboardWidgetTitle(int iIndex)
 {
     Q_UNUSED(iIndex)
-    return i18nc("Noun, the title of a section", "Scheduled operations");
+    return i18nc("Noun, the title of a section", "Scheduled transactions");
 }
 
 SKGBoardWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
@@ -204,6 +248,20 @@ QWidget* SKGScheduledPlugin::getPreferenceWidget()
     auto w = new QWidget();
     ui.setupUi(w);
 
+    ui.kcfg_convert_to_from_template->hide();
+    clearConvertToFromTemplateSetting();
+
+    connect(skgscheduled_settings::self(), &skgscheduled_settings::configChanged,
+    ui.kcfg_convert_to_from_template, [this]() {
+        ui.kcfg_convert_to_from_template->setChecked(false);
+        ui.kcfg_convert_to_from_template->hide();
+    });
+    connect(ui.kcfg_create_template, &QCheckBox::toggled,
+    this, [this](bool isChecked) {
+        ui.kcfg_convert_to_from_template->setChecked(false);
+        const bool isChanged = (isChecked != skgscheduled_settings::create_template());
+        ui.kcfg_convert_to_from_template->setVisible(isChanged);
+    });
     connect(ui.kcfg_remind_me, &QCheckBox::toggled, ui.kcfg_remind_me_days, &QSpinBox::setEnabled);
     connect(ui.kcfg_remind_me, &QCheckBox::toggled, ui.label_3, &QSpinBox::setEnabled);
     connect(ui.kcfg_nb_times, &QCheckBox::toggled, ui.kcfg_nb_times_val, &QSpinBox::setEnabled);
@@ -219,7 +277,7 @@ KConfigSkeleton* SKGScheduledPlugin::getPreferenceSkeleton()
 
 QString SKGScheduledPlugin::title() const
 {
-    return i18nc("Noun", "Scheduled operations");
+    return i18nc("Noun", "Scheduled transactions");
 }
 
 QString SKGScheduledPlugin::icon() const
@@ -229,7 +287,7 @@ QString SKGScheduledPlugin::icon() const
 
 QString SKGScheduledPlugin::toolTip() const
 {
-    return i18nc("Noun", "Operations scheduled management");
+    return i18nc("Noun", "Transactions scheduled management");
 }
 
 int SKGScheduledPlugin::getOrder() const
@@ -240,7 +298,7 @@ int SKGScheduledPlugin::getOrder() const
 QStringList SKGScheduledPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... you can <a href=\"skg://skrooge_scheduled_plugin\">schedule</a> operations or templates.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can <a href=\"skg://skrooge_scheduled_plugin\">schedule</a> transactions or templates.</p>"));
     return output;
 }
 
@@ -254,38 +312,35 @@ SKGError SKGScheduledPlugin::savePreferences() const
     SKGError err;
     if (m_currentBankDocument != nullptr) {
         // Read Setting
-        if (skgscheduled_settings::create_template()) {
+        if (skgscheduled_settings::convert_to_from_template()) {
+            const auto newTemplateMode = skgscheduled_settings::create_template();
             SKGObjectBase::SKGListSKGObjectBase recurrents;
-            err = m_currentBankDocument->getObjects(QStringLiteral("v_recurrentoperation"), QStringLiteral("(select count(1) from operation where operation.id=rd_operation_id and t_template='N')=1"), recurrents);
+            err = m_currentBankDocument->getObjects(QStringLiteral("v_recurrentoperation"), QStringLiteral("(select count(1) from operation where operation.id=rd_operation_id and t_template='%1')=1").arg(newTemplateMode ? "N" : "Y"), recurrents);
             int nb = recurrents.count();
             if (nb != 0) {
                 SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Conversion schedule"), err, nb)
                 for (int i = 0; !err && i < nb; ++i) {
-                    // Migration of existing schedule in template mode
+                    // Converting an existing schedule
                     SKGRecurrentOperationObject recOp(recurrents.at(i));
-                    SKGOperationObject operationObj;
-
-                    IFOK(err) recOp.getParentOperation(operationObj);
-
-                    SKGOperationObject operationObjOrig = operationObj;
-                    IFOKDO(err, operationObjOrig.duplicate(operationObj, operationObjOrig.getDate(), true))
-
-                    IFOKDO(err, recOp.setParentOperation(operationObj))
-                    IFOKDO(err, recOp.save())
-                    IFOKDO(err, recOp.load())
-
-                    IFOKDO(err, operationObjOrig.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recOp.getID())))
-                    IFOKDO(err, operationObjOrig.save())
-
+                    IFOKDO(err, recOp.setTemplate(newTemplateMode))
                     IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                 }
-                IFOK(err) m_currentBankDocument->sendMessage(i18nc("An information message",  "All scheduled operations have been converted in template"));
+                IFOK(err) m_currentBankDocument->sendMessage(i18nc("An information message",  "All scheduled transactions have been converted in template"));
             }
+
+            clearConvertToFromTemplateSetting();
         }
     }
     return err;
 }
 
+void SKGScheduledPlugin::clearConvertToFromTemplateSetting() const
+{
+    // This setting should be enabled only manually and we reset it after conversion is done
+    skgscheduled_settings::setConvert_to_from_template(false);
+    skgscheduled_settings::self()->save();
+}
+
 SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperation, SKGRecurrentOperationObject& oRecurrent) const
 {
     SKGError err;
@@ -294,7 +349,7 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
 
     SKGOperationObject operationObjOrig;
     if (!isTemplate && skgscheduled_settings::create_template()) {
-        // The selected operation is not a template and settings is set to create one
+        // The selected transaction is not a template and settings is set to create one
         operationObjOrig = operationObjDuplicate;
         IFOKDO(err, operationObjOrig.duplicate(operationObjDuplicate, operationObjOrig.getDate(), true))
         IFOK(err) m_currentBankDocument->sendMessage(i18nc("An information message",  "A template has been created"), SKGDocument::Positive);
@@ -336,29 +391,29 @@ void SKGScheduledPlugin::onScheduleOperation()
         int nb = selection.count();
         if ((nb != 0) && (m_currentBankDocument != nullptr)) {
             QStringList list;
-            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Operation schedule"), err, nb)
+            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Transaction schedule"), err, nb)
             for (int i = 0; !err && i < nb; ++i) {
                 SKGOperationObject operationObj(selection.at(i));
                 SKGRecurrentOperationObject rop;
                 err = scheduleOperation(operationObj, rop);
 
                 // Send message
-                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The operation '%1' has been scheduled", operationObj.getDisplayName()), SKGDocument::Hidden))
+                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The transaction '%1' has been scheduled", operationObj.getDisplayName()), SKGDocument::Hidden))
 
                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                 list.push_back(operationObj.getUniqueID());
             }
 
             IFOK(err) {
-                // Open the scheduled operation
+                // Open the scheduled transaction
                 SKGMainPanel::getMainPanel()->openPage("skg://skrooge_scheduled_plugin/?selection=" % SKGServices::encodeForUrl(SKGServices::stringsToCsv(list)));
             }
         }
 
         // status bar
-        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation scheduled.")))
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Transaction scheduled.")))
         else {
-            err.addError(ERR_FAIL, i18nc("Error message",  "Operation schedule failed"));
+            err.addError(ERR_FAIL, i18nc("Error message",  "Transaction schedule failed"));
         }
 
         // Display error
@@ -383,7 +438,7 @@ void SKGScheduledPlugin::onSkipScheduledOperations()
         int nb = selection.count();
         if ((nb != 0) && (m_currentBankDocument != nullptr)) {
             QStringList list;
-            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Skip scheduled operations"), err, nb)
+            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Skip scheduled transactions"), err, nb)
             for (int i = 0; !err && i < nb; ++i) {
                 SKGRecurrentOperationObject rop(m_currentBankDocument, selection.at(i).getID());
                 err = rop.setDate(rop.getNextDate());
@@ -398,9 +453,9 @@ void SKGScheduledPlugin::onSkipScheduledOperations()
         }
 
         // status bar
-        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled operations skipped.")))
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled transactions skipped.")))
         else {
-            err.addError(ERR_FAIL, i18nc("Error message",  "Skip of scheduled operation failed"));
+            err.addError(ERR_FAIL, i18nc("Error message",  "Skip of scheduled transaction failed"));
         }
 
         // Display error
@@ -415,7 +470,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGAdviceList output;
     output.reserve(20);
 
-    // Recurrent operation with the last inserted operation having a different amount
+    // Recurrent transaction with the last inserted transaction having a different amount
     if (!iIgnoredAdvice.contains(QStringLiteral("skgscheduledplugin_notuptodate"))) {
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.rd_operation_id, r.f_CURRENTAMOUNT, r2.f_CURRENTAMOUNT FROM v_recurrentoperation_display r INNER JOIN (SELECT MAX(d_date), f_CURRENTAMOUNT, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 WHERE r2.r_recurrentoperation_id=r.id AND ABS(r.f_CURRENTAMOUNT-r2.f_CURRENTAMOUNT)>" % SKGServices::doubleToString(EPSILON), result);
@@ -434,12 +489,12 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             SKGAdvice ad;
             ad.setUUID("skgscheduledplugin_notuptodate|" % idOper % ';' % amountLastOperation);
             ad.setPriority(4);
-            ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
-            ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the amount of the last inserted operation (%2)", name, amountLastOperation));
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled transaction '%1' not uptodate", name));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled transaction '%1' does not have the amount of the last inserted transaction (%2)", name, amountLastOperation));
             autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
-                a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled operation amount (%1)", amountLastOperation);
+                a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled transaction amount (%1)", amountLastOperation);
                 a.IconName = QStringLiteral("system-run");
                 a.IsRecommended = true;
                 autoCorrections.push_back(a);
@@ -449,7 +504,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    // Recurrent operation with the last inserted operation having a different date
+    // Recurrent transaction with the last inserted transaction having a different date
     if (!iIgnoredAdvice.contains(QStringLiteral("skgscheduledplugin_newdate"))) {
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT r.id, r.d_date, "
@@ -472,12 +527,12 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
                 SKGAdvice ad;
                 ad.setUUID("skgscheduledplugin_newdate|" % line.at(0) % ';' % newDate);
                 ad.setPriority(4);
-                ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
-                ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the date aligned with the last inserted operation (%2)", name, currentDate));
+                ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled transaction '%1' not uptodate", name));
+                ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled transaction '%1' does not have the date aligned with the last inserted transaction (%2)", name, currentDate));
                 autoCorrections.resize(0);
                 {
                     SKGAdvice::SKGAdviceAction a;
-                    a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled operation date (%1)", newDate);
+                    a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled transaction date (%1)", newDate);
                     a.IconName = QStringLiteral("system-run");
                     a.IsRecommended = true;
                     autoCorrections.push_back(a);
@@ -488,7 +543,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    // Possible recurrent operations
+    // Possible recurrent transactions
     if (!iIgnoredAdvice.contains(QStringLiteral("skgscheduledplugin_possibleschedule"))) {
         SKGStringListList result;
 
@@ -511,11 +566,11 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setUUID("skgscheduledplugin_possibleschedule|" % id);
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Possible schedule '%1'", name));
-            ad.setLongMessage(i18nc("Advice on making the best (long)", "The operation '%1' seems to be regularly created and could be scheduled", name));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "The transaction '%1' seems to be regularly created and could be scheduled", name));
             autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
-                a.Title = i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name);
+                a.Title = i18nc("Advice on making the best (action)", "Monthly schedule the transaction '%1'", name);
                 a.IconName = icon();
                 a.IsRecommended = false;
                 autoCorrections.push_back(a);
@@ -540,7 +595,7 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
 
         // Update the operation
         {
-            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled operation"), err)
+            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled transaction"), err)
             SKGOperationObject op(m_currentBankDocument, idOper);
             SKGObjectBase::SKGListSKGObjectBase subOps;
             IFOKDO(err, op.getSubOperations(subOps))
@@ -559,11 +614,11 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             }
 
             // Send message
-            IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user", "The amount of the scheduled operation of '%1' have been updated", op.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user", "The amount of the scheduled transaction of '%1' have been updated", op.getDisplayName()), SKGDocument::Hidden))
         }
 
         // status bar
-        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled operation updated.")))
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled transaction updated.")))
         else {
             err.addError(ERR_FAIL, i18nc("Error message", "Update failed"));
         }
@@ -582,17 +637,17 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
 
         // Update the operation
         {
-            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled operation"), err)
+            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled transaction"), err)
             SKGRecurrentOperationObject rop(m_currentBankDocument, id);
             IFOKDO(err, rop.setDate(SKGServices::stringToTime(newDate).date()))
             IFOKDO(err, rop.save())
 
             // Send message
-            IFOKDO(err, rop.getDocument()->sendMessage(i18nc("An information to the user", "The date of the scheduled operation of '%1' have been updated", rop.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err, rop.getDocument()->sendMessage(i18nc("An information to the user", "The date of the scheduled transaction of '%1' have been updated", rop.getDisplayName()), SKGDocument::Hidden))
         }
 
         // status bar
-        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled operation updated.")))
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled transaction updated.")))
         else {
             err.addError(ERR_FAIL, i18nc("Error message", "Update failed"));
         }
@@ -608,7 +663,7 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
 
         // Update the operation
         {
-            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Scheduled operation"), err)
+            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Scheduled transaction"), err)
             SKGOperationObject op(m_currentBankDocument, idOper);
             SKGRecurrentOperationObject rop;
             err = scheduleOperation(op, rop);
@@ -619,13 +674,13 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             IFOKDO(err, rop.save())
 
             // Send message
-            IFOKDO(err, rop.getDocument()->sendMessage(i18nc("An information to the user", "The scheduled operation of '%1' have been added", rop.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err, rop.getDocument()->sendMessage(i18nc("An information to the user", "The scheduled transaction of '%1' have been added", rop.getDisplayName()), SKGDocument::Hidden))
 
             m_counterAdvice = 0;  // To force the update
         }
 
         // status bar
-        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation scheduled.")))
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Transaction scheduled.")))
         else {
             err.addError(ERR_FAIL, i18nc("Error message", "Schedule failed"));
         }
