@@ -6,7 +6,7 @@
 #ifndef SKGSCHEDULEDPLUGIN_H
 #define SKGSCHEDULEDPLUGIN_H
 /** @file
- * A skrooge plugin to manage scheduled operations.
+ * A skrooge plugin to manage scheduled transactions.
 *
 * @author Stephane MANKOWSKI
  */
@@ -19,7 +19,7 @@ class QMenu;
 class SKGDocumentBank;
 
 /**
- * A skrooge plugin to manage scheduled operations
+ * A skrooge plugin to manage scheduled transactions
  */
 class SKGScheduledPlugin : public SKGInterfacePlugin
 {
@@ -155,6 +155,8 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGScheduledPlugin)
 
+    void clearConvertToFromTemplateSetting() const;
+
     SKGError scheduleOperation(const SKGOperationObject& iOperation, SKGRecurrentOperationObject& oRecurrent) const;
 
     SKGDocumentBank* m_currentBankDocument;
