@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
- * A skrooge plugin to manage scheduled operations.
+ * A skrooge plugin to manage scheduled transactions.
  *
  * @author Stephane MANKOWSKI
  */
@@ -38,7 +38,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(QWidget* iParent, SKGDocument
     if (SKGMainPanel::getMainPanel() != nullptr) {
         auto actJumpToOperation = new QAction(SKGServices::fromTheme(QStringLiteral("quickopen")), ui.kJumpBtn->text(), this);
         connect(actJumpToOperation, &QAction::triggered, this, &SKGScheduledPluginWidget::onJumpToTheOperation);
-        SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_reconcile"), actJumpToOperation, true, QStringList() << QStringLiteral("recurrentoperation"), 1, -1, 160);
+        SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("jump_to_scheduled_operation"), actJumpToOperation, true, QStringList() << QStringLiteral("recurrentoperation"), 1, -1, 160);
     }
 
     // Set show widget
@@ -52,7 +52,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(QWidget* iParent, SKGDocument
     connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
 
-    // Add Standard KDE Icons to buttons to Operations
+    // Add Standard KDE Icons to buttons to Transactions
     ui.kModifyBtn->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
     ui.kProcessBtn->setIcon(SKGServices::fromTheme(QStringLiteral("system-run")));
     connect(ui.kProcessBtn, &QToolButton::clicked, this, &SKGScheduledPluginWidget::onProcess);
@@ -154,7 +154,7 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
     if (!selection.isEmpty()) {
         // Build where clause and title
         QString wc = QStringLiteral("id IN (");
-        QString title = i18nc("Noun, a list of items", "Operations of the schedule");
+        QString title = i18nc("Noun, a list of items", "Transactions of the schedule");
         int nb = selection.count();
         for (int i = 0; i < nb; ++i) {
             SKGRecurrentOperationObject recOp(selection.at(i));
@@ -169,7 +169,7 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
         }
         wc += ')';
 
-        // Call operation plugin
+        // Call transaction plugin
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?template=Y&title_icon=chronometer&operationTable=v_operation_display_all&title=" %
                                                SKGServices::encodeForUrl(title) % "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
     }
@@ -187,6 +187,22 @@ void SKGScheduledPluginWidget::onSelectionChanged()
     if (nb == 1) {
         SKGRecurrentOperationObject recOp(ui.kView->getView()->getFirstSelectedObject());
 
+        const auto isTemplate = recOp.isTemplate();
+        ui.kIsTemplate->setCheckState(isTemplate ? Qt::Checked : Qt::Unchecked);
+        if (isTemplate) {
+            SKGError err;
+            SKGObjectBase::SKGListSKGObjectBase transactions;
+            err = recOp.getRecurredOperations(transactions);
+            IFOK(err) ui.kIsTemplate->setEnabled(!transactions.isEmpty());
+            IFOK(err) ui.kIsTemplate->setToolTip(transactions.isEmpty() ?
+                                                 i18nc("Information message", "A non-template schedule requires at least one transaction") :
+                                                 i18nc("Information message", "Convert to a non-template schedule"));
+        } else {
+            ui.kIsTemplate->setEnabled(true);
+            ui.kIsTemplate->setToolTip(
+                i18nc("Information message", "Convert to a template schedule"));
+        }
+
         ui.kFirstOccurenceDate->setDate(recOp.getDate());
         ui.kOnceEveryVal->setValue(recOp.getPeriodIncrement());
         ui.kOnceEveryUnit->setCurrentIndex(static_cast<int>(recOp.getPeriodUnit()));
@@ -263,14 +279,22 @@ void SKGScheduledPluginWidget::onUpdate()
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
         int nb = selection.count();
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err, nb)
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent transaction update"), err, nb)
         for (int i = 0; !err && i < nb; ++i) {
             // Get the real object, not the object from the view
             SKGRecurrentOperationObject recOp = SKGRecurrentOperationObject(selection.at(i).getDocument(), selection.at(i).getID());
 
+            // Convert to/from template if needed
+            const auto isTemplate = recOp.isTemplate();
+            if (isTemplate && ui.kIsTemplate->checkState() == Qt::Unchecked) {
+                err = recOp.setTemplate(false);
+            } else if (!isTemplate && ui.kIsTemplate->checkState() == Qt::Checked) {
+                err = recOp.setTemplate(true);
+            }
+
             // Update it
             if (ui.kFirstOccurenceDate->currentText() != NOUPDATE) {
-                err = recOp.setDate(ui.kFirstOccurenceDate->date());
+                IFOKDO(err, recOp.setDate(ui.kFirstOccurenceDate->date()))
             }
             IFOKDO(err, recOp.setPeriodIncrement(ui.kOnceEveryVal->value()))
             IFOKDO(err, recOp.setPeriodUnit(static_cast<SKGRecurrentOperationObject::PeriodUnit>(ui.kOnceEveryUnit->currentIndex())))
@@ -283,13 +307,13 @@ void SKGScheduledPluginWidget::onUpdate()
             IFOKDO(err, recOp.save())
 
             // Send message
-            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The recurrent operation '%1' has been updated", recOp.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The recurrent transaction '%1' has been updated", recOp.getDisplayName()), SKGDocument::Hidden))
 
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
     // status bar
-    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent operation updated.")))
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent transaction updated.")))
     else {
         err.addError(ERR_FAIL, i18nc("Error message",  "Update failed"));
     }
@@ -314,7 +338,7 @@ void SKGScheduledPluginWidget::onProcess(bool iImmediately)
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
         int nb = selection.count();
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Insert recurrent operations"), err, nb)
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Insert recurrent transactions"), err, nb)
         for (int i = 0; !err && i < nb; ++i) {
             // Get the real object, not the object from the view
             SKGRecurrentOperationObject recOp = SKGRecurrentOperationObject(selection.at(i).getDocument(), selection.at(i).getID());
@@ -326,7 +350,7 @@ void SKGScheduledPluginWidget::onProcess(bool iImmediately)
         }
     }
     // status bar
-    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent operation inserted.")))
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent transaction inserted.")))
     else {
         err.addError(ERR_FAIL, i18nc("Error message",  "Insertion failed"));
     }
