@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
- * A skrooge plugin to search and process operations
+ * A skrooge plugin to search and process transactions
  *
  * @author Stephane MANKOWSKI
  */
@@ -82,7 +82,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument)
 
     // Create yours actions here
     // Execute on all operation
-    auto actExecuteAll = new QAction(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Verb, action to execute", "Execute on all operations"), this);
+    auto actExecuteAll = new QAction(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Verb, action to execute", "Execute on all transactions"), this);
     connect(actExecuteAll, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::ALL); });
     registerGlobalAction(QStringLiteral("execute_all"), actExecuteAll, QStringList() << QStringLiteral("rule"), 1, -1, 501);
 
@@ -90,16 +90,16 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument)
     {
         QStringList overlaycsv;
         overlaycsv.push_back(QStringLiteral("document-import"));
-        auto actExecuteImported = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not checked operations"), this);
+        auto actExecuteImported = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not checked transactions"), this);
         connect(actExecuteImported, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::NOTCHECKED); });
         registerGlobalAction(QStringLiteral("execute_notchecked"), actExecuteImported, QStringList() << QStringLiteral("rule"), 1, -1, 502);
     }
 
-    // Execute on imported operation
+    // Execute on imported transaction
     {
         QStringList overlaycsv;
         overlaycsv.push_back(QStringLiteral("document-import"));
-        auto actExecuteImported = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on imported operations"), this);
+        auto actExecuteImported = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on imported transactions"), this);
         connect(actExecuteImported, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::IMPORTED); });
         registerGlobalAction(QStringLiteral("execute_imported"), actExecuteImported, QStringList() << QStringLiteral("rule"), 1, -1, 502);
     }
@@ -108,7 +108,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument)
     {
         QStringList overlaycsv;
         overlaycsv.push_back(QStringLiteral("dialog-ok"));
-        auto actExecuteNotValidated = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not validated operations"), this);
+        auto actExecuteNotValidated = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not validated transactions"), this);
         connect(actExecuteNotValidated, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::IMPORTEDNOTVALIDATE); });
         registerGlobalAction(QStringLiteral("execute_not_validated"), actExecuteNotValidated, QStringList() << QStringLiteral("rule"), 1, -1, 503);
     }
@@ -341,8 +341,8 @@ int SKGSearchPlugin::getOrder() const
 QStringList SKGSearchPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... skrooge can <a href=\"skg://skrooge_search_plugin\">search</a> and automatically process some operations.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can create alarms based on <a href=\"skg://skrooge_search_plugin\">searches</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… skrooge can <a href=\"skg://skrooge_search_plugin\">search</a> and automatically process some transactions.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can create alarms based on <a href=\"skg://skrooge_search_plugin\">searches</a>.</p>"));
     return output;
 }
 
@@ -389,7 +389,7 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
                         autoCorrections.resize(0);
                         {
                             SKGAdvice::SKGAdviceAction a;
-                            a.Title = i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm");
+                            a.Title = i18nc("Advice on making the best (action)", "Open transactions corresponding to this alarm");
                             a.IconName = QStringLiteral("quickopen");
                             a.IsRecommended = false;
                             autoCorrections.push_back(a);
