@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
- * A skrooge plugin to search and process operations.
+ * A skrooge plugin to search and process transactions.
  *
  * @author Stephane MANKOWSKI
  */
@@ -105,7 +105,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(QWidget* iParent, SKGDocument* iDoc
     ui.kQueryCreator->setParameters(iDocument, QStringLiteral("v_suboperation_consolidated"), attributeForQuery);
     ui.kActionCreator->setParameters(iDocument, QStringLiteral("v_suboperation_consolidated"), attributeForUpdate, true);
 
-    // Bind operation view
+    // Bind transaction view
     ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_rule_display"), QStringLiteral("1=1 ORDER BY f_sortorder"), this, QLatin1String(""), false));
     ui.kView->getView()->sortByColumn(0, Qt::AscendingOrder);
 
@@ -556,9 +556,9 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
 
     // Build where clause and title
     QString wc = "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % iRule.getSelectSqlOrder() % ')';
-    QString title = i18nc("Noun, a list of items", "Sub operations corresponding to rule '%1'",  iRule.getSearchDescription());
+    QString title = i18nc("Noun, a list of items", "Sub transactions corresponding to rule '%1'",  iRule.getSearchDescription());
 
-    // Call operation plugin
+    // Call transaction plugin
     QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(iMode == TABLE ? QStringLiteral("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS") : QStringLiteral("SKGREPORT_DEFAULT_PARAMETERS")));
     QDomElement root = doc.documentElement();
@@ -574,7 +574,7 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
     if (iMode == TABLE) {
         root.setAttribute(QStringLiteral("operationTable"), QStringLiteral("v_suboperation_consolidated"));
         root.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-1"));
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString(), i18nc("Noun, a list of items", "Sub operations"));
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString(), i18nc("Noun, a list of items", "Sub transactions"));
     } else {
         root.setAttribute(QStringLiteral("period"), QStringLiteral("0"));
         SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge report plugin")), -1, doc.toString());
@@ -619,7 +619,7 @@ void SKGSearchPluginWidget::onEditorModified()
             vNotValidatedl = SKGServices::stringToInt(result.at(1).at(0));
         }
 
-        ui.kQueryInfo->setText(i18np("%1 operation found (%2 imported, %3 not yet validated, %4 not checked).", "%1 operations found (%2 imported, %3 not yet validated, %4 not checked).", vAll, vImported, vNotValidatedl, vNotChecked));
+        ui.kQueryInfo->setText(i18np("%1 transaction found (%2 imported, %3 not yet validated, %4 not checked).", "%1 transactions found (%2 imported, %3 not yet validated, %4 not checked).", vAll, vImported, vNotValidatedl, vNotChecked));
     }
 }
 
