@@ -49,7 +49,7 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(QWidget* iParent, SKGDocument* iDocument)
     });
     addAction(m_menuCurrencies);
 
-    m_menuIndexes = new QAction(i18nc("Financial indexes, used as an indicator of financial places' health. Examples : Dow Jones, CAC40, Nikkei...", "Indexes"), this);
+    m_menuIndexes = new QAction(i18nc("Financial indexes, used as an indicator of financial places' health. Examples : Dow Jones, CAC40, Nikkei…", "Indexes"), this);
     m_menuIndexes->setCheckable(true);
     m_menuIndexes->setChecked(true);
     connect(m_menuIndexes, &QAction::triggered, this, [ = ]() {
@@ -217,7 +217,7 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                             html += "<tr><td><b>" % SKGServices::stringToHtml(lastTitle) % "</b></td></tr>";
                         }
                         html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?operationWhereClause=rc_unit_id=" % SKGServices::intToString(obj.getID()) %
-                                        "&title=" % SKGServices::encodeForUrl(i18nc("A list of operations made on the specified unit", "Operations with unit equal to '%1'",  obj.getName())) %
+                                        "&title=" % SKGServices::encodeForUrl(i18nc("A list of transactions made on the specified unit", "Transactions with unit equal to '%1'",  obj.getName())) %
                                         "&title_icon=taxes-finances&currentPage=-1" % "\">") % SKGServices::stringToHtml(obj.getDisplayName()) % "</a></td><td align=\"right\">";
                         if (obj.getType() == SKGUnitObject::INDEX) {
                             primary.Symbol = ' ';
