@@ -61,7 +61,7 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument)
     setXMLFile(QStringLiteral("skrooge_unit.rc"));
 
     // Menu
-    auto actSplitShare = new QAction(SKGServices::fromTheme(QStringLiteral("format-text-strikethrough")), i18nc("Verb", "Split share..."), this);
+    auto actSplitShare = new QAction(SKGServices::fromTheme(QStringLiteral("format-text-strikethrough")), i18nc("Verb", "Split share…"), this);
     connect(actSplitShare, &QAction::triggered, this, &SKGUnitPlugin::onSplitShare);
     actionCollection()->setDefaultShortcut(actSplitShare, Qt::ALT + Qt::Key_Slash);
     registerGlobalAction(QStringLiteral("edit_split_stock"), actSplitShare, QStringList() << QStringLiteral("unit"), 1, 1, 310);  // TODO(Stephane MANKOWSKI): must be a share
@@ -242,7 +242,7 @@ KConfigSkeleton* SKGUnitPlugin::getPreferenceSkeleton()
 
 QString SKGUnitPlugin::title() const
 {
-    return i18nc("Noun, units for operations, usually currencies or a shares", "Units");
+    return i18nc("Noun, units for transactions, usually currencies or a shares", "Units");
 }
 
 QString SKGUnitPlugin::icon() const
@@ -258,12 +258,12 @@ QString SKGUnitPlugin::toolTip() const
 QStringList SKGUnitPlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tips", "<p>... you can download <a href=\"skg://skrooge_unit_plugin\">units</a>.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... <a href=\"skg://skrooge_unit_plugin\">units</a> can be downloaded <a href=\"skg://tab_configure?page=Skrooge Unit Plugin\">automatically</a> when a document is opened.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can split a <a href=\"skg://skrooge_unit_plugin\">share</a>.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... <a href=\"skg://skrooge_unit_plugin\">units</a> can be merged by drag & drop.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can download more <a href=\"skg://skrooge_unit_plugin\">sources</a> of quote.</p>"));
-    output.push_back(i18nc("Description of a tips", "<p>... you can create and share your own source of quote.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can download <a href=\"skg://skrooge_unit_plugin\">units</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… <a href=\"skg://skrooge_unit_plugin\">units</a> can be downloaded <a href=\"skg://tab_configure?page=Skrooge Unit Plugin\">automatically</a> when a document is opened.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can split a <a href=\"skg://skrooge_unit_plugin\">share</a>.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… <a href=\"skg://skrooge_unit_plugin\">units</a> can be merged by drag & drop.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can download more <a href=\"skg://skrooge_unit_plugin\">sources</a> of quote.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>… you can create and share your own source of quote.</p>"));
 
     return output;
 }
@@ -431,7 +431,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setUUID(QStringLiteral("skgunitplugin_unused"));
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused units"));
-            ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no operation is registered."));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no transaction is registered."));
             QStringList autoCorrections;
             autoCorrections.push_back(QStringLiteral("skg://clean_delete_unused_units"));
             ad.setAutoCorrections(autoCorrections);
