@@ -108,6 +108,13 @@ public:
      */
     QStringList tips() const override;
 
+    /**
+     * The sub plugins services types list of the plugin.
+     * This will be used to display authors in the "About" of the application
+     * @return The sub plugins list of the plugin
+     */
+    QStringList subPlugins() const override;
+
     /**
      * Must be implemented to set the position of the plugin.
      * @return integer value between 0 and 999 (default = 999)
