@@ -79,7 +79,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
             QStringLiteral("highlighted"),
             QLatin1String(""),
             QStringLiteral("all"), Qt::META + Qt::Key_S);
-    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("index"), i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), QLatin1String(""),
+    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("index"), i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40…", "Index"), QLatin1String(""),
             QStringLiteral("t_type='I'"),
             QLatin1String(""),
             QStringLiteral("highlighted"),
@@ -191,7 +191,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     ui.kTypeCreatorUnit->addItem(i18nc("Noun", "Secondary currency"), static_cast<int>(SKGUnitObject::SECONDARY));
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a country's currency", "Currency"), static_cast<int>(SKGUnitObject::CURRENCY));
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial share, as in a stock market", "Share"), static_cast<int>(SKGUnitObject::SHARE));
-    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), static_cast<int>(SKGUnitObject::INDEX));
+    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40…", "Index"), static_cast<int>(SKGUnitObject::INDEX));
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a physical object like a house or a car", "Object"), static_cast<int>(SKGUnitObject::OBJECT));
     bool primaryUnit, secondaryUnit;
     iDocument->existObjects(QStringLiteral("unit"), QStringLiteral("t_type='1'"), primaryUnit);
@@ -518,7 +518,7 @@ void SKGUnitPluginWidget::onModifyUnit()
                     err = unitObj1.merge(unitObj);
                 }
 
-                // Change selection for the rest of the operation
+                // Change selection for the rest of the transaction
                 selection.clear();
                 selection.push_back(unitObj1);
                 nb = 1;
