@@ -229,7 +229,7 @@ QString SKGObjectModel::getAttributeForGrouping(const SKGObjectBase& iObject, co
         return val == QStringLiteral("Y") ? i18n("Yes") : i18n("No");
     } else if (iAttribute == QStringLiteral("t_status")) {
         QString val = iObject.getAttribute(iAttribute);
-        return val == QStringLiteral("N") ? i18n("None") : val == QStringLiteral("P") ? i18n("Pointed") : i18n("Checked");
+        return val == QStringLiteral("N") ? i18n("None") : val == QStringLiteral("P") ? i18n("Marked") : i18n("Checked");
     }
     return SKGObjectModelBase::getAttributeForGrouping(iObject, iAttribute);
 }
@@ -350,6 +350,10 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 unit.NbDecimal = 2;
                 if (!att.contains(QStringLiteral("QUANTITY")) && !att.contains(QStringLiteral("f_BALANCE_ENTERED"))) {
                     unit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                    unit.NbDecimal = SKGServices::stringToInt(obj->getAttribute(QStringLiteral("i_NBDEC")));
+                    if (unit.NbDecimal == 0) {
+                        unit.NbDecimal = 2;
+                    }
                     if (m_unitvalueTable && !m_cacheUnit.Symbol.isEmpty()) {
                         unit = m_cacheUnit;
                     }
@@ -503,8 +507,10 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 }
             }
         } else if (m_accountTable) {
+            SKGAccountObject act(*obj);
             if (att == QStringLiteral("t_BANK")) {
-                QString t_icon = obj->getAttribute(QStringLiteral("t_icon"));
+                const bool wallet = (act.getType() == SKGAccountObject::WALLET);
+                QString t_icon = wallet ? QStringLiteral("wallet-closed") : obj->getAttribute(QStringLiteral("t_icon"));
                 if (t_icon.isEmpty()) {
                     t_icon = obj->getAttribute(QStringLiteral("t_ICON"));
                 }
@@ -513,7 +519,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                     if (fileName.isEmpty()) {
                         fileName = t_icon;
                     }
-                    return QVariant::fromValue(QIcon(fileName));
+                    return QVariant::fromValue(SKGServices::fromTheme(fileName));
                 }
             } else if (att == QStringLiteral("f_importbalance")) {
                 QString val = obj->getAttribute(att);
@@ -522,7 +528,6 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 }
 
                 // Compute value
-                SKGAccountObject act(*obj);
                 auto soluces = act.getPossibleReconciliations(SKGServices::stringToDouble(val), false);
                 return SKGServices::fromTheme(soluces.isEmpty() ? QStringLiteral("security-low") : QStringLiteral("security-high"));
             } else if (att == QStringLiteral("f_reconciliationbalance")) {
@@ -532,7 +537,6 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 }
 
                 // Compute value
-                SKGAccountObject act(*obj);
                 auto soluces = act.getPossibleReconciliations(SKGServices::stringToDouble(val), false);
                 return SKGServices::fromTheme(soluces.isEmpty() ? QStringLiteral("security-low") : QStringLiteral("security-high"));
             }
@@ -909,10 +913,10 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
 
             if (m_operationTable && !m_suboperationTable && toolTipString.isEmpty()) {
                 SKGOperationObject op(*obj);
-                if (op.getStatus() == SKGOperationObject::POINTED) {
-                    toolTipString = i18nc("A tool tip", "This operation is pointed but not checked yet.");
+                if (op.getStatus() == SKGOperationObject::MARKED) {
+                    toolTipString = i18nc("A tool tip", "This transaction is marked but not checked yet.");
                     toolTipString += '\n';
-                    toolTipString += i18nc("A tool tip", "You can use the reconciliation mode to validate pointed operations.");
+                    toolTipString += i18nc("A tool tip", "You can use the reconciliation mode to validate marked transactions.");
                     toolTipString += '\n';
                     if (att == QStringLiteral("t_status")) {
                         toolTipString += i18nc("A tool tip", "Click in this column to switch back status.");
@@ -922,11 +926,11 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                     toolTipString += '\n';
                     toolTipString += i18nc("A tool tip", "Ctrl+click to force checked status.");
                 } else if (op.getStatus() == SKGOperationObject::CHECKED) {
-                    toolTipString = i18nc("A tool tip", "This operation is already checked.");
+                    toolTipString = i18nc("A tool tip", "This transaction is already checked.");
                 } else if (op.getStatus() == SKGOperationObject::NONE) {
-                    toolTipString = i18nc("A tool tip", "This operation is not pointed yet.");
+                    toolTipString = i18nc("A tool tip", "This transaction is not marked yet.");
                     toolTipString += '\n';
-                    toolTipString += i18nc("A tool tip", "Click to set pointed status.");
+                    toolTipString += i18nc("A tool tip", "Click to set marked status.");
                     toolTipString += '\n';
                     toolTipString += i18nc("A tool tip", "Ctrl+click to force checked status.");
                 }
@@ -999,24 +1003,24 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                 SKGObjectBase* objtmp = getObjectPointer(iIndex);
                 if (objtmp != nullptr) {
                     SKGOperationObject obj = SKGOperationObject(objtmp->getDocument(), objtmp->getID());
-                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err)
+                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change transaction status"), err)
                     SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
                     SKGOperationObject::OperationStatus t_status = statusinitial;
                     if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u) {
-                        // 2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
+                        // 2747379: NONE ==> CHECKED, MARKED ==> CHECKED, CHECKED ==> CHECKED
                         t_status = SKGOperationObject::CHECKED;
-                        // t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
+                        // t_status= ( t_status==SKGOperationObject::MARKED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::MARKED : SKGOperationObject::NONE ) );
                     } else {
-                        // 2747379: NONE ==> POINTED, POINTED ==> NONE, CHECKED ==> POINTED
-                        t_status = (t_status == SKGOperationObject::NONE ? SKGOperationObject::POINTED : (t_status == SKGOperationObject::POINTED ? SKGOperationObject::NONE : SKGOperationObject::POINTED));
-                        // t_status=(t_status==SKGOperationObject::POINTED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::POINTED ));
+                        // 2747379: NONE ==> MARKED, MARKED ==> NONE, CHECKED ==> MARKED
+                        t_status = (t_status == SKGOperationObject::NONE ? SKGOperationObject::MARKED : (t_status == SKGOperationObject::MARKED ? SKGOperationObject::NONE : SKGOperationObject::MARKED));
+                        // t_status=(t_status==SKGOperationObject::MARKED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::MARKED ));
                     }
                     if (t_status != statusinitial) {
                         err = obj.setStatus(t_status);
                         IFOKDO(err, obj.save())
 
                         // Send message
-                        IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The status of the operation '%1' has been changed", obj.getDisplayName()), SKGDocument::Hidden))
+                        IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The status of the transaction '%1' has been changed", obj.getDisplayName()), SKGDocument::Hidden))
                     }
                 }
             } else if (m_recurrentoperationTable) {
@@ -1027,7 +1031,7 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                 if (objtmp != nullptr) {
                     SKGRecurrentOperationObject obj = SKGRecurrentOperationObject(objtmp->getDocument(), objtmp->getID());
 
-                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err)
+                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent transaction update"), err)
                     if (att == QStringLiteral("i_warn_days")) {
                         err = obj.warnEnabled(!obj.isWarnEnabled());
                     } else if (att == QStringLiteral("i_auto_write_days")) {
@@ -1038,7 +1042,7 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                     IFOKDO(err, obj.save())
 
                     // Send message
-                    IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The recurrent operation '%1' has been updated", obj.getDisplayName()), SKGDocument::Hidden))
+                    IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The recurrent transaction '%1' has been updated", obj.getDisplayName()), SKGDocument::Hidden))
                 }
             } else if (m_budgetRuleTable) {
                 QString att = m_listAttibutes[iIndex.column()];
