@@ -243,8 +243,8 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     for (int i = 0; i < nb; ++i) {
         const QString& op = listOps.at(i);
         QString nlsOp = SKGRuleObject::getDisplayForOperator(op,
-                        i18nc("Default value", "..."),
-                        i18nc("Default value", "..."),
+                        i18nc("Default value", "…"),
+                        i18nc("Default value", "…"),
                         i18nc("Noun, an item's attribute", "attribute"));
         if (m_kOperator != nullptr) {
             m_kOperator->addItem(nlsOp, op);
