@@ -467,7 +467,7 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
     oInterests = 0;
     bool computationNeeded = false;
 
-    // Add operations
+    // Add transactions
     SKGObjectBase::SKGListSKGObjectBase items;
     err = getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) %
                                     " AND t_template='N' AND t_TYPEUNIT IN ('1', '2', 'C')"
@@ -590,7 +590,7 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
         SKGInterestItem tmp = ioInterestList.at(i);
         SKGObjectBase object = tmp.object;
         if (object.getRealTable() == QStringLiteral("operation")) {
-            // Get operations
+            // Get transactions
             SKGOperationObject op(object);
 
             // Get current amount
@@ -667,7 +667,7 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
             }
 
             // Compute annual interest
-            // BUG 329568: We must ignore operations of the day
+            // BUG 329568: We must ignore transactions of the day
             tmp.amount = getAmount(tmp.valueDate.addDays(-1), true);
             tmp.annualInterest = tmp.amount * tmp.coef * (tmp.rate - currentInterest.rate) / 100;
 
@@ -709,7 +709,7 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
                 "INSERT INTO interest_result (d_date,d_valuedate,t_comment,f_currentamount,f_coef,f_rate,f_annual_interest,f_accrued_interest) "
                 " VALUES ('" % SKGServices::dateToSqlString(interest.date) %
                 "','" % SKGServices::dateToSqlString(interest.valueDate) %
-                "','" % SKGServices::stringToSqlString(object.getRealTable() == QStringLiteral("operation") ? i18nc("Noun", "Relative to operation '%1'", SKGOperationObject(object).getDisplayName()) : i18nc("Noun", "Rate change")) %
+                "','" % SKGServices::stringToSqlString(object.getRealTable() == QStringLiteral("operation") ? i18nc("Noun", "Relative to transaction '%1'", SKGOperationObject(object).getDisplayName()) : i18nc("Noun", "Rate change")) %
                 "'," % SKGServices::doubleToString(interest.amount) %
                 ',' % SKGServices::doubleToString(interest.coef) %
                 ',' % SKGServices::doubleToString(interest.rate) %
@@ -730,15 +730,15 @@ SKGError SKGAccountObject::transferDeferredOperations(const SKGAccountObject& iT
     //
     auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc != nullptr) {
-        // Get pointed operations
-        SKGObjectBase::SKGListSKGObjectBase operations;
-        IFOKDO(err, getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='P'", operations))
-        int nb = operations.count();
+        // Get marked transactions
+        SKGObjectBase::SKGListSKGObjectBase transactions;
+        IFOKDO(err, getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='P'", transactions))
+        int nb = transactions.count();
         if (nb != 0) {
             SKGOperationObject mergedOperations;
             SKGOperationObject balancedOperations;
             for (int i = 0; !err && i < nb; ++i) {
-                SKGOperationObject op(operations.at(i));
+                SKGOperationObject op(transactions.at(i));
 
                 // Create the balance operation
                 SKGOperationObject opdup;
@@ -768,7 +768,7 @@ SKGError SKGAccountObject::transferDeferredOperations(const SKGAccountObject& iT
                 IFOKDO(err, opduptarget.setImported(op.isImported()))
                 IFOKDO(err, opduptarget.setImportID(op.getImportID()))
                 IFOKDO(err, opduptarget.setGroupOperation(mergedOperations))
-                IFOKDO(err, opduptarget.setStatus(SKGOperationObject::POINTED))
+                IFOKDO(err, opduptarget.setStatus(SKGOperationObject::MARKED))
                 IFOKDO(err, opduptarget.save())
                 IFOKDO(err, mergedOperations.load())  // To reload the modif done by the setGroupOperation
 
@@ -804,7 +804,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
         }
         SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, unit1, false) << SKGENDL;
 
-        // Get balance of checked operations
+        // Get balance of checked transactions
         QString balanceString;
         getDocument()->executeSingleSelectSqliteOrder("SELECT f_CHECKED from v_account_display WHERE id=" % SKGServices::intToString(getID()), balanceString);
         double balance = SKGServices::stringToDouble(balanceString);
@@ -819,24 +819,24 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
             output.push_back(QVector<SKGOperationObject>());
             SKGTRACEL(5) << "empty solution found !!!" << SKGENDL;
         } else {
-            // Get all imported operation
-            SKGObjectBase::SKGListSKGObjectBase operations;
-            getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status!='Y' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations);
-            int nb = operations.count();
+            // Get all imported transaction
+            SKGObjectBase::SKGListSKGObjectBase transactions;
+            getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status!='Y' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", transactions);
+            int nb = transactions.count();
 
             if (!iSearchAllPossibleReconciliation) {
-                // Check if all operations are a solution
+                // Check if all transactions are a solution
                 double amount = 0.0;
                 QVector<SKGOperationObject> list;
                 list.reserve(nb);
                 for (int i = 0; i < nb; ++i) {
-                    SKGOperationObject op(operations.at(i));
+                    SKGOperationObject op(transactions.at(i));
                     amount += op.getCurrentAmount();
                     list.push_back(op);
                 }
                 QString sdiff = doc->formatMoney(amount + balance - iTargetBalance * unit1.Value, unit1, false);
                 if (sdiff == zero || sdiff == negativezero) {
-                    SKGTRACEL(5) << "all operations are a solution !!!" << SKGENDL;
+                    SKGTRACEL(5) << "all transactions are a solution !!!" << SKGENDL;
                     output.push_back(list);
                     return output;
                 }
@@ -844,17 +844,17 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
             // Search
             int nbmax = 500;
-            SKGTRACEL(5) << "Nb operations:" << nb << SKGENDL;
+            SKGTRACEL(5) << "Nb transactions:" << nb << SKGENDL;
             if (nb > nbmax) {
-                SKGTRACEL(5) << "Too many operations (" << nb << ") ==> Reducing the size of the computation" << SKGENDL;
+                SKGTRACEL(5) << "Too many transactions (" << nb << ") ==> Reducing the size of the computation" << SKGENDL;
                 for (int i = 0; i < nb - nbmax; ++i) {
-                    SKGOperationObject op(operations.at(0));
+                    SKGOperationObject op(transactions.at(0));
                     auto amount = op.getCurrentAmount();
                     balance += amount;
-                    operations.removeFirst();
+                    transactions.removeFirst();
                 }
             }
-            output = getPossibleReconciliations(operations, balance, iTargetBalance, unit1, iSearchAllPossibleReconciliation);
+            output = getPossibleReconciliations(transactions, balance, iTargetBalance, unit1, iSearchAllPossibleReconciliation);
         }
     }
     return output;
@@ -873,10 +873,10 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
         QString zero = doc->formatMoney(0, iUnit, false);
         QString negativezero = doc->formatMoney(-EPSILON, iUnit, false);
 
-        // Check operations list
+        // Check transactions list
         int nb = iOperations.count();
         if (nb > 0) {
-            // Get all operations of the next date
+            // Get all transactions of the next date
             QVector<SKGOperationObject> nextOperations;
             nextOperations.reserve(iOperations.count());
             QString date = iOperations.at(0).getAttribute(QStringLiteral("d_date"));
@@ -889,9 +889,9 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 }
             }
 
-            // Get all combination of operations
+            // Get all combination of transactions
             int nbNext = nextOperations.count();
-            SKGTRACEL(5) << date << ":" << nbNext << " operations found" << SKGENDL;
+            SKGTRACEL(5) << date << ":" << nbNext << " transactions found" << SKGENDL;
             std::vector<int> v(nbNext);
             for (int i = 0; i < nbNext; ++i) {
                 v[i] = i;
@@ -961,7 +961,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
                 // Check if tests of all combinations can be cancelled
                 if ((previousDiff > 0 && previousDiff + sumOperationsNegatives > 0) || (previousDiff < 0 && previousDiff + sumOperationPositives < 0)) {
-                    SKGTRACEL(5) << "No need to test all combinations due to signs of operations and diffs" << SKGENDL;
+                    SKGTRACEL(5) << "No need to test all combinations due to signs of transactions and diffs" << SKGENDL;
                     stopTests = true;
                 }
 
@@ -1013,15 +1013,15 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         }
 
         // Check all
-        SKGTRACEL(5) << length << " operations pointed" << SKGENDL;
+        SKGTRACEL(5) << length << " transactions marked" << SKGENDL;
         for (int i = 0; i < length; ++i) {
             SKGOperationObject op(soluce.at(i));
-            err = op.setStatus(SKGOperationObject::POINTED);
+            err = op.setStatus(SKGOperationObject::MARKED);
             IFOKDO(err, op.save(true, false))
         }
     } else {
-        err = SKGError(ERR_FAIL, i18nc("Error message",  "Can not find the imported operations for obtaining the expected final balance"),
-                       QString("skg://skrooge_operation_plugin/?title_icon=quickopen&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations of account \"%1\" used for auto reconciliation", getDisplayName())) %
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "Can not find the imported transactions for obtaining the expected final balance"),
+                       QString("skg://skrooge_operation_plugin/?title_icon=quickopen&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Transactions of account \"%1\" used for auto reconciliation", getDisplayName())) %
                                "&operationWhereClause=" % SKGServices::encodeForUrl("rd_account_id=" + SKGServices::intToString(getID()) + " AND t_template='N' AND ((t_status='N' AND t_imported IN ('Y','P')) OR t_status='Y')")));
     }
 
@@ -1044,7 +1044,7 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount, bool iMergeIn
         IFOKDO(err, const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2))
     }
 
-    // Transfer operations
+    // Transfer transactions
     SKGObjectBase::SKGListSKGObjectBase ops;
     IFOKDO(err, iAccount.getOperations(ops))
     int nb = ops.count();
