@@ -185,16 +185,18 @@ public:
     /**
      * Get formated money in primary unit
      * @param iValue value
+     * @param iForcedNbOfDigit the number of digit (-1 means nb of digit of the unit)
      * @return formated value in red or black
      */
-    Q_INVOKABLE QString formatPrimaryMoney(double iValue) const override;
+    Q_INVOKABLE QString formatPrimaryMoney(double iValue, int iForcedNbOfDigit = -1) const override;
 
     /**
      * Get formated money in primary unit
      * @param iValue value
+     * @param iForcedNbOfDigit the number of digit (-1 means nb of digit of the unit)
      * @return formated value in red or black
      */
-    Q_INVOKABLE QString formatSecondaryMoney(double iValue) const override;
+    Q_INVOKABLE QString formatSecondaryMoney(double iValue, int iForcedNbOfDigit = -1) const override;
 
 public Q_SLOTS:
     /**
@@ -232,7 +234,7 @@ protected:
     SKGError migrate(bool& oMigrationDone) override;
 
     /**
-     * Compute balance of each operation.
+     * Compute balance of each transaction.
      * @return an object managing the error.
      *   @see SKGError
      */
