@@ -319,41 +319,41 @@ SKGError SKGImportExportManager::finalizeImportation()
     if (!getImportParameters().contains(QStringLiteral("donotfinalize"))) {
         SKGTRACEINFUNCRC(2, err)
         if (m_document != nullptr) {
-            // Count the number of operations imported but already existing
+            // Count the number of transactions imported but already existing
             QString wc = "v_operation.t_imported='T' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % ')';
             SKGObjectBase::SKGListSKGObjectBase objects;
             err = m_document->getObjects(QStringLiteral("v_operation"), wc, objects);
             int nbOperations = objects.count();
             if (!err && (nbOperations != 0)) {
-                err = m_document->sendMessage(i18np("One operation not imported because it already exists", "%1 operations not imported because they already exist", nbOperations), SKGDocument::Warning);
+                err = m_document->sendMessage(i18np("One transaction not imported because it already exists", "%1 transactions not imported because they already exist", nbOperations), SKGDocument::Warning);
 
                 SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BY IMPORT_ID ###" << SKGENDL;
                 for (int i = 0; i < nbOperations; ++i) {
                     SKGTRACEL(1) << objects.at(i).getDisplayName() << " " << objects.at(i).getAttribute(QStringLiteral("t_import_id")) << SKGENDL;
                 }
 
-                // Remove operations imported for nothing
+                // Remove transactions imported for nothing
                 IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')'))
             }
 
-            // Delete operations before the last import
+            // Delete transactions before the last import
             if (sinceLastImportDate() && !err) {
                 SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-since last date", err)
 
-                // Count the number of operations before the last import
+                // Count the number of transactions before the last import
                 QString wc2 = QStringLiteral("operation.t_imported='T' AND "
                                              "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND date(o.d_date,'-4 day')>operation.d_date)");
                 err = m_document->getObjects(QStringLiteral("operation"), wc2, objects);
                 int nbOperations2 = objects.count();
                 if (!err && (nbOperations2 != 0)) {
-                    err = m_document->sendMessage(i18np("One operation was not imported because it was dated before the last imported one, you can uncheck the option to avoid this.", "%1 operations were not imported because they were dated before the last imported one, you can uncheck the option to avoid this.", nbOperations2), SKGDocument::Warning);
+                    err = m_document->sendMessage(i18np("One transaction was not imported because it was dated before the last imported one, you can uncheck the option to avoid this.", "%1 transactions were not imported because they were dated before the last imported one, you can uncheck the option to avoid this.", nbOperations2), SKGDocument::Warning);
 
                     SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BECAUSE AFTER THE LAST ONE ###" << SKGENDL;
                     for (int i = 0; i < nbOperations2; ++i) {
                         SKGTRACEL(1) << objects.at(i).getDisplayName() << SKGENDL;
                     }
 
-                    // Remove operations imported for nothing
+                    // Remove transactions imported for nothing
                     IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE " % wc2))
                 }
             }
@@ -387,7 +387,7 @@ SKGError SKGImportExportManager::finalizeImportation()
                 SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-change imported status", err)
                 int nbopimported = 0;
                 err = m_document->getNbObjects(QStringLiteral("operation"), QStringLiteral("t_imported='T'"), nbopimported);
-                IFOKDO(err, m_document->sendMessage(i18np("%1 operation imported", "%1 operations imported", nbopimported), SKGDocument::Positive))
+                IFOKDO(err, m_document->sendMessage(i18np("%1 transaction imported", "%1 transactions imported", nbopimported), SKGDocument::Positive))
                 IFOKDO(err, m_document->executeSqliteOrder(QStringLiteral("UPDATE operation SET t_imported='") %
                         (m_automaticValidationOfImportedOperation ? QStringLiteral("Y") : QStringLiteral("P")) %
                         "' WHERE t_imported='T'"));
@@ -407,7 +407,7 @@ SKGError SKGImportExportManager::finalizeImportation()
                 if (soluces.isEmpty()) {
                     IFOKDO(err, m_document->sendMessage(i18nc("Information message", "The balance of account '%1' is not aligned with import balance %2", act.getDisplayName(), m_document->formatMoney(targetBalance, m_document->getPrimaryUnit())),
                                                         SKGDocument::Warning,
-                                                        QString("skg://skrooge_operation_plugin/?title_icon=quickopen&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations of account \"%1\" used for auto reconciliation", act.getDisplayName())) %
+                                                        QString("skg://skrooge_operation_plugin/?title_icon=quickopen&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Transactions of account \"%1\" used for auto reconciliation", act.getDisplayName())) %
                                                                 "&operationWhereClause=" % SKGServices::encodeForUrl("rd_account_id=" + SKGServices::intToString(act.getID()) + " AND t_template='N' AND ((t_status='N' AND t_imported IN ('Y','P')) OR t_status='Y')"))));
                 } else {
                     IFOKDO(err, m_document->sendMessage(i18nc("Information message", "The balance of account '%1' is aligned with import balance %2", act.getDisplayName(), m_document->formatMoney(targetBalance, m_document->getPrimaryUnit())), SKGDocument::Positive))
@@ -675,13 +675,13 @@ SKGError SKGImportExportManager::cleanBankImport()
     if (m_document != nullptr) {
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Clean import"), 3);
         IFOK(err) {
-            // Step 1 Clean operations without mode and with comment with double space
-            SKGObjectBase::SKGListSKGObjectBase operations;
-            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_mode='' and t_comment like '%  %'"), operations))
+            // Step 1 Clean transactions without mode and with comment with double space
+            SKGObjectBase::SKGListSKGObjectBase transactions;
+            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_mode='' and t_comment like '%  %'"), transactions))
 
-            int nb = operations.count();
+            int nb = transactions.count();
             for (int i = 0; !err && i < nb ; ++i) {
-                SKGOperationObject op(operations.at(i));
+                SKGOperationObject op(transactions.at(i));
 
                 // Comment is like this: <TYPE>  <INFO>
                 // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
@@ -702,12 +702,12 @@ SKGError SKGImportExportManager::cleanBankImport()
             // Step 1 done
             IFOKDO(err, m_document->stepForward(1))
 
-            // Step 2 Clean operations without mode and with comment
-            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_mode='' and t_comment!=''"), operations))
+            // Step 2 Clean transactions without mode and with comment
+            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_mode='' and t_comment!=''"), transactions))
 
-            nb = operations.count();
+            nb = transactions.count();
             for (int i = 0; !err && i < nb ; ++i) {
-                SKGOperationObject op(operations.at(i));
+                SKGOperationObject op(transactions.at(i));
 
                 // Comment is like this: <TYPE> <INFO>
                 // Example: RETRAIT DAB 14-05-16607-482390
@@ -729,11 +729,11 @@ SKGError SKGImportExportManager::cleanBankImport()
             IFOKDO(err, m_document->stepForward(2))
 
             // Step 3 Clean cheque without number
-            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_number='' and lower(t_mode)='cheque'"), operations))
+            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_number='' and lower(t_mode)='cheque'"), transactions))
 
-            nb = operations.count();
+            nb = transactions.count();
             for (int i = 0; !err && i < nb ; ++i) {
-                SKGOperationObject op(operations.at(i));
+                SKGOperationObject op(transactions.at(i));
 
                 // Comment is like this: <TYPE>  <INFO>
                 // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
@@ -836,7 +836,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), 3);
         IFOK(err) {
             IFOKDO(err, m_document->executeSqliteOrder(QStringLiteral("ANALYZE")))
-            // Look for operations with
+            // Look for transactions with
             //  Same units
             //  Same dates
             //  Null i_group_id
