@@ -89,7 +89,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, QDate iDa
         }
     }
 
-    // Duplicate grouped operation to support recurrent transfers
+    // Duplicate grouped transaction to support recurrent transfers
     IFOK(err) {
         SKGListSKGObjectBase goupops;
         err = getGroupedOperations(goupops);
@@ -151,7 +151,7 @@ SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount,
     } else {
         if (newAccount != currentAccount) {
             if (iAccount.isClosed() && !iForce) {
-                err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
+                err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add a transaction in a closed account"));
             } else {
                 err = setAttribute(QStringLiteral("rd_account_id"), newAccount);
             }
@@ -208,14 +208,14 @@ SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
         return SKGOperationObject::CHECKED;
     }
     if (t_status == QStringLiteral("P")) {
-        return SKGOperationObject::POINTED;
+        return SKGOperationObject::MARKED;
     }
     return SKGOperationObject::NONE;
 }
 
 SKGError SKGOperationObject::setStatus(SKGOperationObject::OperationStatus iStatus)
 {
-    return setAttribute(QStringLiteral("t_status"), (iStatus == SKGOperationObject::CHECKED ? QStringLiteral("Y") : (iStatus == SKGOperationObject::POINTED ? QStringLiteral("P") : QStringLiteral("N"))));
+    return setAttribute(QStringLiteral("t_status"), (iStatus == SKGOperationObject::CHECKED ? QStringLiteral("Y") : (iStatus == SKGOperationObject::MARKED ? QStringLiteral("P") : QStringLiteral("N"))));
 }
 
 SKGError SKGOperationObject::setDate(QDate iDate, bool iRefreshSubOperations)
@@ -224,7 +224,7 @@ SKGError SKGOperationObject::setDate(QDate iDate, bool iRefreshSubOperations)
     // Compute delta of the change of date
     QDate previousDate = getDate();
     if (iRefreshSubOperations) {
-        // Apply the delta on sub operations
+        // Apply the delta on sub transactions
         SKGObjectBase::SKGListSKGObjectBase listSubOperations;
         getSubOperations(listSubOperations);  // Error is not manage to avoid error in case of first creation
         int nbSubOperations = listSubOperations.count();
@@ -254,7 +254,7 @@ QDate SKGOperationObject::getDate() const
 
 SKGError SKGOperationObject::getUnit(SKGUnitObject& oUnit) const
 {
-    SKGError err = (getDocument() == nullptr ? SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing")) : getDocument()->getObject(QStringLiteral("v_unit"), "id=" % getAttribute(QStringLiteral("rc_unit_id")), oUnit));
+    SKGError err = (getDocument() == nullptr ? SKGError(ERR_POINTER, i18nc("Error message", "Transaction impossible because the document is missing")) : getDocument()->getObject(QStringLiteral("v_unit"), "id=" % getAttribute(QStringLiteral("rc_unit_id")), oUnit));
     // SKGError err = getDocument()->getObject(QStringLiteral("v_unit"), "id=" % getAttribute(QStringLiteral("rc_unit_id")), oUnit);
     return err;
 }
@@ -484,6 +484,110 @@ SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecur
     return err;
 }
 
+int SKGOperationObject::getRecurrentOperation() const
+{
+    const auto recurrentId = SKGServices::stringToInt(getAttribute(QStringLiteral("r_recurrentoperation_id")));
+    if (recurrentId != 0) {
+        return recurrentId;
+    } else {
+        SKGObjectBase::SKGListSKGObjectBase recops;
+        SKGError err = getRecurrentOperations(recops);
+        IFOK(err) {
+            if (!recops.isEmpty()) {
+                return recops.first().getID();
+            }
+        }
+    }
+
+    return 0;
+}
+
+SKGError SKGOperationObject::setRecurrentOperation(int recurrentId)
+{
+    SKGError err;
+    const auto currentRecurrentId = getRecurrentOperation();
+    if (currentRecurrentId != 0 && recurrentId != 0 && currentRecurrentId == recurrentId) {
+        err = SKGError(ERR_FAIL, i18nc("Error message", "Trying to set the same recurrent transaction with id=%1.", recurrentId));
+        return err;
+    } else if (isTemplate()) {
+        err = SKGError(ERR_FAIL, i18nc("Error message", "Cannot set a recurrent for a template operation."));
+        return err;
+    }
+
+    SKGRecurrentOperationObject oldRop(getDocument(), currentRecurrentId);
+    SKGRecurrentOperationObject newRop(getDocument(), recurrentId);
+    if (oldRop.exist()) {
+        // Unlink from the current schedule
+        SKGOperationObject oldRopParent;
+        err = oldRop.getParentOperation(oldRopParent);
+        if (oldRopParent == *this) {
+            SKGObjectBase::SKGListSKGObjectBase transactions;
+            IFOKDO(err, oldRop.getRecurredOperations(transactions))
+            IFOK(err) {
+                if (!transactions.isEmpty()) {
+                    SKGOperationObject lastObj(transactions.last());
+                    IFOKDO(err, oldRop.setParentOperation(lastObj))
+                    IFOKDO(err, oldRop.setDate(lastObj.getDate()))
+                    IFOKDO(err, oldRop.setDate(oldRop.getNextDate()))
+                    IFOKDO(err, oldRop.save())
+                    IFOKDO(err, lastObj.setAttribute(QStringLiteral("r_recurrentoperation_id"), QString("0")))
+                    IFOKDO(err, lastObj.save())
+                } else {
+                    IFOKDO(err, oldRop.remove(true, true))
+                }
+            }
+        }
+
+        IFOKDO(err, setAttribute(QStringLiteral("r_recurrentoperation_id"), QString("0")))
+        IFOKDO(err, save())
+    }
+
+    if (newRop.exist()) {
+        // Link to a new schedule
+        const auto currentDate = getDate();
+        QDate lastDate;
+        SKGOperationObject newRopParent;
+        err = newRop.getParentOperation(newRopParent);
+        if (newRopParent.isTemplate()) {
+            SKGObjectBase::SKGListSKGObjectBase transactions;
+            IFOKDO(err, newRop.getRecurredOperations(transactions))
+            IFOK(err) {
+                if (!transactions.isEmpty()) {
+                    SKGOperationObject lastObj(transactions.last());
+                    lastDate = lastObj.getDate();
+                }
+            }
+        } else {
+            lastDate = newRopParent.getDate();
+        }
+        if (currentDate.isValid() && lastDate.isValid() && currentDate >= lastDate) {
+            IFOK(err) {
+                if (!newRopParent.isTemplate()) {
+                    // Set old parent op as recurrent
+                    IFOKDO(err, newRopParent.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
+                    IFOKDO(err, newRopParent.save())
+
+                    // Set this transaction as reference
+                    IFOKDO(err, newRop.setParentOperation(*this))
+                } else {
+                    // Set this op as recurrent
+                    IFOKDO(err, setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
+                    IFOKDO(err, save())
+                }
+
+                IFOKDO(err, newRop.setDate(currentDate))
+                IFOKDO(err, newRop.setDate(newRop.getNextDate()))
+                IFOKDO(err, newRop.save())
+            }
+        } else {
+            IFOKDO(err, setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
+            IFOKDO(err, save())
+        }
+    }
+
+    return err;
+}
+
 SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOne, SKGOperationObject::AmountAlignmentMode iMode, bool iSendMessage)
 {
     // Merge operation
@@ -510,7 +614,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     }
     IFOKDO(err, save())
 
-    // Merge suboperations
+    // Merge subtransactions
     double currentAmount = getCurrentAmount();
     double targettAmount = iDeletedOne.getCurrentAmount();
     if (qAbs(currentAmount - targettAmount) > 0.0001) {
@@ -531,7 +635,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
         }
 
         if (mode == SKGOperationObject::ADDSUBOPERATION) {
-            // Add sub operation to align amount
+            // Add sub transaction to align amount
             SKGSubOperationObject so1;
             IFOKDO(err, addSubOperation(so1))
             IFOKDO(err, so1.setQuantity(targettAmount - currentAmount))
@@ -546,7 +650,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
         }
         IFOKDO(err, load())
         if (iSendMessage) {
-            IFOK(err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
+            IFOK(err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported transaction"), SKGDocument::Positive);
         }
     }
 
