@@ -63,6 +63,69 @@ SKGError SKGRecurrentOperationObject::setParentOperation(const SKGOperationObjec
     return setAttribute(QStringLiteral("rd_operation_id"), SKGServices::intToString(iOperation.getID()));
 }
 
+SKGError SKGRecurrentOperationObject::setTemplate(bool iTemplate)
+{
+    SKGError err;
+
+    if (iTemplate == isTemplate()) {
+        err.addError(ERR_UNEXPECTED, i18nc("Error message", "Trying to set the same template status \"%1\" to a recurrent operation", iTemplate));
+        return err;
+    }
+
+    SKGOperationObject parentOp;
+    err = getParentOperation(parentOp);
+    if (iTemplate) {
+        // Convert to template
+        SKGOperationObject operationObjOrig = parentOp;
+        IFOKDO(err, operationObjOrig.duplicate(parentOp, operationObjOrig.getDate(), true))
+
+        IFOKDO(err, setParentOperation(parentOp))
+        IFOKDO(err, save())
+
+        IFOKDO(err, operationObjOrig.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(getID())))
+        IFOKDO(err, operationObjOrig.save())
+    } else {
+        // Convert to non-template
+        SKGObjectBase::SKGListSKGObjectBase transactions;
+        IFOKDO(err, getRecurredOperations(transactions))
+        IFOK(err) {
+            if (!transactions.isEmpty()) {
+                SKGOperationObject lastObj(transactions.last());
+                IFOKDO(err, setParentOperation(lastObj))
+                IFOKDO(err, save())
+                IFOKDO(err, lastObj.setAttribute(QStringLiteral("r_recurrentoperation_id"), QString()))
+                IFOKDO(err, lastObj.save())
+
+                SKGObjectBase::SKGListSKGObjectBase goupops;
+                IFOKDO(err, parentOp.getGroupedOperations(goupops))
+                IFOK(err) {
+                    int nbgoupops = goupops.count();
+                    for (int i = 0; !err && i < nbgoupops; ++i) {
+                        SKGOperationObject groupop(goupops.at(i));
+                        if (groupop != parentOp) {
+                            IFOKDO(err, groupop.remove(true))
+                        }
+                    }
+                }
+
+                IFOKDO(err, parentOp.remove(true))
+            } else {
+                err.addError(ERR_FAIL, i18nc("Error message", "Need at least one transaction to convert a schedule to a non-template one"));
+            }
+        }
+    }
+
+    return err;
+}
+
+bool SKGRecurrentOperationObject::isTemplate() const
+{
+    SKGOperationObject op;
+    SKGError err = getParentOperation(op);
+    IFOK(err) return op.isTemplate();
+    return false;
+}
+
 SKGError SKGRecurrentOperationObject::setPeriodIncrement(int iIncrement)
 {
     return setAttribute(QStringLiteral("i_period_increment"), SKGServices::intToString(iIncrement));
@@ -210,7 +273,7 @@ bool SKGRecurrentOperationObject::isAutoWriteEnabled() const
 
 SKGError SKGRecurrentOperationObject::getRecurredOperations(SKGListSKGObjectBase& oOperations) const
 {
-    return getDocument()->getObjects(QStringLiteral("v_operation"), "r_recurrentoperation_id=" % SKGServices::intToString(getID()), oOperations);
+    return getDocument()->getObjects(QStringLiteral("v_operation"), "r_recurrentoperation_id=" % SKGServices::intToString(getID()) % " ORDER BY d_date", oOperations);
 }
 
 SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, QDate iDate)
@@ -229,26 +292,13 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, QDa
                     // Create the duplicated operation
                     SKGOperationObject newOp;
                     err = op.duplicate(newOp, nextDate);
+                    IFOKDO(err, newOp.setRecurrentOperation(getID()))
+                    IFOKDO(err, load())
 
-                    if (!op.isTemplate()) {
-                        // Set old op as recurrent
-                        IFOKDO(err, op.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(getID())))
-                        IFOKDO(err, op.save())
-
-                        // Set new operation as reference
-                        IFOKDO(err, setParentOperation(newOp))
-                    } else {
-                        // Set new op as recurrent
-                        IFOKDO(err, newOp.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(getID())))
-                        IFOKDO(err, newOp.save())
-                    }
-
-                    IFOKDO(err, setDate(getNextDate()))
                     if (!err && hasTimeLimit()) {
                         err = setTimeLimit(getTimeLimit() - 1);
                     }
                     IFOKDO(err, save())
-                    IFOKDO(err, load())
 
                     // Process again in case of multi insert needed
                     int nbi = 0;
@@ -258,7 +308,7 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, QDa
                     // Send message
                     IFOKDO(err, newOp.load())
                     IFOK(err) {
-                        err = getDocument()->sendMessage(i18nc("An information message", "Operation '%1' has been inserted", newOp.getDisplayName()), SKGDocument::Positive);
+                        err = getDocument()->sendMessage(i18nc("An information message", "Transaction '%1' has been inserted", newOp.getDisplayName()), SKGDocument::Positive);
                     }
                 }
             }
@@ -272,7 +322,7 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, QDa
                 IFOK(err) {
                     int nbdays = QDate::currentDate().daysTo(nextDate);
                     if (nbdays > 0) {
-                        err = getDocument()->sendMessage(i18np("Operation '%2' will be inserted in one day", "Operation '%2' will be inserted in %1 days", nbdays, getDisplayName()));
+                        err = getDocument()->sendMessage(i18np("Transaction '%2' will be inserted in one day", "Transaction '%2' will be inserted in %1 days", nbdays, getDisplayName()));
                     }
                 }
             }
@@ -286,7 +336,7 @@ SKGError SKGRecurrentOperationObject::process(SKGDocumentBank* iDocument, int& o
     SKGError err;
     oNbInserted = 0;
 
-    // Get all operation with auto_write
+    // Get all transaction with auto_write
     SKGListSKGObjectBase recuOps;
     if (iDocument != nullptr) {
         err = iDocument->getObjects(QStringLiteral("v_recurrentoperation"), QLatin1String(""), recuOps);
