@@ -165,7 +165,7 @@ QVariantList SKGReportBank::getPortfolio()
             if (doc != nullptr) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
-                // Get list of operations
+                // Get list of transactions
                 SKGObjectBase::SKGListSKGObjectBase objs;
                 auto sqlFilter = getSqlFilter();
                 if (sqlFilter.isEmpty()) {
@@ -753,7 +753,7 @@ void SKGReportBank::addItemsInMapping(QVariantHash& iMapping)
                     "What should you do now ?<br/>"
                     "<ul>"
                     "<li>Create at least one <a href=\"%1\">account</a></li>"
-                    "<li>Add some operations, using <a href=\"%3\">import</a> or <a href=\"%2\">manual input</a></li>"
+                    "<li>Add some transactions, using <a href=\"%3\">import</a> or <a href=\"%2\">manual input</a></li>"
                     "<li>Categorize them</li>"
                     "</ul>"
                     "<p>You may come back to this page any time by closing all tabs.<br/>"
@@ -774,14 +774,14 @@ void SKGReportBank::addItemsInMapping(QVariantHash& iMapping)
     iMapping.insert(QStringLiteral("title_portfolio"), i18nc("A monthly report title", "Stock portfolio"));
     iMapping.insert(QStringLiteral("title_interests"), i18nc("A monthly report title", "Estimated interests"));
     iMapping.insert(QStringLiteral("title_alarms"), i18nc("A monthly report title", "Alarms"));
-    iMapping.insert(QStringLiteral("title_highlighted"), i18nc("A monthly report title", "Highlighted operations"));
+    iMapping.insert(QStringLiteral("title_highlighted"), i18nc("A monthly report title", "Highlighted transactions"));
     iMapping.insert(QStringLiteral("title_networth"), i18nc("A monthly report title", "Net Worth"));
     iMapping.insert(QStringLiteral("title_annual_spending"), i18nc("A monthly report title", "Annual Spending"));
     iMapping.insert(QStringLiteral("title_personal_finance_score"), i18nc("A monthly report title", "Personal Finance Score"));
 
     iMapping.insert(QStringLiteral("msg_no_variation"), i18nc("A monthly report message", "No variation found."));
-    iMapping.insert(QStringLiteral("msg_no_scheduled"), i18nc("A monthly report message", R"(No scheduled operations defined on the "<a href="%1">Scheduled operations</a>" page.)", "skg://Skrooge_scheduled_plugin/"));
-    iMapping.insert(QStringLiteral("msg_no_highlighted"), i18nc("A monthly report message", R"(No highlighted operations defined on the "<a href="%1">Operations</a>" page.)", "skg://Skrooge_operation_plugin/"));
+    iMapping.insert(QStringLiteral("msg_no_scheduled"), i18nc("A monthly report message", R"(No scheduled transactions defined on the "<a href="%1">Scheduled transactions</a>" page.)", "skg://Skrooge_scheduled_plugin/"));
+    iMapping.insert(QStringLiteral("msg_no_highlighted"), i18nc("A monthly report message", R"(No highlighted transactions defined on the "<a href="%1">Transactions</a>" page.)", "skg://Skrooge_operation_plugin/"));
     iMapping.insert(QStringLiteral("msg_no_budget"), i18nc("A monthly report message", R"(No budget defined on the "<a href="%1">Budget</a>" page.)", "skg://Skrooge_budget_plugin/"));
     iMapping.insert(QStringLiteral("msg_no_share"), i18nc("A monthly report message", R"(No share defined on the "<a href="%1">Unit</a>" page.)", "skg://Skrooge_unit_plugin/"));
     iMapping.insert(QStringLiteral("msg_amount_unit_date"), i18nc("A monthly report message", "All amounts are calculated using the unit rates of the last day of the corresponding period."));
