@@ -257,7 +257,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 if (!err && result.count() == 2) {
                     int nbChanges = SKGServices::stringToInt(result.at(1).at(0));
                     if (nbChanges != 0) {
-                        doc->sendMessage(i18np("1 operation modified by %2", "%1 operations modified by %2", nbChanges, getAttribute(QStringLiteral("i_ORDER"))));
+                        doc->sendMessage(i18np("1 transaction modified by %2", "%1 transactions modified by %2", nbChanges, getAttribute(QStringLiteral("i_ORDER"))));
                     }
                 }
             }
@@ -304,7 +304,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 // Get template
                 SKGOperationObject templateToApply(doc, SKGServices::stringToInt(id));
 
-                // Get operations to modify
+                // Get transactions to modify
                 SKGObjectBase::SKGListSKGObjectBase objectsToModify;
                 IFOKDO(err, doc->getObjects(QStringLiteral("v_operation_prop"), wc, objectsToModify))
                 int nb = objectsToModify.count();
@@ -331,115 +331,115 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
 {
     QString output = iOperator;
     if (output == QStringLiteral("#ATT# LIKE '%#V1S#%'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "contains '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "contains '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT# NOT LIKE '%#V1S#%'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "does not contain '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "does not contain '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT# LIKE '#V1S#%'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "starts with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "starts with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT# NOT LIKE '#V1S#%'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "does not start with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "does not start with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT# LIKE '%#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "ends with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "ends with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT# NOT LIKE '%#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "does not end with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "does not end with '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#=''")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is empty");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is empty");
     } else if (output == QStringLiteral("#ATT#!=''")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not empty");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is not empty");
     } else if (output == QStringLiteral("#ATT#=REGEXPCAPTURE('#V1S#', #ATT2#, #V2#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=regexpcapture(#ATT2#, '#V1S#', #V2#)").replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#V2#"), iParam2).replace(QStringLiteral("#ATT2#"), iAtt2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=regexpcapture(#ATT2#, '#V1S#', #V2#)").replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#V2#"), iParam2).replace(QStringLiteral("#ATT2#"), iAtt2);
     } else if (output == QStringLiteral("REGEXP('#V1S#', #ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "regexp '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "regexp '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("NOT(REGEXP('#V1S#', #ATT#))")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "not regexp '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "not regexp '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("WILDCARD('#V1S#', #ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "wildcard '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "wildcard '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("NOT(WILDCARD('#V1S#', #ATT#))")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "not wildcard '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "not wildcard '#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#=#V1#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#V1#").replace(QStringLiteral("#V1#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=#V1#").replace(QStringLiteral("#V1#"), iParam1);
     } else if (output == QStringLiteral("#ATT#!=#V1#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!=#V1#").replace(QStringLiteral("#V1#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "!=#V1#").replace(QStringLiteral("#V1#"), iParam1);
     } else if (output == QStringLiteral("#ATT#>#V1#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">#V1#").replace(QStringLiteral("#V1#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", ">#V1#").replace(QStringLiteral("#V1#"), iParam1);
     } else if (output == QStringLiteral("#ATT#<#V1#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<#V1#").replace(QStringLiteral("#V1#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "<#V1#").replace(QStringLiteral("#V1#"), iParam1);
     } else if (output == QStringLiteral("#ATT#>=#V1#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">=#V1#").replace(QStringLiteral("#V1#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", ">=#V1#").replace(QStringLiteral("#V1#"), iParam1);
     } else if (output == QStringLiteral("#ATT#<=#V1#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<=#V1#").replace(QStringLiteral("#V1#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "<=#V1#").replace(QStringLiteral("#V1#"), iParam1);
     } else if (output == QStringLiteral("#ATT#='#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#!='#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "!='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "!='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#>'#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">'#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", ">'#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#<'#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<'#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "<'#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#>='#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", ">='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", ">='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#<='#V1S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "<='#V1S#'").replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#>=#V1# AND #ATT#<=#V2#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between #V1# and #V2#").replace(QStringLiteral("#V1#"), iParam1).replace(QStringLiteral("#V2#"), iParam2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is between #V1# and #V2#").replace(QStringLiteral("#V1#"), iParam1).replace(QStringLiteral("#V2#"), iParam2);
     } else if (output == QStringLiteral("((#ATT#>='#V1S#' AND #ATT#<='#V2S#') OR (#ATT#>='#V2S#' AND #ATT#<='#V1S#'))")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between '#V1S#' and '#V2S#'").replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#V2S#"), iParam2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is between '#V1S#' and '#V2S#'").replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#V2S#"), iParam2);
     } else if (output == QStringLiteral("#ATT#=lower(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to lower");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is set to lower");
     } else if (output == QStringLiteral("#ATT#=upper(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to upper");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is set to upper");
     } else if (output == QStringLiteral("#ATT#=capitalize(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to capitalize");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is set to capitalize");
     } else if (output == QStringLiteral("#ATT#!=lower(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not lower");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is not lower");
     } else if (output == QStringLiteral("#ATT#!=upper(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not upper");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is not upper");
     } else if (output == QStringLiteral("#ATT#!=capitalize(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not capitalize");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is not capitalize");
     } else if (output == QStringLiteral("#ATT#= lower(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is lower");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is lower");
     } else if (output == QStringLiteral("#ATT#= upper(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is upper");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is upper");
     } else if (output == QStringLiteral("#ATT#= capitalize(#ATT#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is capitalize");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is capitalize");
     } else if (output == QStringLiteral("#ATT#=replace(#ATT2#,'#V1S#','#V2S#')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# with '#V1S#' replaced by '#V2S#'").replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#V2S#"), iParam2).replace(QStringLiteral("#ATT2#"), iAtt2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=#ATT2# with '#V1S#' replaced by '#V2S#'").replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#V2S#"), iParam2).replace(QStringLiteral("#ATT2#"), iAtt2);
     } else if (output == QStringLiteral("#ATT#=substr(#ATT2#,'#V1#','#V2#')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=substring of #ATT2# from #V1# to #V2#").replace(QStringLiteral("#V1#"), iParam1).replace(QStringLiteral("#V2#"), iParam2).replace(QStringLiteral("#ATT2#"), iAtt2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=substring of #ATT2# from #V1# to #V2#").replace(QStringLiteral("#V1#"), iParam1).replace(QStringLiteral("#V2#"), iParam2).replace(QStringLiteral("#ATT2#"), iAtt2);
     } else if (output == QStringLiteral("#ATT#=#ATT2#")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2#").replace(QStringLiteral("#ATT2#"), iAtt2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=#ATT2#").replace(QStringLiteral("#ATT2#"), iAtt2);
     } else if (output == QStringLiteral("#ATT#=WORD(#ATT2#,#V1S#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#)").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#V1S#"), iParam1);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=word(#ATT2#,#V1S#)").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#V1S#"), iParam1);
     } else if (output == QStringLiteral("#ATT#=todate(#ATT2#,'#DF#')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# as date with format #DF#").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#DF#"), iParam2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=#ATT2# as date with format #DF#").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#DF#"), iParam2);
     } else if (output == QStringLiteral("#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#) as date with format #DF#").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#DF#"), iParam2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "=word(#ATT2#,#V1S#) as date with format #DF#").replace(QStringLiteral("#ATT2#"), iAtt2).replace(QStringLiteral("#V1S#"), iParam1).replace(QStringLiteral("#DF#"), iParam2);
     } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime'))")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current month");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in current month");
     } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime','start of month','-1 month'))")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous month");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in previous month");
     } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime'))")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current year");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in current year");
     } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime','start of month','-1 year'))")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in previous year");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in previous year");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-30 day') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 30 days");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in last 30 days");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 month') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 months");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in last 3 months");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-6 month') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 6 months");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in last 6 months");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-12 month') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 12 months");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in last 12 months");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-2 year') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 2 years");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in last 2 years");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 year') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 3 years");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in last 3 years");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-5 year') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 5 years");
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "is in last 5 years");
     } else if (output == QStringLiteral("ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "If total(#ATT#)#OP##V1# then send '#V2S#'").replace(QStringLiteral("#V1#"), iParam1).replace(QStringLiteral("#V2S#"), iParam2).replace(QStringLiteral("#OP#"), iAtt2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "If total(#ATT#)#OP##V1# then send '#V2S#'").replace(QStringLiteral("#V1#"), iParam1).replace(QStringLiteral("#V2S#"), iParam2).replace(QStringLiteral("#OP#"), iAtt2);
     } else if (output == QStringLiteral("APPLYTEMPLATE(#V1#)")) {
-        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "Apply the template '#V2S#'").replace(QStringLiteral("#V2S#"), iParam2);
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, …)", "Apply the template '#V2S#'").replace(QStringLiteral("#V2S#"), iParam2);
     }
 
     return output;
@@ -533,27 +533,27 @@ QString SKGRuleObject::getToolTipForOperator(const QString& iOperator)
     } else if (output == QStringLiteral("#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')")) {
         output = i18nc("Help for a condition", "To set the date attribute with a word of another attribute converted in date format");
     } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime'))")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is today");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is today");
     } else if (output == QStringLiteral("STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now', 'localtime','start of month','-1 month'))")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in previous month");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in previous month");
     } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime'))")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in current year");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in current year");
     } else if (output == QStringLiteral("STRFTIME('%Y',#ATT#)=STRFTIME('%Y',date('now', 'localtime','start of month','-1 year'))")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in previous year");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in previous year");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-30 day') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in last 30 days");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in last 30 days");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 month') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in last 3 months");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in last 3 months");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-6 month') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in last 6 months");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in last 6 months");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-12 month') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in last 12 months");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in last 12 months");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-2 year') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in last 2 years");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in last 2 years");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-3 year') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in last 3 years");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in last 3 years");
     } else if (output == QStringLiteral("#ATT#>date('now', 'localtime','-5 year') AND #ATT#<=date('now', 'localtime')")) {
-        output = i18nc("Help for a condition", "To find out if the date of the operation is in last 5 years");
+        output = i18nc("Help for a condition", "To find out if the date of the transaction is in last 5 years");
     }
 
     return output;
