@@ -136,9 +136,9 @@ SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker, boo
     getTracker(previous);
     if (iTracker != previous) {
         if (!iForce && previous.isClosed()) {
-            err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to remove an operation from a closed tracker"));
+            err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to remove a transaction from a closed tracker"));
         } else if (!iForce && iTracker.isClosed()) {
-            err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
+            err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add a transaction in a closed tracker"));
         } else {
             err = setAttribute(QStringLiteral("r_refund_id"), SKGServices::intToString(iTracker.getID()));
         }
