@@ -20,7 +20,7 @@ SKGDateEdit::SKGDateEdit(QWidget* iParent, const char* name)
 {
     setObjectName(name);
     setMode(CURRENT);
-    setToolTip(i18n("Date of the operation\nup or down to add or remove one day\nCTRL + up or CTRL + down to add or remove one month"));
+    setToolTip(i18n("Date of the transaction\nup or down to add or remove one day\nCTRL + up or CTRL + down to add or remove one month"));
 }
 
 SKGDateEdit::~SKGDateEdit()
