@@ -79,7 +79,7 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     QAction* actPrint = m_mainMenu->addAction(ui.kPrint->icon(), ui.kPrint->toolTip());
     connect(actPrint, &QAction::triggered, this, &SKGGraphicsView::onPrint);
 
-    QAction* actExport = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export..."));
+    QAction* actExport = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export…"));
     connect(actExport, &QAction::triggered, this, &SKGGraphicsView::onExport);
 
     connect(graphicsView(), &QHeaderView::customContextMenuRequested, this, &SKGGraphicsView::showMenu);
