@@ -23,11 +23,11 @@ SKGPeriodEdit::SKGPeriodEdit(QWidget* iParent, bool iModeEnabled)
     this->setFocusProxy(ui.kPeriod);
 
     ui.kPeriod->addItem(i18nc("Period mode", "All Dates"), static_cast<int>(SKGPeriodEdit::ALL));
-    ui.kPeriod->addItem(i18nc("Period mode", "Current..."), static_cast<int>(SKGPeriodEdit::CURRENT));
-    ui.kPeriod->addItem(i18nc("Period mode", "Previous..."), static_cast<int>(SKGPeriodEdit::PREVIOUS));
-    ui.kPeriod->addItem(i18nc("Period mode", "Last..."), static_cast<int>(SKGPeriodEdit::LAST));
-    ui.kPeriod->addItem(i18nc("Period mode", "Custom..."), static_cast<int>(SKGPeriodEdit::CUSTOM));
-    ui.kPeriod->addItem(i18nc("Period mode", "Timeline..."), static_cast<int>(SKGPeriodEdit::TIMELINE));
+    ui.kPeriod->addItem(i18nc("Period mode", "Current…"), static_cast<int>(SKGPeriodEdit::CURRENT));
+    ui.kPeriod->addItem(i18nc("Period mode", "Previous…"), static_cast<int>(SKGPeriodEdit::PREVIOUS));
+    ui.kPeriod->addItem(i18nc("Period mode", "Last…"), static_cast<int>(SKGPeriodEdit::LAST));
+    ui.kPeriod->addItem(i18nc("Period mode", "Custom…"), static_cast<int>(SKGPeriodEdit::CUSTOM));
+    ui.kPeriod->addItem(i18nc("Period mode", "Timeline…"), static_cast<int>(SKGPeriodEdit::TIMELINE));
 
     ui.kInterval->addItem(i18nc("Period interval", "day(s)"), 0);
     ui.kInterval->addItem(i18nc("Period interval", "week(s)"), 1);
@@ -117,7 +117,7 @@ void SKGPeriodEdit::setState(const QString& iState)
 
 QString SKGPeriodEdit::text() const
 {
-    QString during = ui.kPeriod->text().remove(QStringLiteral("..."));
+    QString during = ui.kPeriod->text().remove(QStringLiteral("…"));
 
     SKGPeriodEdit::PeriodMode m = mode();
     if (m == CUSTOM || m == TIMELINE) {
@@ -473,10 +473,10 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         ui.kDateEnd->setDate(b);
         wc = sqlAttribute % ">=(SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
         if (iForecast) {
-            wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled operations
+            wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled transactions
 
             if (oWhereClausForPreviousData != nullptr) {
-                *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
+                *oWhereClausForPreviousData = sqlAttribute % " <= (SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
             }
             if (oWhereClausForForecastData != nullptr) {
                 *oWhereClausForForecastData = sqlAttribute % " > (SELECT period(date('now', 'localtime','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";
@@ -491,9 +491,9 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
 
-        wc = "d_date > (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
+        wc = "d_date >= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
         if (iForecast) {
-            wc += QStringLiteral(" AND d_date<=(SELECT date('now', 'localtime'))");    // For forecast based on scheduled operations
+            wc += QStringLiteral(" AND d_date<=(SELECT date('now', 'localtime'))");    // For forecast based on scheduled transactions
         }
 
         if (ui.kFuture->isChecked()) {
@@ -510,7 +510,7 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         // Custom Date
         wc = "d_date>='" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
         if (iForecast) {
-            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % '\'';    // For forecast based on scheduled operations
+            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % '\'';    // For forecast based on scheduled transactions
         }
         if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
@@ -525,7 +525,7 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         ui.kDateEnd->setDate(b);
         wc = "d_date>='" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
         if (iForecast) {
-            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % '\'';    // For forecast based on scheduled operations
+            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % '\'';    // For forecast based on scheduled transactions
         }
         if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
