@@ -581,7 +581,7 @@ void SKGTreeView::setupHeaderMenu()
         }
         m_headerMenu->addSeparator();
 
-        QAction* actExport = m_headerMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export..."));
+        QAction* actExport = m_headerMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export…"));
         connect(actExport, &QAction::triggered, this, &SKGTreeView::onExport);
 
         if (m_autoResize) {
