@@ -187,12 +187,12 @@ void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
         menu->addAction(pageAction(QWebPage::Copy));
 #endif
 
-        QAction* actPrint = menu->addAction(SKGServices::fromTheme(QStringLiteral("printer")), i18nc("Action", "Print..."));
+        QAction* actPrint = menu->addAction(SKGServices::fromTheme(QStringLiteral("printer")), i18nc("Action", "Print…"));
         connect(actPrint, &QAction::triggered, this, &SKGWebView::onPrint);
 
         menu->addAction(KStandardAction::printPreview(this, SLOT(onPrintPreview()), this));
 
-        QAction* actExport = menu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export..."));
+        QAction* actExport = menu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export…"));
         connect(actExport, &QAction::triggered, this, &SKGWebView::onExport);
 
         menu->popup(this->mapToGlobal(iEvent->pos()));
