@@ -118,7 +118,7 @@ public:
         QString id;         /**< Identifier of the schema */
         QString name;       /**< The nls name */
         QString icon;       /**< The icon */
-        QString schema;     /**< The schema. The format of this string is the following one: attribute name[|visibility Y or N[|size]];attribute name[|visibility Y or N[|size]];... */
+        QString schema;     /**< The schema. The format of this string is the following one: attribute name[|visibility Y or N[|size]];attribute name[|visibility Y or N[|size]];… */
     };
 
     /**
@@ -393,7 +393,7 @@ public:
      * @param iAsColumn Attribute used as column names
      * @param iAsRow Attribute used as lines names
      * @param iAttribute Attribute
-     * @param iOpAtt Operation to apply on @p iAttribute
+     * @param iOpAtt Transaction to apply on @p iAttribute
      * @param iWhereClause Where clause
      * @param oTable the consolidated view
      * @param iMissingValue value to put if no value found
@@ -744,16 +744,18 @@ public:
     /**
      * Get formated money in primary unit
      * @param iValue value
+     * @param iForcedNbOfDigit the number of digit (-1 means nb of digit of the unit)
      * @return formated value in red or black
      */
-    Q_INVOKABLE virtual QString formatPrimaryMoney(double iValue) const;
+    Q_INVOKABLE virtual QString formatPrimaryMoney(double iValue, int iForcedNbOfDigit = -1) const;
 
     /**
      * Get formated money in primary unit
      * @param iValue value
+     * @param iForcedNbOfDigit the number of digit (-1 means nb of digit of the unit)
      * @return formated value in red or black
      */
-    Q_INVOKABLE virtual QString formatSecondaryMoney(double iValue) const;
+    Q_INVOKABLE virtual QString formatSecondaryMoney(double iValue, int iForcedNbOfDigit = -1) const;
 
     /**
      * Get formated percentage
