@@ -235,7 +235,7 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
     if (Q_LIKELY(iValue != NOUPDATE)) {
         QString val = iValue;
 
-        // Case modification on pointed document
+        // Case modification on marked document
         if (this->getRealTable() == this->getTable() && iName != iName.toLower()) {
             QString realAttribute = d->document->getRealAttribute(iName);
             if (!realAttribute.isEmpty()) {
@@ -296,7 +296,7 @@ QString SKGObjectBase::getAttribute(const QString& iName) const
                 output = d->attributes[keys.at(pos)];
             }
         } else {
-            // Case modification on pointed document iName1.(iTable2)iName2 or iName1.iName2
+            // Case modification on marked document iName1.(iTable2)iName2 or iName1.iName2
             int pos = iName.indexOf('.');
             if (pos != -1) {
                 QString attributeref = iName.left(pos);
@@ -403,7 +403,7 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
     SKGTRACEINFUNCRC(20, err)
 
     if (Q_UNLIKELY(!d->document)) {
-        err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+        err = SKGError(ERR_POINTER, i18nc("Error message", "Transaction impossible because the document is missing"));
     } else {
         // Save linking objects
         int nb = d->objects.count();
@@ -480,7 +480,7 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
     SKGError err;
     SKGTRACEINFUNCRC(20, err)
     if (Q_UNLIKELY(!d->document)) {
-        err = SKGError(ERR_POINTER, i18nc("Error message", "Operation impossible because the document is missing"));
+        err = SKGError(ERR_POINTER, i18nc("Error message", "Transaction impossible because the document is missing"));
     } else {
         // Check if we are in a transaction
         err = d->document->checkExistingTransaction();
