@@ -184,7 +184,7 @@ void SKGReport::addItemsInMapping(QVariantHash& iMapping)
     iMapping.insert(QStringLiteral("about_homepage"), about.homepage());
     iMapping.insert(QStringLiteral("about_shortdescription"), about.shortDescription());
     iMapping.insert(QStringLiteral("about_othertext"), about.otherText());
-    iMapping.insert(QStringLiteral("about_did_you_know"), i18nc("Title for tips of the day", "Did you know ...?"));
+    iMapping.insert(QStringLiteral("about_did_you_know"), i18nc("Title for tips of the day", "Did you know …?"));
 }
 
 SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFile, QString& oHtml)
