@@ -18,6 +18,7 @@
 #include <sys/time.h>
 #endif
 
+#include <QLocale>
 #include <qapplication.h>
 #include <qca.h>
 #include <qdom.h>
@@ -853,7 +854,8 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
 
 QString SKGServices::toPercentageString(double iAmount, int iNbDecimal)
 {
-    return toCurrencyString(iAmount, QString(), iNbDecimal) % " %";
+    QString currencyString = toCurrencyString(iAmount, QString(), iNbDecimal);
+    return i18nc("Percent value; %1 is the value, % is the sign. Use the appropriate percent sign and positioning for your locale.", "%1%", currencyString);
 }
 
 QString SKGServices::toCurrencyString(double iAmount, const QString& iSymbol, int iNbDecimal)
@@ -861,7 +863,9 @@ QString SKGServices::toCurrencyString(double iAmount, const QString& iSymbol, in
     static auto lc_monetary = (SKGServices::getEnvVariable(QStringLiteral("LC_MONETARY")).isEmpty() ? "" : SKGServices::splitCSVLine(SKGServices::getEnvVariable(QStringLiteral("LC_MONETARY")), '.')[0]);
 
 
-    if (iSymbol == QStringLiteral("%")) {
+    QLocale locale;
+    QString localizedPercentSign = locale.percent();
+    if (iSymbol == localizedPercentSign || iSymbol == QStringLiteral("%")) {
         return toPercentageString(iAmount, iNbDecimal);
     }
     return QLocale(lc_monetary).toCurrencyString(iAmount, iSymbol.isEmpty() ? QStringLiteral(" ") : iSymbol, iNbDecimal).trimmed();
@@ -1274,11 +1278,11 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                 // BUG 249955 ^^^
 
                 // Suppress header
-                SKGTRACEL(10) << "input=[" << input.left(50) << "...]" << SKGENDL;
+                SKGTRACEL(10) << "input=[" << input.left(50) << "…]" << SKGENDL;
                 if (!iHeaderFile.isEmpty() && input.startsWith(iHeaderFile.toLatin1())) {
                     input = input.right(input.length() - iHeaderFile.length() - 11);
                 }
-                SKGTRACEL(10) << "input without header=[" << input.left(50) << "...]" << SKGENDL;
+                SKGTRACEL(10) << "input without header=[" << input.left(50) << "…]" << SKGENDL;
 
                 QCA::SecureArray u;
                 if (cipher != nullptr) {
@@ -1299,7 +1303,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
 
                 IFOK(err) {
                     // Check if decryption is OK
-                    SKGTRACEL(10) << "output 1=[" << uba.left(50) << "...]" << SKGENDL;
+                    SKGTRACEL(10) << "output 1=[" << uba.left(50) << "…]" << SKGENDL;
                     if (!iEncrypt) {
                         if (!uba.startsWith(QByteArray("SQLite format 3"))) {
                             if (!uba.startsWith(SQLCIPHERHEARDER)) {
@@ -1328,7 +1332,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                 cipher = nullptr;
             }
         }
-        SKGTRACEL(10) << "output 2=[" << uba.left(50) << "...]" << SKGENDL;
+        SKGTRACEL(10) << "output 2=[" << uba.left(50) << "…]" << SKGENDL;
 
         // output the results of that stage
         IFOK(err) {
