@@ -23,6 +23,7 @@
 #include <qcommandlineoption.h>
 #include <qcommandlineparser.h>
 #include <qsplashscreen.h>
+#include <QtQuickControls2/qquickstyle.h>
 
 /**
  * To compute the version
@@ -67,6 +68,10 @@ void SKGMessageOutput(QtMsgType type, const QMessageLogContext& context, const Q
  */
 int main(int argc, char** argv)
 {
+#ifdef SKG_WEBENGINE
+    QApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
+#endif
+
     qInstallMessageHandler(SKGMessageOutput);
     if (!SKGServices::getEnvVariable(QStringLiteral("SKGHIGHDPI")).isEmpty()) {
         QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -122,7 +127,7 @@ int main(int argc, char** argv)
     about.setOrganizationDomain("kde.org");
     about.setDesktopFileName(QStringLiteral("org.kde.skrooge"));
 
-    about.addCredit(QStringLiteral("vicnet, noidea, rbruce, JesusM, schunka, SylvaiNN, Wolf, Hizoka, neutron68, blep0, BigaAl, steffie, skierpage ..."), i18nc("Reason of the about/credit", "Users helping us to improve this application"));
+    about.addCredit(QStringLiteral("vicnet, noidea, rbruce, JesusM, schunka, SylvaiNN, Wolf, Hizoka, neutron68, blep0, BigaAl, steffie, skierpage …"), i18nc("Reason of the about/credit", "Users helping us to improve this application"));
 
     KAboutData::setApplicationData(about);
 
@@ -180,7 +185,7 @@ int main(int argc, char** argv)
             if (m_splash != nullptr) {
                 m_splash->setMask(pix.createMaskFromColor(Qt::blue));
                 m_splash->show();
-                m_splash->showMessage(i18nc("Splash screen message", "Loading ..."), Qt::AlignLeft, QColor(221, 130, 8));  // krazy:exclude=qmethods
+                m_splash->showMessage(i18nc("Splash screen message", "Loading …"), Qt::AlignLeft, QColor(221, 130, 8));  // krazy:exclude=qmethods
             }
         } else {
             SKGTRACE << "WARNING: Splash screen (" << splashPathRelativePath << ") not found !" << SKGENDL;
@@ -189,9 +194,7 @@ int main(int argc, char** argv)
 
     // First instance
     QApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
-#ifdef SKG_WEBENGINE
-    QApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
-#endif
+    QQuickStyle::setStyle("Breeze");
     auto m_widget = new SKGMainPanel(m_splash, &doc);
     m_widget->processArguments(argument);
     m_widget->setUnifiedTitleAndToolBarOnMac(true);
