@@ -2,9 +2,9 @@
 EXE=skgtestimportxhb
 
 #initialisation
-. `dirname $0`/init.sh
+. "`dirname \"$0\"`/init.sh"
 
-${EXE}
+"${EXE}"
 rc=$?
 if [ $rc != 0 ] ; then
 	exit $rc
