@@ -655,13 +655,13 @@ int main(int argc, char** argv)
         }
         int nb = 0;
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("operation"), QLatin1String(""), nb), true)
-        SKGTEST(QStringLiteral("CSV:nb operations"), nb, 1)
+        SKGTEST(QStringLiteral("CSV:nb transactions"), nb, 1)
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2015-07-07'"), nb), true)
-        SKGTEST(QStringLiteral("CSV:nb suboperations 2015-07-07"), nb, 1)
+        SKGTEST(QStringLiteral("CSV:nb subtransactions 2015-07-07"), nb, 1)
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2015-07-08'"), nb), true)
-        SKGTEST(QStringLiteral("CSV:nb suboperations 2015-07-08"), nb, 1)
+        SKGTEST(QStringLiteral("CSV:nb subtransactions 2015-07-08"), nb, 1)
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2015-07-09'"), nb), true)
-        SKGTEST(QStringLiteral("CSV:nb suboperations 2015-07-09"), nb, 1)
+        SKGTEST(QStringLiteral("CSV:nb subtransactions 2015-07-09"), nb, 1)
     }
 
     {
@@ -679,9 +679,9 @@ int main(int argc, char** argv)
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("operation"), QStringLiteral("d_date!='0000-00-00'"), nb), true)
         SKGTEST(QStringLiteral("CSV:nb operation"), nb, 1)
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2016-05-15'"), nb), true)
-        SKGTEST(QStringLiteral("CSV:nb suboperations 2016-05-15"), nb, 1)
+        SKGTEST(QStringLiteral("CSV:nb subtransactions 2016-05-15"), nb, 1)
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2016-05-20'"), nb), true)
-        SKGTEST(QStringLiteral("CSV:nb suboperations 2016-05-20"), nb, 1)
+        SKGTEST(QStringLiteral("CSV:nb subtransactions 2016-05-20"), nb, 1)
     }
 
     {
