@@ -155,8 +155,8 @@ int main(int argc, char** argv)
         }
 
         int nb = 0;
-        SKGTESTERROR(QStringLiteral("KMY:getNbObjects(operations without suboperation)"), document1.getNbObjects(QStringLiteral("operation"), QStringLiteral("NOT EXISTS (SELECT 1 FROM suboperation where rd_operation_id=operation.id)"), nb), true)
-        SKGTEST(QStringLiteral("KMY:getNbObjects(operations without suboperation)"), nb, 0)
+        SKGTESTERROR(QStringLiteral("KMY:getNbObjects(transactions without suboperation)"), document1.getNbObjects(QStringLiteral("operation"), QStringLiteral("NOT EXISTS (SELECT 1 FROM suboperation where rd_operation_id=operation.id)"), nb), true)
+        SKGTEST(QStringLiteral("KMY:getNbObjects(transactions without suboperation)"), nb, 0)
     }
 
     {
