@@ -39,7 +39,7 @@ int main(int argc, char** argv)
 
         int nboperation = 0;
         SKGTESTERROR(QStringLiteral("document1.getNbObjects()"), document1.getNbObjects(QStringLiteral("v_operation_display"), QLatin1String(""), nboperation), true)
-        SKGTEST(QStringLiteral("document1:nb operations"), nboperation, 0)
+        SKGTEST(QStringLiteral("document1:nb transactions"), nboperation, 0)
     }
 
     {
