@@ -453,12 +453,12 @@ int main(int argc, char** argv)
             bool test = false;
             for (const auto& msg : qAsConst(messages)) {
                 SKGTRACE << "Message:" << msg.Text << SKGENDL;
-                if (msg.Text.contains(QStringLiteral("0 operations imported")) ||
-                    msg.Text.contains(QStringLiteral("1 operation imported"))) {
+                if (msg.Text.contains(QStringLiteral("0 transactions imported")) ||
+                    msg.Text.contains(QStringLiteral("1 transaction imported"))) {
                     test = true;
                 }
             }
-            SKGTEST(QStringLiteral("message.0 operations imported"), static_cast<unsigned int>(test), 1)
+            SKGTEST(QStringLiteral("message.0 transactions imported"), static_cast<unsigned int>(test), 1)
         }
     }
 
