@@ -149,6 +149,26 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("XHB.importFile"), imp1.importFile(), true)
         }
     }
+
+    {
+        // Test import 481144
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_XHB"), err)
+
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportxhb/481144.xhb"));
+            SKGTESTERROR(QStringLiteral("XHB.importFile"), imp1.importFile(), true)
+        }
+
+        {
+            SKGStringListList result;
+            SKGTESTERROR(QStringLiteral("XHB.executeSelectSqliteOrder"), document1.executeSelectSqliteOrder(QStringLiteral("SELECT count(1) FROM refund"), result), true)
+            SKGTEST(QStringLiteral("XHB:tracker"), result.at(1).at(0), "1")
+        }
+    }    
     // End test
     SKGENDTEST()
 }
