@@ -58,7 +58,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("ACCOUNT:setClosed"), account.setClosed(true), true)
             SKGTESTERROR(QStringLiteral("ACCOUNT:save"), account.save(), true)
 
-            // Creation operation ==> failed
+            // Creation transaction ==> failed
             SKGTESTERROR(QStringLiteral("ACCOUNT:addOperation"), account.addOperation(op_1), false)
 
             // Reopen account
@@ -75,7 +75,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("UNITVALUE:setDate"), unit_euro_val1.setDate(now), true)
             SKGTESTERROR(QStringLiteral("UNITVALUE:save"), unit_euro_val1.save(), true)
 
-            // Creation operation ==> OK
+            // Creation transaction ==> OK
             SKGTESTERROR(QStringLiteral("ACCOUNT:addOperation"), account.addOperation(op_1), true)
 
             SKGSubOperationObject subop_1;
@@ -362,7 +362,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("UNITVALUE:setDate"), unit_euro_val1.setDate(now), true)
             SKGTESTERROR(QStringLiteral("UNITVALUE:save"), unit_euro_val1.save(), true)
 
-            // Creation operations
+            // Creation transactions
             SKGOperationObject op_1;
             SKGTESTERROR(QStringLiteral("ACCOUNT:addOperation"), account1.addOperation(op_1), true)
             SKGTESTERROR(QStringLiteral("OPE:setDate"), op_1.setDate(now), true)
@@ -389,7 +389,7 @@ int main(int argc, char** argv)
 
 
             SKGTESTERROR(QStringLiteral("OPE:setGroupOperation"), op_1.setGroupOperation(op_2), true)
-            SKGTESTERROR(QStringLiteral("OPE:setStatus"), op_1.setStatus(SKGOperationObject::POINTED), true)
+            SKGTESTERROR(QStringLiteral("OPE:setStatus"), op_1.setStatus(SKGOperationObject::MARKED), true)
             SKGTESTERROR(QStringLiteral("OPE:save"), op_1.save(), true)
 
             SKGOperationObject tmp;
